######################################################################################
######################################################################################
# Notations summary ##################################################################
######################################################################################
######################################################################################

# Symbol                  Description
# Date                    Date of measurements
# Year                    Year of measurements
# Month                   Month of measurements
# Day                     Day of measurements
# PlotNum                 Plot number
# Block                   Block
# Man                     Land-use regimes (L) (or management), including Mowing (M), Fencing (F) and Grazing (G)                                  
# Precip                  Precipiation treatments (P), iincluding Dry, control check (Amb, Ambient) and Wet                                
# GS_Pre                  Growing-season precipiation
# Annual_Pre              Annual precipiation
# ST                      Soil temperature at 5 cm depth
# SM                      Soil moisture at 5 cm depth
# SR                      Soil respiration
# RH                      Heterotrophic component of soil respiration
# RA                      Autotrophic component of soil respiration
# ANPP                    Aboveground net primary productivity
# BNPP                    Belowground net primary productivity
# MBC                     Soil microbial biomass carbon
# MBN                     Soil microbial biomass nitrogen

######################################################################################
######################################################################################
# R codes and results showed in R software ###########################################
######################################################################################
######################################################################################

f_path = "/Users/yh_wang/Documents/研究生/Chi_Zhang_200318/V04.4_CZ_IMSR/Dataset_and_R_code"
setwd(f_path)

rm(list=ls())
library(lavaan)
library(emmeans)
library(multcomp)

# each measurement dataset of the altered precipitation and land-use regimes experiment.
srda = read.csv("_Mani_Prec_SR_Each Measure.csv", header=T)
names(srda)
srda = within(srda, {
  Date=factor(Date);
  Year=factor(Year);
  Month=factor(Month);
  Day=factor(Day);
  Block=factor(Block);
  Man=ifelse(Man=="F", "Fencing", ifelse(Man=="G", "Grazing", "Mowing"));
  Man=factor(Man, levels=c("Fencing", "Grazing", "Mowing"));
  Precip=ifelse(Precip=="Dry", "Dry", ifelse(Precip=="Ck", "Amb", "Wet"));
  Precip=factor(Precip, levels=c("Dry", "Amb", "Wet"))})

# Annual dataset of the altered precipitation and land-use regimes experiment.
srda_ann = read.csv("_Mani_Prec_SR_Annual.csv", header=T)
names(srda_ann)
srda_ann = within(srda_ann, {
  Year=factor(Year);
  Block=factor(Block);
  Man=ifelse(Man=="Fencing", "Fencing", ifelse(Man=="Grazing", "Grazing", "Mowing"));
  Man=factor(Man, levels=c("Fencing", "Grazing", "Mowing"));
  Precip=ifelse(Precip=="Dry", "Dry", ifelse(Precip=="CK", "Amb", "Wet"));
  Precip=factor(Precip, levels=c("Dry", "Amb", "Wet"))
  })

######################################################################################
######################################################################################

######################################################################################
# Codes of the following part is used to investigating effects of land-use regimes
# and altered precipitation amount on soil temperature and moisture, net primary 
# productivity (aboveground, belowground), microbial biomass (carbon, nitrogen)and 
# soil respiration and its autotrophic and heterotrophic components with repeated 
# measures ANOVA and MANOVA using mixed effect models.
# Results of these analyses can also be found in Figure 2, 3 and Figure S4, S5.
######################################################################################

######################################################################################
# The following codes and results were used to analyze the effects of land-use regimes
# and altered precipitation amount on soil temperature in 2017, 2018, 2019 and during 
# the overall 3 years of our experiment.##############################################

# R codes for analyzing the effects of land-use regimes and altered precipitation 
# amount on soil temperature in 2017.
aov_st_17 = aov(ST~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda, Year=="2017"))
summary(aov_st_17)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  274.8   137.4               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)
# Man        2  2.170   1.085   0.472  0.655
# Residuals  4  9.196   2.299               
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value  Pr(>F)   
# Precip      2  55.65  27.823   7.804 0.00674 **
# Man:Precip  4  25.26   6.314   1.771 0.19946   
# Residuals  12  42.78   3.565                   
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq F value   Pr(>F)    
# Date             10   4941   494.1 182.152  < 2e-16 ***
# Man:Date         20    150     7.5   2.766 0.000183 ***
# Precip:Date      20     27     1.3   0.491 0.967482    
# Man:Precip:Date  40     54     1.4   0.500 0.994501    
# Residuals       180    488     2.7                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda$ST[srda$Year==2017], list(srda$Precip[srda$Year==2017], srda$Man[srda$Year==2017]), mean)

#      Fencing  Grazing   Mowing
# Dry 16.29798 16.08615 17.15214
# Amb 16.27759 16.29279 15.86130
# Wet 15.28021 15.66513 15.45545

summary(emmeans(aov_st_17, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate    SE df t.ratio p.value
#  Fencing Dry - Grazing Dry  0.21183 0.436 16  0.485  0.6340 
#  Fencing Dry - Mowing Dry  -0.85416 0.436 16 -1.957  0.0680 
#  Fencing Dry - Fencing Amb  0.02039 0.465 12  0.044  0.9657 
#  Fencing Dry - Grazing Amb  0.00519 0.436 16  0.012  0.9907 
#  Fencing Dry - Mowing Amb   0.43668 0.436 16  1.001  0.3320 
#  Fencing Dry - Fencing Wet  1.01777 0.465 12  2.190  0.0490 
#  Fencing Dry - Grazing Wet  0.63285 0.436 16  1.450  0.1664 
#  Fencing Dry - Mowing Wet   0.84254 0.436 16  1.930  0.0715 
#  Grazing Dry - Mowing Dry  -1.06599 0.436 16 -2.442  0.0266 
#  Grazing Dry - Fencing Amb -0.19144 0.436 16 -0.439  0.6668 
#  Grazing Dry - Grazing Amb -0.20664 0.465 12 -0.445  0.6646 
#  Grazing Dry - Mowing Amb   0.22485 0.436 16  0.515  0.6135 
#  Grazing Dry - Fencing Wet  0.80594 0.436 16  1.847  0.0834 
#  Grazing Dry - Grazing Wet  0.42102 0.465 12  0.906  0.3829 
#  Grazing Dry - Mowing Wet   0.63071 0.436 16  1.445  0.1677 
#  Mowing Dry - Fencing Amb   0.87455 0.436 16  2.004  0.0623 
#  Mowing Dry - Grazing Amb   0.85935 0.436 16  1.969  0.0665 
#  Mowing Dry - Mowing Amb    1.29084 0.465 12  2.777  0.0167 
#  Mowing Dry - Fencing Wet   1.87193 0.436 16  4.289  0.0006 
#  Mowing Dry - Grazing Wet   1.48701 0.436 16  3.407  0.0036 
#  Mowing Dry - Mowing Wet    1.69669 0.465 12  3.650  0.0033 
#  Fencing Amb - Grazing Amb -0.01520 0.436 16 -0.035  0.9727 
#  Fencing Amb - Mowing Amb   0.41629 0.436 16  0.954  0.3544 
#  Fencing Amb - Fencing Wet  0.99738 0.465 12  2.146  0.0531 
#  Fencing Amb - Grazing Wet  0.61246 0.436 16  1.403  0.1796 
#  Fencing Amb - Mowing Wet   0.82215 0.436 16  1.884  0.0779 
#  Grazing Amb - Mowing Amb   0.43149 0.436 16  0.989  0.3376 
#  Grazing Amb - Fencing Wet  1.01258 0.436 16  2.320  0.0339 
#  Grazing Amb - Grazing Wet  0.62766 0.465 12  1.350  0.2018 
#  Grazing Amb - Mowing Wet   0.83734 0.436 16  1.919  0.0731 
#  Mowing Amb - Fencing Wet   0.58109 0.436 16  1.331  0.2017 
#  Mowing Amb - Grazing Wet   0.19617 0.436 16  0.449  0.6591 
#  Mowing Amb - Mowing Wet    0.40586 0.465 12  0.873  0.3997 
#  Fencing Wet - Grazing Wet -0.38492 0.436 16 -0.882  0.3909 
#  Fencing Wet - Mowing Wet  -0.17523 0.436 16 -0.401  0.6934 
#  Grazing Wet - Mowing Wet   0.20969 0.436 16  0.480  0.6374 
# 
# Results are averaged over the levels of: Date 

tapply(srda$ST[srda$Year==2017], list(srda$Man[srda$Year==2017]), mean)

#  Fencing  Grazing   Mowing 
# 15.95193 16.01469 16.15630 

summary(emmeans(aov_st_17, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate    SE df t.ratio p.value
#  Fencing - Grazing  -0.0628 0.216  4 -0.291  0.7854 
#  Fencing - Mowing   -0.2044 0.216  4 -0.948  0.3967 
#  Grazing - Mowing   -0.1416 0.216  4 -0.657  0.5470 
# 
# Results are averaged over the levels of: Precip, Date 

tapply(srda$ST[srda$Year==2017], list(srda$Precip[srda$Year==2017]), mean)

#      Dry      Amb      Wet 
# 16.51209 16.14389 15.46693 

summary(emmeans(aov_st_17, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate    SE df t.ratio p.value
#  Dry - Amb    0.368 0.268 12 1.372   0.1952 
#  Dry - Wet    1.045 0.268 12 3.894   0.0021 
#  Amb - Wet    0.677 0.268 12 2.523   0.0268 
# 
# Results are averaged over the levels of: Man, Date 

# R codes for analyzing the effects of land-use regimes and altered precipitation 
# amount on soil temperature in 2018.
aov_st_18 = aov(ST~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda, Year=="2018"))
summary(aov_st_18)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  47.24   23.62               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)
# Man        2  45.59   22.80   1.205  0.389
# Residuals  4  75.69   18.92               
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value  Pr(>F)   
# Precip      2  33.53  16.763   8.133 0.00585 **
# Man:Precip  4   1.58   0.396   0.192 0.93796   
# Residuals  12  24.73   2.061                   
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq F value Pr(>F)    
# Date             10   4064   406.4 121.712 <2e-16 ***
# Man:Date         20     55     2.7   0.821  0.686    
# Precip:Date      20     32     1.6   0.478  0.972    
# Man:Precip:Date  40     36     0.9   0.267  1.000    
# Residuals       180    601     3.3                   
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda$ST[srda$Year==2018], list(srda$Precip[srda$Year==2018], srda$Man[srda$Year==2018]), mean)

#      Fencing  Grazing   Mowing
# Dry 16.47668 17.48451 17.25748
# Amb 15.90061 16.58221 16.52075
# Wet 15.79977 16.86470 16.50235

summary(emmeans(aov_st_18, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate    SE    df t.ratio p.value
#  Fencing Dry - Grazing Dry  -1.0078 0.682  5.84 -1.477  0.1914 
#  Fencing Dry - Mowing Dry   -0.7808 0.682  5.84 -1.144  0.2972 
#  Fencing Dry - Fencing Amb   0.5761 0.353 12.00  1.630  0.1291 
#  Fencing Dry - Grazing Amb  -0.1055 0.682  5.84 -0.155  0.8823 
#  Fencing Dry - Mowing Amb   -0.0441 0.682  5.84 -0.065  0.9507 
#  Fencing Dry - Fencing Wet   0.6769 0.353 12.00  1.915  0.0796 
#  Fencing Dry - Grazing Wet  -0.3880 0.682  5.84 -0.569  0.5908 
#  Fencing Dry - Mowing Wet   -0.0257 0.682  5.84 -0.038  0.9712 
#  Grazing Dry - Mowing Dry    0.2270 0.682  5.84  0.333  0.7510 
#  Grazing Dry - Fencing Amb   1.5839 0.682  5.84  2.321  0.0605 
#  Grazing Dry - Grazing Amb   0.9023 0.353 12.00  2.553  0.0253 
#  Grazing Dry - Mowing Amb    0.9638 0.682  5.84  1.412  0.2088 
#  Grazing Dry - Fencing Wet   1.6847 0.682  5.84  2.469  0.0496 
#  Grazing Dry - Grazing Wet   0.6198 0.353 12.00  1.754  0.1050 
#  Grazing Dry - Mowing Wet    0.9822 0.682  5.84  1.439  0.2014 
#  Mowing Dry - Fencing Amb    1.3569 0.682  5.84  1.989  0.0952 
#  Mowing Dry - Grazing Amb    0.6753 0.682  5.84  0.990  0.3615 
#  Mowing Dry - Mowing Amb     0.7367 0.353 12.00  2.085  0.0591 
#  Mowing Dry - Fencing Wet    1.4577 0.682  5.84  2.136  0.0778 
#  Mowing Dry - Grazing Wet    0.3928 0.682  5.84  0.576  0.5863 
#  Mowing Dry - Mowing Wet     0.7551 0.353 12.00  2.137  0.0539 
#  Fencing Amb - Grazing Amb  -0.6816 0.682  5.84 -0.999  0.3574 
#  Fencing Amb - Mowing Amb   -0.6201 0.682  5.84 -0.909  0.3994 
#  Fencing Amb - Fencing Wet   0.1008 0.353 12.00  0.285  0.7803 
#  Fencing Amb - Grazing Wet  -0.9641 0.682  5.84 -1.413  0.2087 
#  Fencing Amb - Mowing Wet   -0.6017 0.682  5.84 -0.882  0.4126 
#  Grazing Amb - Mowing Amb    0.0615 0.682  5.84  0.090  0.9312 
#  Grazing Amb - Fencing Wet   0.7824 0.682  5.84  1.147  0.2963 
#  Grazing Amb - Grazing Wet  -0.2825 0.353 12.00 -0.799  0.4397 
#  Grazing Amb - Mowing Wet    0.0799 0.682  5.84  0.117  0.9108 
#  Mowing Amb - Fencing Wet    0.7210 0.682  5.84  1.057  0.3324 
#  Mowing Amb - Grazing Wet   -0.3440 0.682  5.84 -0.504  0.6326 
#  Mowing Amb - Mowing Wet     0.0184 0.353 12.00  0.052  0.9593 
#  Fencing Wet - Grazing Wet  -1.0649 0.682  5.84 -1.561  0.1709 
#  Fencing Wet - Mowing Wet   -0.7026 0.682  5.84 -1.030  0.3439 
#  Grazing Wet - Mowing Wet    0.3623 0.682  5.84  0.531  0.6150 
# 
# Results are averaged over the levels of: Date 

tapply(srda$ST[srda$Year==2018], list(srda$Man[srda$Year==2018]), mean)

#  Fencing  Grazing   Mowing 
# 16.05902 16.97714 16.76019 

summary(emmeans(aov_st_18, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate    SE df t.ratio p.value
#  Fencing - Grazing   -0.918 0.618  4 -1.485  0.2117 
#  Fencing - Mowing    -0.701 0.618  4 -1.134  0.3201 
#  Grazing - Mowing     0.217 0.618  4  0.351  0.7434 
# 
# Results are averaged over the levels of: Precip, Date 

tapply(srda$ST[srda$Year==2018], list(srda$Precip[srda$Year==2018]), mean)

#      Dry      Amb      Wet 
# 17.07289 16.33452 16.38894 

summary(emmeans(aov_st_18, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate    SE df t.ratio p.value
#  Dry - Amb   0.7384 0.204 12  3.618  0.0035 
#  Dry - Wet   0.6840 0.204 12  3.352  0.0058 
#  Amb - Wet  -0.0544 0.204 12 -0.267  0.7942 
# 
# Results are averaged over the levels of: Man, Date 

# R codes for analyzing the effects of land-use regimes and altered precipitation
# amount on soil temperature in 2019.
aov_st_19 = aov(ST~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda, Year=="2019"))
summary(aov_st_19)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  60.97   30.49               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)
# Man        2  12.04   6.022   0.204  0.824
# Residuals  4 118.16  29.539               
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value Pr(>F)  
# Precip      2 108.48   54.24   6.313 0.0134 *
# Man:Precip  4  32.59    8.15   0.948 0.4697  
# Residuals  12 103.10    8.59                 
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq  F value  Pr(>F)    
# Date             11  12947  1177.0 1417.694 < 2e-16 ***
# Man:Date         22     38     1.7    2.078 0.00452 ** 
# Precip:Date      22     24     1.1    1.332 0.15409    
# Man:Precip:Date  44     31     0.7    0.842 0.74630    
# Residuals       198    164     0.8                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda$ST[srda$Year==2019], list(srda$Precip[srda$Year==2019], srda$Man[srda$Year==2019]), mean)

#      Fencing  Grazing   Mowing
# Dry 15.41679 16.61908 16.18640
# Amb 15.59617 15.21890 15.69249
# Wet 14.55408 15.14160 14.29959

summary(emmeans(aov_st_19, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate    SE    df t.ratio p.value
#  Fencing Dry - Grazing Dry  -1.2023 0.930  8.99 -1.293  0.2284 
#  Fencing Dry - Mowing Dry   -0.7696 0.930  8.99 -0.827  0.4294 
#  Fencing Dry - Fencing Amb  -0.1794 0.691 12.00 -0.260  0.7995 
#  Fencing Dry - Grazing Amb   0.1979 0.930  8.99  0.213  0.8363 
#  Fencing Dry - Mowing Amb   -0.2757 0.930  8.99 -0.296  0.7737 
#  Fencing Dry - Fencing Wet   0.8627 0.691 12.00  1.249  0.2356 
#  Fencing Dry - Grazing Wet   0.2752 0.930  8.99  0.296  0.7741 
#  Fencing Dry - Mowing Wet    1.1172 0.930  8.99  1.201  0.2604 
#  Grazing Dry - Mowing Dry    0.4327 0.930  8.99  0.465  0.6529 
#  Grazing Dry - Fencing Amb   1.0229 0.930  8.99  1.100  0.3000 
#  Grazing Dry - Grazing Amb   1.4002 0.691 12.00  2.027  0.0655 
#  Grazing Dry - Mowing Amb    0.9266 0.930  8.99  0.996  0.3452 
#  Grazing Dry - Fencing Wet   2.0650 0.930  8.99  2.220  0.0536 
#  Grazing Dry - Grazing Wet   1.4775 0.691 12.00  2.139  0.0537 
#  Grazing Dry - Mowing Wet    2.3195 0.930  8.99  2.494  0.0342 
#  Mowing Dry - Fencing Amb    0.5902 0.930  8.99  0.635  0.5415 
#  Mowing Dry - Grazing Amb    0.9675 0.930  8.99  1.040  0.3254 
#  Mowing Dry - Mowing Amb     0.4939 0.691 12.00  0.715  0.4883 
#  Mowing Dry - Fencing Wet    1.6323 0.930  8.99  1.755  0.1132 
#  Mowing Dry - Grazing Wet    1.0448 0.930  8.99  1.123  0.2904 
#  Mowing Dry - Mowing Wet     1.8868 0.691 12.00  2.731  0.0182 
#  Fencing Amb - Grazing Amb   0.3773 0.930  8.99  0.406  0.6945 
#  Fencing Amb - Mowing Amb   -0.0963 0.930  8.99 -0.104  0.9198 
#  Fencing Amb - Fencing Wet   1.0421 0.691 12.00  1.508  0.1573 
#  Fencing Amb - Grazing Wet   0.4546 0.930  8.99  0.489  0.6368 
#  Fencing Amb - Mowing Wet    1.2966 0.930  8.99  1.394  0.1968 
#  Grazing Amb - Mowing Amb   -0.4736 0.930  8.99 -0.509  0.6229 
#  Grazing Amb - Fencing Wet   0.6648 0.930  8.99  0.715  0.4929 
#  Grazing Amb - Grazing Wet   0.0773 0.691 12.00  0.112  0.9128 
#  Grazing Amb - Mowing Wet    0.9193 0.930  8.99  0.988  0.3488 
#  Mowing Amb - Fencing Wet    1.1384 0.930  8.99  1.224  0.2521 
#  Mowing Amb - Grazing Wet    0.5509 0.930  8.99  0.592  0.5683 
#  Mowing Amb - Mowing Wet     1.3929 0.691 12.00  2.016  0.0667 
#  Fencing Wet - Grazing Wet  -0.5875 0.930  8.99 -0.632  0.5433 
#  Fencing Wet - Mowing Wet    0.2545 0.930  8.99  0.274  0.7906 
#  Grazing Wet - Mowing Wet    0.8420 0.930  8.99  0.905  0.3890 
# 
# Results are averaged over the levels of: Date 

tapply(srda$ST[srda$Year==2019], list(srda$Man[srda$Year==2019]), mean)

#  Fencing  Grazing   Mowing 
# 15.18901 15.65986 15.39283 

summary(emmeans(aov_st_19, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate   SE df t.ratio p.value
#  Fencing - Grazing   -0.471 0.74  4 -0.637  0.5590 
#  Fencing - Mowing    -0.204 0.74  4 -0.276  0.7965 
#  Grazing - Mowing     0.267 0.74  4  0.361  0.7363 
# 
# Results are averaged over the levels of: Precip, Date 

tapply(srda$ST[srda$Year==2019], list(srda$Precip[srda$Year==2019]), mean)

#      Dry      Amb      Wet 
# 16.07409 15.50252 14.66509 

summary(emmeans(aov_st_19, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate    SE df t.ratio p.value
#  Dry - Amb    0.572 0.399 12 1.433   0.1774 
#  Dry - Wet    1.409 0.399 12 3.532   0.0041 
#  Amb - Wet    0.837 0.399 12 2.099   0.0576 
# 
# Results are averaged over the levels of: Man, Date 

# R codes for analyzing the effects of land-use regimes and altered precipitation
# amount on soil temperature during the overall 3 years.
aov_st_oa = aov(ST~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda))
summary(aov_st_oa)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  32.47   16.23               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)
# Man        2  38.86   19.43   0.834  0.498
# Residuals  4  93.17   23.29               
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value  Pr(>F)   
# Precip      2 171.05   85.52   12.80 0.00106 **
# Man:Precip  4  24.59    6.15    0.92 0.48367   
# Residuals  12  80.16    6.68                   
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq F value Pr(>F)    
# Date             33  22170   671.8 221.142 <2e-16 ***
# Man:Date         66    264     4.0   1.315 0.0551 .  
# Precip:Date      66    109     1.7   0.546 0.9986    
# Man:Precip:Date 132    155     1.2   0.388 1.0000    
# Residuals       594   1805     3.0                   
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda$ST, list(srda$Precip, srda$Man), mean)

#      Fencing  Grazing   Mowing
# Dry 16.04479 16.72665 16.84537
# Amb 15.91513 16.00741 16.01507
# Wet 15.19202 15.86845 15.38620

summary(emmeans(aov_st_oa, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate    SE    df t.ratio p.value
#  Fencing Dry - Grazing Dry -0.68186 0.489  8.93 -1.393  0.1973 
#  Fencing Dry - Mowing Dry  -0.80058 0.489  8.93 -1.636  0.1366 
#  Fencing Dry - Fencing Amb  0.12966 0.362 12.00  0.358  0.7264 
#  Fencing Dry - Grazing Amb  0.03738 0.489  8.93  0.076  0.9408 
#  Fencing Dry - Mowing Amb   0.02972 0.489  8.93  0.061  0.9529 
#  Fencing Dry - Fencing Wet  0.85277 0.362 12.00  2.356  0.0363 
#  Fencing Dry - Grazing Wet  0.17634 0.489  8.93  0.360  0.7270 
#  Fencing Dry - Mowing Wet   0.65859 0.489  8.93  1.346  0.2116 
#  Grazing Dry - Mowing Dry  -0.11872 0.489  8.93 -0.243  0.8138 
#  Grazing Dry - Fencing Amb  0.81153 0.489  8.93  1.658  0.1320 
#  Grazing Dry - Grazing Amb  0.71925 0.362 12.00  1.987  0.0702 
#  Grazing Dry - Mowing Amb   0.71158 0.489  8.93  1.454  0.1802 
#  Grazing Dry - Fencing Wet  1.53463 0.489  8.93  3.135  0.0121 
#  Grazing Dry - Grazing Wet  0.85820 0.362 12.00  2.371  0.0353 
#  Grazing Dry - Mowing Wet   1.34045 0.489  8.93  2.739  0.0231 
#  Mowing Dry - Fencing Amb   0.93025 0.489  8.93  1.901  0.0901 
#  Mowing Dry - Grazing Amb   0.83797 0.489  8.93  1.712  0.1213 
#  Mowing Dry - Mowing Amb    0.83030 0.362 12.00  2.294  0.0406 
#  Mowing Dry - Fencing Wet   1.65335 0.489  8.93  3.378  0.0082 
#  Mowing Dry - Grazing Wet   0.97692 0.489  8.93  1.996  0.0773 
#  Mowing Dry - Mowing Wet    1.45917 0.362 12.00  4.032  0.0017 
#  Fencing Amb - Grazing Amb -0.09228 0.489  8.93 -0.189  0.8547 
#  Fencing Amb - Mowing Amb  -0.09994 0.489  8.93 -0.204  0.8428 
#  Fencing Amb - Fencing Wet  0.72311 0.362 12.00  1.998  0.0689 
#  Fencing Amb - Grazing Wet  0.04667 0.489  8.93  0.095  0.9261 
#  Fencing Amb - Mowing Wet   0.52892 0.489  8.93  1.081  0.3082 
#  Grazing Amb - Mowing Amb  -0.00766 0.489  8.93 -0.016  0.9879 
#  Grazing Amb - Fencing Wet  0.81539 0.489  8.93  1.666  0.1304 
#  Grazing Amb - Grazing Wet  0.13895 0.362 12.00  0.384  0.7077 
#  Grazing Amb - Mowing Wet   0.62120 0.489  8.93  1.269  0.2365 
#  Mowing Amb - Fencing Wet   0.82305 0.489  8.93  1.682  0.1272 
#  Mowing Amb - Grazing Wet   0.14662 0.489  8.93  0.300  0.7714 
#  Mowing Amb - Mowing Wet    0.62887 0.362 12.00  1.738  0.1079 
#  Fencing Wet - Grazing Wet -0.67643 0.489  8.93 -1.382  0.2006 
#  Fencing Wet - Mowing Wet  -0.19418 0.489  8.93 -0.397  0.7009 
#  Grazing Wet - Mowing Wet   0.48225 0.489  8.93  0.985  0.3504 
# 
# Results are averaged over the levels of: Date 

tapply(srda$ST, list(srda$Man), mean)

#  Fencing  Grazing   Mowing 
# 15.71731 16.20084 16.08221 

summary(emmeans(aov_st_oa, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate   SE df t.ratio p.value
#  Fencing - Grazing   -0.484 0.39  4 -1.239  0.2830 
#  Fencing - Mowing    -0.365 0.39  4 -0.935  0.4026 
#  Grazing - Mowing     0.119 0.39  4  0.304  0.7763 
# 
# Results are averaged over the levels of: Precip, Date 

tapply(srda$ST, list(srda$Precip), mean)

#      Dry      Amb      Wet 
# 16.53894 15.97920 15.48223 

summary(emmeans(aov_st_oa, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate    SE df t.ratio p.value
#  Dry - Amb    0.560 0.209 12 2.679   0.0201 
#  Dry - Wet    1.057 0.209 12 5.057   0.0003 
#  Amb - Wet    0.497 0.209 12 2.378   0.0349 
# 
# Results are averaged over the levels of: Man, Date 

######################################################################################
# The following codes and results were used to analyze the effects of land-use regimes
# and altered precipitation amount on soil moisture in 2017, 2018, 2019 and during the 
# overall 3 years of our experiment.##################################################

# R codes for analyzing the effects of land-use regimes and altered precipitation 
# amount on soil moisture in 2017.
aov_sm_17 = aov(SM~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda, Year=="2017"))
summary(aov_sm_17)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2    2.1    1.05               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)
# Man        2  2.183   1.091    1.21  0.388
# Residuals  4  3.608   0.902               
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value  Pr(>F)    
# Precip      2  712.1   356.1 860.719 1.1e-13 ***
# Man:Precip  4    7.5     1.9   4.506  0.0188 *  
# Residuals  12    5.0     0.4                    
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq F value   Pr(>F)    
# Date             10  735.3   73.53 173.273  < 2e-16 ***
# Man:Date         20   33.2    1.66   3.907 3.83e-07 ***
# Precip:Date      20   79.3    3.96   9.338  < 2e-16 ***
# Man:Precip:Date  40   14.8    0.37   0.872    0.688    
# Residuals       180   76.4    0.42                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda$SM[srda$Year==2017], list(srda$Precip[srda$Year==2017], srda$Man[srda$Year==2017]), mean)

#      Fencing  Grazing   Mowing
# Dry 5.339166 5.241167 5.497466
# Amb 7.860373 8.034196 7.720506
# Wet 9.406955 9.061176 8.760607

summary(emmeans(aov_sm_17, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate    SE   df t.ratio p.value
#  Fencing Dry - Grazing Dry    0.098 0.187 11.5   0.524 0.6100 
#  Fencing Dry - Mowing Dry    -0.158 0.187 11.5  -0.847 0.4143 
#  Fencing Dry - Fencing Amb   -2.521 0.158 12.0 -15.923 <.0001 
#  Fencing Dry - Grazing Amb   -2.695 0.187 11.5 -14.419 <.0001 
#  Fencing Dry - Mowing Amb    -2.381 0.187 11.5 -12.741 <.0001 
#  Fencing Dry - Fencing Wet   -4.068 0.158 12.0 -25.690 <.0001 
#  Fencing Dry - Grazing Wet   -3.722 0.187 11.5 -19.913 <.0001 
#  Fencing Dry - Mowing Wet    -3.421 0.187 11.5 -18.305 <.0001 
#  Grazing Dry - Mowing Dry    -0.256 0.187 11.5  -1.371 0.1965 
#  Grazing Dry - Fencing Amb   -2.619 0.187 11.5 -14.013 <.0001 
#  Grazing Dry - Grazing Amb   -2.793 0.158 12.0 -17.640 <.0001 
#  Grazing Dry - Mowing Amb    -2.479 0.187 11.5 -13.265 <.0001 
#  Grazing Dry - Fencing Wet   -4.166 0.187 11.5 -22.288 <.0001 
#  Grazing Dry - Grazing Wet   -3.820 0.158 12.0 -24.126 <.0001 
#  Grazing Dry - Mowing Wet    -3.519 0.187 11.5 -18.830 <.0001 
#  Mowing Dry - Fencing Amb    -2.363 0.187 11.5 -12.642 <.0001 
#  Mowing Dry - Grazing Amb    -2.537 0.187 11.5 -13.572 <.0001 
#  Mowing Dry - Mowing Amb     -2.223 0.158 12.0 -14.040 <.0001 
#  Mowing Dry - Fencing Wet    -3.909 0.187 11.5 -20.916 <.0001 
#  Mowing Dry - Grazing Wet    -3.564 0.187 11.5 -19.066 <.0001 
#  Mowing Dry - Mowing Wet     -3.263 0.158 12.0 -20.609 <.0001 
#  Fencing Amb - Grazing Amb   -0.174 0.187 11.5  -0.930 0.3715 
#  Fencing Amb - Mowing Amb     0.140 0.187 11.5   0.748 0.4693 
#  Fencing Amb - Fencing Wet   -1.547 0.158 12.0  -9.768 <.0001 
#  Fencing Amb - Grazing Wet   -1.201 0.187 11.5  -6.424 <.0001 
#  Fencing Amb - Mowing Wet    -0.900 0.187 11.5  -4.816 0.0005 
#  Grazing Amb - Mowing Amb     0.314 0.187 11.5   1.678 0.1203 
#  Grazing Amb - Fencing Wet   -1.373 0.187 11.5  -7.344 <.0001 
#  Grazing Amb - Grazing Wet   -1.027 0.158 12.0  -6.486 <.0001 
#  Grazing Amb - Mowing Wet    -0.726 0.187 11.5  -3.886 0.0023 
#  Mowing Amb - Fencing Wet    -1.686 0.187 11.5  -9.023 <.0001 
#  Mowing Amb - Grazing Wet    -1.341 0.187 11.5  -7.173 <.0001 
#  Mowing Amb - Mowing Wet     -1.040 0.158 12.0  -6.569 <.0001 
#  Fencing Wet - Grazing Wet    0.346 0.187 11.5   1.850 0.0902 
#  Fencing Wet - Mowing Wet     0.646 0.187 11.5   3.458 0.0050 
#  Grazing Wet - Mowing Wet     0.301 0.187 11.5   1.608 0.1349 
# 
# Results are averaged over the levels of: Date 

tapply(srda$SM[srda$Year==2017], list(srda$Man[srda$Year==2017]), mean)

#  Fencing  Grazing   Mowing 
# 7.535498 7.445513 7.326193 

summary(emmeans(aov_sm_17, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate    SE df t.ratio p.value
#  Fencing - Grazing    0.090 0.135  4 0.667   0.5415 
#  Fencing - Mowing     0.209 0.135  4 1.551   0.1959 
#  Grazing - Mowing     0.119 0.135  4 0.884   0.4267 
# 
# Results are averaged over the levels of: Precip, Date 

tapply(srda$SM[srda$Year==2017], list(srda$Precip[srda$Year==2017]), mean)

#      Dry      Amb      Wet 
# 5.359266 7.871691 9.076246 

summary(emmeans(aov_sm_17, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate     SE df t.ratio p.value
#  Dry - Amb    -2.51 0.0914 12 -27.483 <.0001 
#  Dry - Wet    -3.72 0.0914 12 -40.660 <.0001 
#  Amb - Wet    -1.20 0.0914 12 -13.177 <.0001 
# 
# Results are averaged over the levels of: Man, Date 

# R codes for analyzing the effects of land-use regimes and altered precipitation 
# amount on soil moisture in 2018.
aov_sm_18 = aov(SM~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda, Year=="2018"))
summary(aov_sm_18)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  20.41   10.21               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)  
# Man        2 142.30   71.15   10.57 0.0253 *
# Residuals  4  26.92    6.73                 
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2 1343.2   671.6   272.1 1.01e-10 ***
# Man:Precip  4  132.3    33.1    13.4 0.000221 ***
# Residuals  12   29.6     2.5                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq F value Pr(>F)    
# Date             10 2403.2  240.32  93.998 <2e-16 ***
# Man:Date         20   68.4    3.42   1.338  0.161    
# Precip:Date      20   71.3    3.56   1.394  0.130    
# Man:Precip:Date  40   85.0    2.12   0.831  0.752    
# Residuals       180  460.2    2.56                   
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda$SM[srda$Year==2018], list(srda$Precip[srda$Year==2018], srda$Man[srda$Year==2018]), mean)

#       Fencing  Grazing    Mowing
# Dry  7.381082  8.11359  8.062167
# Amb  8.716753 10.11448  9.376536
# Wet 12.743395 14.89471 11.165002

summary(emmeans(aov_sm_18, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate    SE   df t.ratio p.value
#  Fencing Dry - Grazing Dry  -0.7325 0.485 10.2  -1.509 0.1617 
#  Fencing Dry - Mowing Dry   -0.6811 0.485 10.2  -1.403 0.1904 
#  Fencing Dry - Fencing Amb  -1.3357 0.387 12.0  -3.453 0.0048 
#  Fencing Dry - Grazing Amb  -2.7334 0.485 10.2  -5.630 0.0002 
#  Fencing Dry - Mowing Amb   -1.9955 0.485 10.2  -4.110 0.0020 
#  Fencing Dry - Fencing Wet  -5.3623 0.387 12.0 -13.863 <.0001 
#  Fencing Dry - Grazing Wet  -7.5136 0.485 10.2 -15.477 <.0001 
#  Fencing Dry - Mowing Wet   -3.7839 0.485 10.2  -7.794 <.0001 
#  Grazing Dry - Mowing Dry    0.0514 0.485 10.2   0.106 0.9177 
#  Grazing Dry - Fencing Amb  -0.6032 0.485 10.2  -1.242 0.2419 
#  Grazing Dry - Grazing Amb  -2.0009 0.387 12.0  -5.173 0.0002 
#  Grazing Dry - Mowing Amb   -1.2629 0.485 10.2  -2.601 0.0260 
#  Grazing Dry - Fencing Wet  -4.6298 0.485 10.2  -9.536 <.0001 
#  Grazing Dry - Grazing Wet  -6.7811 0.387 12.0 -17.531 <.0001 
#  Grazing Dry - Mowing Wet   -3.0514 0.485 10.2  -6.285 0.0001 
#  Mowing Dry - Fencing Amb   -0.6546 0.485 10.2  -1.348 0.2068 
#  Mowing Dry - Grazing Amb   -2.0523 0.485 10.2  -4.227 0.0017 
#  Mowing Dry - Mowing Amb    -1.3144 0.387 12.0  -3.398 0.0053 
#  Mowing Dry - Fencing Wet   -4.6812 0.485 10.2  -9.642 <.0001 
#  Mowing Dry - Grazing Wet   -6.8325 0.485 10.2 -14.074 <.0001 
#  Mowing Dry - Mowing Wet    -3.1028 0.387 12.0  -8.022 <.0001 
#  Fencing Amb - Grazing Amb  -1.3977 0.485 10.2  -2.879 0.0161 
#  Fencing Amb - Mowing Amb   -0.6598 0.485 10.2  -1.359 0.2034 
#  Fencing Amb - Fencing Wet  -4.0266 0.387 12.0 -10.410 <.0001 
#  Fencing Amb - Grazing Wet  -6.1780 0.485 10.2 -12.725 <.0001 
#  Fencing Amb - Mowing Wet   -2.4482 0.485 10.2  -5.043 0.0005 
#  Grazing Amb - Mowing Amb    0.7379 0.485 10.2   1.520 0.1589 
#  Grazing Amb - Fencing Wet  -2.6289 0.485 10.2  -5.415 0.0003 
#  Grazing Amb - Grazing Wet  -4.7802 0.387 12.0 -12.358 <.0001 
#  Grazing Amb - Mowing Wet   -1.0505 0.485 10.2  -2.164 0.0552 
#  Mowing Amb - Fencing Wet   -3.3669 0.485 10.2  -6.935 <.0001 
#  Mowing Amb - Grazing Wet   -5.5182 0.485 10.2 -11.366 <.0001 
#  Mowing Amb - Mowing Wet    -1.7885 0.387 12.0  -4.624 0.0006 
#  Fencing Wet - Grazing Wet  -2.1513 0.485 10.2  -4.431 0.0012 
#  Fencing Wet - Mowing Wet    1.5784 0.485 10.2   3.251 0.0085 
#  Grazing Wet - Mowing Wet    3.7297 0.485 10.2   7.682 <.0001 
# 
# Results are averaged over the levels of: Date 

tapply(srda$SM[srda$Year==2018], list(srda$Man[srda$Year==2018]), mean)

#   Fencing   Grazing    Mowing 
#  9.613743 11.040924  9.534568 

summary(emmeans(aov_sm_18, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate    SE df t.ratio p.value
#  Fencing - Grazing  -1.4272 0.369  4 -3.871  0.0180 
#  Fencing - Mowing    0.0792 0.369  4  0.215  0.8405 
#  Grazing - Mowing    1.5064 0.369  4  4.085  0.0150 
# 
# Results are averaged over the levels of: Precip, Date 

tapply(srda$SM[srda$Year==2018], list(srda$Precip[srda$Year==2018]), mean)

#       Dry       Amb       Wet 
#  7.852280  9.402588 12.934368 

summary(emmeans(aov_sm_18, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate    SE df t.ratio p.value
#  Dry - Amb    -1.55 0.223 12  -6.942 <.0001 
#  Dry - Wet    -5.08 0.223 12 -22.757 <.0001 
#  Amb - Wet    -3.53 0.223 12 -15.815 <.0001 
# 
# Results are averaged over the levels of: Man, Date 

# R codes for analyzing the effects of land-use regimes and altered precipitation 
# amount on soil moisture in 2019.
aov_sm_19 = aov(SM~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda, Year=="2019"))
summary(aov_sm_19)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  96.43   48.21               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)  
# Man        2  252.7  126.32   4.705  0.089 .
# Residuals  4  107.4   26.85                 
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2 1646.8   823.4   80.13 1.14e-07 ***
# Man:Precip  4   53.4    13.4    1.30    0.324    
# Residuals  12  123.3    10.3                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq F value  Pr(>F)    
# Date             11   3241  294.65 139.166 < 2e-16 ***
# Man:Date         22     85    3.88   1.833 0.01602 *  
# Precip:Date      22    103    4.67   2.204 0.00229 ** 
# Man:Precip:Date  44    100    2.27   1.070 0.36698    
# Residuals       198    419    2.12                    
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda$SM[srda$Year==2019], list(srda$Precip[srda$Year==2019], srda$Man[srda$Year==2019]), mean)

#       Fencing   Grazing    Mowing
# Dry  6.330680  7.752693  9.057359
# Amb  8.480546  9.225899 11.302625
# Wet 12.589263 13.381388 13.521476

summary(emmeans(aov_sm_19, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate    SE   df t.ratio p.value
#  Fencing Dry - Grazing Dry   -1.422 0.937 10.4 -1.518  0.1588 
#  Fencing Dry - Mowing Dry    -2.727 0.937 10.4 -2.910  0.0149 
#  Fencing Dry - Fencing Amb   -2.150 0.756 12.0 -2.845  0.0147 
#  Fencing Dry - Grazing Amb   -2.895 0.937 10.4 -3.090  0.0109 
#  Fencing Dry - Mowing Amb    -4.972 0.937 10.4 -5.307  0.0003 
#  Fencing Dry - Fencing Wet   -6.259 0.756 12.0 -8.283  <.0001 
#  Fencing Dry - Grazing Wet   -7.051 0.937 10.4 -7.526  <.0001 
#  Fencing Dry - Mowing Wet    -7.191 0.937 10.4 -7.675  <.0001 
#  Grazing Dry - Mowing Dry    -1.305 0.937 10.4 -1.393  0.1927 
#  Grazing Dry - Fencing Amb   -0.728 0.937 10.4 -0.777  0.4545 
#  Grazing Dry - Grazing Amb   -1.473 0.756 12.0 -1.950  0.0749 
#  Grazing Dry - Mowing Amb    -3.550 0.937 10.4 -3.789  0.0033 
#  Grazing Dry - Fencing Wet   -4.837 0.937 10.4 -5.162  0.0004 
#  Grazing Dry - Grazing Wet   -5.629 0.756 12.0 -7.450  <.0001 
#  Grazing Dry - Mowing Wet    -5.769 0.937 10.4 -6.157  0.0001 
#  Mowing Dry - Fencing Amb     0.577 0.937 10.4  0.616  0.5513 
#  Mowing Dry - Grazing Amb    -0.169 0.937 10.4 -0.180  0.8607 
#  Mowing Dry - Mowing Amb     -2.245 0.756 12.0 -2.972  0.0117 
#  Mowing Dry - Fencing Wet    -3.532 0.937 10.4 -3.770  0.0034 
#  Mowing Dry - Grazing Wet    -4.324 0.937 10.4 -4.615  0.0009 
#  Mowing Dry - Mowing Wet     -4.464 0.756 12.0 -5.908  0.0001 
#  Fencing Amb - Grazing Amb   -0.745 0.937 10.4 -0.796  0.4440 
#  Fencing Amb - Mowing Amb    -2.822 0.937 10.4 -3.012  0.0125 
#  Fencing Amb - Fencing Wet   -4.109 0.756 12.0 -5.438  0.0002 
#  Fencing Amb - Grazing Wet   -4.901 0.937 10.4 -5.231  0.0003 
#  Fencing Amb - Mowing Wet    -5.041 0.937 10.4 -5.381  0.0003 
#  Grazing Amb - Mowing Amb    -2.077 0.937 10.4 -2.217  0.0499 
#  Grazing Amb - Fencing Wet   -3.363 0.937 10.4 -3.590  0.0046 
#  Grazing Amb - Grazing Wet   -4.155 0.756 12.0 -5.500  0.0001 
#  Grazing Amb - Mowing Wet    -4.296 0.937 10.4 -4.585  0.0009 
#  Mowing Amb - Fencing Wet    -1.287 0.937 10.4 -1.373  0.1984 
#  Mowing Amb - Grazing Wet    -2.079 0.937 10.4 -2.219  0.0497 
#  Mowing Amb - Mowing Wet     -2.219 0.756 12.0 -2.937  0.0124 
#  Fencing Wet - Grazing Wet   -0.792 0.937 10.4 -0.846  0.4168 
#  Fencing Wet - Mowing Wet    -0.932 0.937 10.4 -0.995  0.3422 
#  Grazing Wet - Mowing Wet    -0.140 0.937 10.4 -0.150  0.8840 
# 
# Results are averaged over the levels of: Date 

tapply(srda$SM[srda$Year==2019], list(srda$Man[srda$Year==2019]), mean)

#   Fencing   Grazing    Mowing 
#  9.133496 10.119993 11.293820 

summary(emmeans(aov_sm_19, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate    SE df t.ratio p.value
#  Fencing - Grazing   -0.986 0.705  4 -1.399  0.2343 
#  Fencing - Mowing    -2.160 0.705  4 -3.064  0.0375 
#  Grazing - Mowing    -1.174 0.705  4 -1.665  0.1713 
# 
# Results are averaged over the levels of: Precip, Date 

tapply(srda$SM[srda$Year==2019], list(srda$Precip[srda$Year==2019]), mean)

#       Dry       Amb       Wet 
#  7.713577  9.669690 13.164042 

summary(emmeans(aov_sm_19, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate    SE df t.ratio p.value
#  Dry - Amb    -1.96 0.436 12  -4.484 0.0007 
#  Dry - Wet    -5.45 0.436 12 -12.495 <.0001 
#  Amb - Wet    -3.49 0.436 12  -8.011 <.0001 
# 
# Results are averaged over the levels of: Man, Date 

# R codes for analyzing the effects of land-use regimes and altered precipitation
# amount on soil moisture during the overall 3 years.
aov_sm_oa = aov(SM~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda))
summary(aov_sm_oa)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  79.29   39.65               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)  
# Man        2 109.13   54.56   10.89 0.0241 *
# Residuals  4  20.04    5.01                 
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2   3511  1755.7  618.82 7.84e-13 ***
# Man:Precip  4    125    31.2   10.99 0.000556 ***
# Residuals  12     34     2.8                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq F value   Pr(>F)    
# Date             33   7835  237.43 113.999  < 2e-16 ***
# Man:Date         66    475    7.20   3.455 7.32e-16 ***
# Precip:Date      66    444    6.73   3.230 3.53e-14 ***
# Man:Precip:Date 132    268    2.03   0.975    0.563    
# Residuals       594   1237    2.08                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda$SM, list(srda$Precip, srda$Man), mean)

#       Fencing   Grazing    Mowing
# Dry  6.349732  7.056901  7.583655
# Amb  8.356322  9.127829  9.520558
# Wet 11.609559 12.473275 11.218806

summary(emmeans(aov_sm_oa, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate    SE   df t.ratio p.value
#  Fencing Dry - Grazing Dry   -0.707 0.264 12.7  -2.676 0.0193 
#  Fencing Dry - Mowing Dry    -1.234 0.264 12.7  -4.670 0.0005 
#  Fencing Dry - Fencing Amb   -2.007 0.236 12.0  -8.507 <.0001 
#  Fencing Dry - Grazing Amb   -2.778 0.264 12.7 -10.513 <.0001 
#  Fencing Dry - Mowing Amb    -3.171 0.264 12.7 -11.999 <.0001 
#  Fencing Dry - Fencing Wet   -5.260 0.236 12.0 -22.300 <.0001 
#  Fencing Dry - Grazing Wet   -6.124 0.264 12.7 -23.173 <.0001 
#  Fencing Dry - Mowing Wet    -4.869 0.264 12.7 -18.426 <.0001 
#  Grazing Dry - Mowing Dry    -0.527 0.264 12.7  -1.993 0.0681 
#  Grazing Dry - Fencing Amb   -1.299 0.264 12.7  -4.917 0.0003 
#  Grazing Dry - Grazing Amb   -2.071 0.236 12.0  -8.780 <.0001 
#  Grazing Dry - Mowing Amb    -2.464 0.264 12.7  -9.323 <.0001 
#  Grazing Dry - Fencing Wet   -4.553 0.264 12.7 -17.229 <.0001 
#  Grazing Dry - Grazing Wet   -5.416 0.236 12.0 -22.964 <.0001 
#  Grazing Dry - Mowing Wet    -4.162 0.264 12.7 -15.750 <.0001 
#  Mowing Dry - Fencing Amb    -0.773 0.264 12.7  -2.924 0.0121 
#  Mowing Dry - Grazing Amb    -1.544 0.264 12.7  -5.844 0.0001 
#  Mowing Dry - Mowing Amb     -1.937 0.236 12.0  -8.212 <.0001 
#  Mowing Dry - Fencing Wet    -4.026 0.264 12.7 -15.235 <.0001 
#  Mowing Dry - Grazing Wet    -4.890 0.264 12.7 -18.504 <.0001 
#  Mowing Dry - Mowing Wet     -3.635 0.236 12.0 -15.412 <.0001 
#  Fencing Amb - Grazing Amb   -0.772 0.264 12.7  -2.920 0.0122 
#  Fencing Amb - Mowing Amb    -1.164 0.264 12.7  -4.406 0.0007 
#  Fencing Amb - Fencing Wet   -3.253 0.236 12.0 -13.793 <.0001 
#  Fencing Amb - Grazing Wet   -4.117 0.264 12.7 -15.580 <.0001 
#  Fencing Amb - Mowing Wet    -2.862 0.264 12.7 -10.833 <.0001 
#  Grazing Amb - Mowing Amb    -0.393 0.264 12.7  -1.486 0.1615 
#  Grazing Amb - Fencing Wet   -2.482 0.264 12.7  -9.392 <.0001 
#  Grazing Amb - Grazing Wet   -3.345 0.236 12.0 -14.184 <.0001 
#  Grazing Amb - Mowing Wet    -2.091 0.264 12.7  -7.913 <.0001 
#  Mowing Amb - Fencing Wet    -2.089 0.264 12.7  -7.905 <.0001 
#  Mowing Amb - Grazing Wet    -2.953 0.264 12.7 -11.174 <.0001 
#  Mowing Amb - Mowing Wet     -1.698 0.236 12.0  -7.200 <.0001 
#  Fencing Wet - Grazing Wet   -0.864 0.264 12.7  -3.269 0.0063 
#  Fencing Wet - Mowing Wet     0.391 0.264 12.7   1.479 0.1635 
#  Grazing Wet - Mowing Wet     1.254 0.264 12.7   4.747 0.0004 
# 
# Results are averaged over the levels of: Date 

tapply(srda$SM, list(srda$Man), mean)

#  Fencing  Grazing   Mowing 
# 8.771871 9.552668 9.441006 

summary(emmeans(aov_sm_oa, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate    SE df t.ratio p.value
#  Fencing - Grazing   -0.781 0.181  4 -4.315  0.0125 
#  Fencing - Mowing    -0.669 0.181  4 -3.698  0.0209 
#  Grazing - Mowing     0.112 0.181  4  0.617  0.5706 
# 
# Results are averaged over the levels of: Precip, Date 

tapply(srda$SM, list(srda$Precip), mean)

#       Dry       Amb       Wet 
#  6.996763  9.001569 11.767213 

summary(emmeans(aov_sm_oa, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate    SE df t.ratio p.value
#  Dry - Amb    -2.00 0.136 12 -14.722 <.0001 
#  Dry - Wet    -4.77 0.136 12 -35.032 <.0001 
#  Amb - Wet    -2.77 0.136 12 -20.310 <.0001 
# 
# Results are averaged over the levels of: Man, Date 

######################################################################################
# The following codes and results were used to analyze the effects of land-use regimes
# and altered precipitation amount on aboveground net primary productivity in 2017, 
# 2018, 2019 and during the overall 3 years of our experiment.########################

# R codes for analyzing the effects of land-use regimes and altered precipitation 
# amount on aboveground net primary productivity in 2017.
aov_anpp_17 = aov(ANPP~Man*Precip+Error(Block/Man/Precip), data=subset(srda_ann, Year=="2017"))
summary(aov_anpp_17)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  297.1   148.5               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value  Pr(>F)   
# Man        2 2988.0  1494.0   26.06 0.00508 **
# Residuals  4  229.3    57.3                   
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2  25256   12628  77.102 1.42e-07 ***
# Man:Precip  4    304      76   0.464    0.761    
# Residuals  12   1965     164                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$ANPP[srda_ann$Year==2017], list(srda_ann$Precip[srda_ann$Year==2017], srda_ann$Man[srda_ann$Year==2017]), mean)

#       Fencing   Grazing   Mowing
# Dry  30.87333  38.56333 24.01667
# Amb  77.40333  99.31000 66.94333
# Wet 101.92333 120.47667 90.94000

summary(emmeans(aov_anpp_17, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate    SE   df t.ratio p.value
#  Fencing Dry - Grazing Dry    -7.69  9.25 15.2  -0.831 0.4186 
#  Fencing Dry - Mowing Dry      6.86  9.25 15.2   0.741 0.4698 
#  Fencing Dry - Fencing Amb   -46.53 10.45 12.0  -4.453 0.0008 
#  Fencing Dry - Grazing Amb   -68.44  9.25 15.2  -7.400 <.0001 
#  Fencing Dry - Mowing Amb    -36.07  9.25 15.2  -3.900 0.0014 
#  Fencing Dry - Fencing Wet   -71.05 10.45 12.0  -6.800 <.0001 
#  Fencing Dry - Grazing Wet   -89.60  9.25 15.2  -9.689 <.0001 
#  Fencing Dry - Mowing Wet    -60.07  9.25 15.2  -6.495 <.0001 
#  Grazing Dry - Mowing Dry     14.55  9.25 15.2   1.573 0.1364 
#  Grazing Dry - Fencing Amb   -38.84  9.25 15.2  -4.200 0.0008 
#  Grazing Dry - Grazing Amb   -60.75 10.45 12.0  -5.813 0.0001 
#  Grazing Dry - Mowing Amb    -28.38  9.25 15.2  -3.069 0.0077 
#  Grazing Dry - Fencing Wet   -63.36  9.25 15.2  -6.851 <.0001 
#  Grazing Dry - Grazing Wet   -81.91 10.45 12.0  -7.839 <.0001 
#  Grazing Dry - Mowing Wet    -52.38  9.25 15.2  -5.663 <.0001 
#  Mowing Dry - Fencing Amb    -53.39  9.25 15.2  -5.773 <.0001 
#  Mowing Dry - Grazing Amb    -75.29  9.25 15.2  -8.141 <.0001 
#  Mowing Dry - Mowing Amb     -42.93 10.45 12.0  -4.108 0.0015 
#  Mowing Dry - Fencing Wet    -77.91  9.25 15.2  -8.424 <.0001 
#  Mowing Dry - Grazing Wet    -96.46  9.25 15.2 -10.430 <.0001 
#  Mowing Dry - Mowing Wet     -66.92 10.45 12.0  -6.405 <.0001 
#  Fencing Amb - Grazing Amb   -21.91  9.25 15.2  -2.369 0.0315 
#  Fencing Amb - Mowing Amb     10.46  9.25 15.2   1.131 0.2756 
#  Fencing Amb - Fencing Wet   -24.52 10.45 12.0  -2.347 0.0369 
#  Fencing Amb - Grazing Wet   -43.07  9.25 15.2  -4.657 0.0003 
#  Fencing Amb - Mowing Wet    -13.54  9.25 15.2  -1.464 0.1637 
#  Grazing Amb - Mowing Amb     32.37  9.25 15.2   3.500 0.0032 
#  Grazing Amb - Fencing Wet    -2.61  9.25 15.2  -0.283 0.7813 
#  Grazing Amb - Grazing Wet   -21.17 10.45 12.0  -2.026 0.0656 
#  Grazing Amb - Mowing Wet      8.37  9.25 15.2   0.905 0.3796 
#  Mowing Amb - Fencing Wet    -34.98  9.25 15.2  -3.782 0.0018 
#  Mowing Amb - Grazing Wet    -53.53  9.25 15.2  -5.788 <.0001 
#  Mowing Amb - Mowing Wet     -24.00 10.45 12.0  -2.296 0.0405 
#  Fencing Wet - Grazing Wet   -18.55  9.25 15.2  -2.006 0.0630 
#  Fencing Wet - Mowing Wet     10.98  9.25 15.2   1.188 0.2533 
#  Grazing Wet - Mowing Wet     29.54  9.25 15.2   3.194 0.0060 

tapply(srda_ann$ANPP[srda_ann$Year==2017], list(srda_ann$Man[srda_ann$Year==2017]), mean)

#  Fencing  Grazing   Mowing 
# 70.06667 86.11667 60.63333 

summary(emmeans(aov_anpp_17, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate   SE df t.ratio p.value
#  Fencing - Grazing   -16.05 3.57  4 -4.496  0.0109 
#  Fencing - Mowing      9.43 3.57  4  2.643  0.0574 
#  Grazing - Mowing     25.48 3.57  4  7.139  0.0020 
# 
# Results are averaged over the levels of: Precip 

tapply(srda_ann$ANPP[srda_ann$Year==2017], list(srda_ann$Precip[srda_ann$Year==2017]), mean)

#       Dry       Amb       Wet 
#  31.15111  81.21889 104.44667 

summary(emmeans(aov_anpp_17, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate   SE df t.ratio p.value
#  Dry - Amb    -50.1 6.03 12  -8.299 <.0001 
#  Dry - Wet    -73.3 6.03 12 -12.149 <.0001 
#  Amb - Wet    -23.2 6.03 12  -3.850 0.0023 
# 
# Results are averaged over the levels of: Man 

# R codes for analyzing the effects of land-use regimes and altered
# precipitation amount on aboveground net primary productivity in 2018.
aov_anpp_18 = aov(ANPP~Man*Precip+Error(Block/Man/Precip), data=subset(srda_ann, Year=="2018"))
summary(aov_anpp_18)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  43.52   21.76               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)
# Man        2  632.4   316.2   0.414  0.687
# Residuals  4 3056.4   764.1               
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2  55210   27605 125.114 9.18e-09 ***
# Man:Precip  4   2663     666   3.017   0.0616 .  
# Residuals  12   2648     221                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$ANPP[srda_ann$Year==2018], list(srda_ann$Precip[srda_ann$Year==2018], srda_ann$Man[srda_ann$Year==2018]), mean)

#      Fencing    Grazing    Mowing
# Dry  19.2300   7.643333  16.19667
# Amb  65.6700  78.700000  91.94667
# Wet 112.9867 145.876667 114.94000

summary(emmeans(aov_anpp_18, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate   SE    df t.ratio p.value
#  Fencing Dry - Grazing Dry    11.59 16.4  8.96   0.708 0.4970 
#  Fencing Dry - Mowing Dry      3.03 16.4  8.96   0.185 0.8571 
#  Fencing Dry - Fencing Amb   -46.44 12.1 12.00  -3.829 0.0024 
#  Fencing Dry - Grazing Amb   -59.47 16.4  8.96  -3.634 0.0055 
#  Fencing Dry - Mowing Amb    -72.72 16.4  8.96  -4.443 0.0016 
#  Fencing Dry - Fencing Wet   -93.76 12.1 12.00  -7.730 <.0001 
#  Fencing Dry - Grazing Wet  -126.65 16.4  8.96  -7.738 <.0001 
#  Fencing Dry - Mowing Wet    -95.71 16.4  8.96  -5.848 0.0002 
#  Grazing Dry - Mowing Dry     -8.55 16.4  8.96  -0.523 0.6139 
#  Grazing Dry - Fencing Amb   -58.03 16.4  8.96  -3.545 0.0063 
#  Grazing Dry - Grazing Amb   -71.06 12.1 12.00  -5.859 0.0001 
#  Grazing Dry - Mowing Amb    -84.30 16.4  8.96  -5.151 0.0006 
#  Grazing Dry - Fencing Wet  -105.34 16.4  8.96  -6.437 0.0001 
#  Grazing Dry - Grazing Wet  -138.23 12.1 12.00 -11.398 <.0001 
#  Grazing Dry - Mowing Wet   -107.30 16.4  8.96  -6.556 0.0001 
#  Mowing Dry - Fencing Amb    -49.47 16.4  8.96  -3.023 0.0145 
#  Mowing Dry - Grazing Amb    -62.50 16.4  8.96  -3.819 0.0041 
#  Mowing Dry - Mowing Amb     -75.75 12.1 12.00  -6.246 <.0001 
#  Mowing Dry - Fencing Wet    -96.79 16.4  8.96  -5.914 0.0002 
#  Mowing Dry - Grazing Wet   -129.68 16.4  8.96  -7.924 <.0001 
#  Mowing Dry - Mowing Wet     -98.74 12.1 12.00  -8.142 <.0001 
#  Fencing Amb - Grazing Amb   -13.03 16.4  8.96  -0.796 0.4465 
#  Fencing Amb - Mowing Amb    -26.28 16.4  8.96  -1.606 0.1430 
#  Fencing Amb - Fencing Wet   -47.32 12.1 12.00  -3.901 0.0021 
#  Fencing Amb - Grazing Wet   -80.21 16.4  8.96  -4.901 0.0009 
#  Fencing Amb - Mowing Wet    -49.27 16.4  8.96  -3.010 0.0148 
#  Grazing Amb - Mowing Amb    -13.25 16.4  8.96  -0.809 0.4393 
#  Grazing Amb - Fencing Wet   -34.29 16.4  8.96  -2.095 0.0658 
#  Grazing Amb - Grazing Wet   -67.18 12.1 12.00  -5.539 0.0001 
#  Grazing Amb - Mowing Wet    -36.24 16.4  8.96  -2.214 0.0542 
#  Mowing Amb - Fencing Wet    -21.04 16.4  8.96  -1.286 0.2308 
#  Mowing Amb - Grazing Wet    -53.93 16.4  8.96  -3.295 0.0094 
#  Mowing Amb - Mowing Wet     -22.99 12.1 12.00  -1.896 0.0823 
#  Fencing Wet - Grazing Wet   -32.89 16.4  8.96  -2.010 0.0755 
#  Fencing Wet - Mowing Wet     -1.95 16.4  8.96  -0.119 0.9076 
#  Grazing Wet - Mowing Wet     30.94 16.4  8.96   1.890 0.0915 

tapply(srda_ann$ANPP[srda_ann$Year==2018], list(srda_ann$Man[srda_ann$Year==2018]), mean)

#  Fencing  Grazing   Mowing 
# 65.96222 77.40667 74.36111 

summary(emmeans(aov_anpp_18, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate SE df t.ratio p.value
#  Fencing - Grazing   -11.44 13  4 -0.878  0.4294 
#  Fencing - Mowing     -8.40 13  4 -0.645  0.5543 
#  Grazing - Mowing      3.05 13  4  0.234  0.8267 
# 
# Results are averaged over the levels of: Precip 

tapply(srda_ann$ANPP[srda_ann$Year==2018], list(srda_ann$Precip[srda_ann$Year==2018]), mean)

#       Dry       Amb       Wet 
#  14.35667  78.77222 124.60111 

summary(emmeans(aov_anpp_18, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate SE df t.ratio p.value
#  Dry - Amb    -64.4  7 12  -9.199 <.0001 
#  Dry - Wet   -110.2  7 12 -15.744 <.0001 
#  Amb - Wet    -45.8  7 12  -6.545 <.0001 
# 
# Results are averaged over the levels of: Man 

# R codes for analyzing the effects of land-use regimes and altered
# precipitation amount on aboveground net primary productivity in 2019.
aov_anpp_19 = aov(ANPP~Man*Precip+Error(Block/Man/Precip), data=subset(srda_ann, Year=="2019"))
summary(aov_anpp_19)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  655.3   327.7               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value  Pr(>F)   
# Man        2 2654.7  1327.4   20.62 0.00782 **
# Residuals  4  257.5    64.4                   
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2  39818   19909  67.167 3.04e-07 ***
# Man:Precip  4   1030     257   0.868    0.511    
# Residuals  12   3557     296                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$ANPP[srda_ann$Year==2019], list(srda_ann$Precip[srda_ann$Year==2019], srda_ann$Man[srda_ann$Year==2019]), mean)

#       Fencing  Grazing   Mowing
# Dry  20.49667  21.5800 12.89000
# Amb  91.46333  62.2100 60.90333
# Wet 128.66000 113.1833 94.47333

summary(emmeans(aov_anpp_19, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate   SE   df t.ratio p.value
#  Fencing Dry - Grazing Dry    -1.08 12.1 14.2 -0.090  0.9298 
#  Fencing Dry - Mowing Dry      7.61 12.1 14.2  0.629  0.5390 
#  Fencing Dry - Fencing Amb   -70.97 14.1 12.0 -5.048  0.0003 
#  Fencing Dry - Grazing Amb   -41.71 12.1 14.2 -3.452  0.0038 
#  Fencing Dry - Mowing Amb    -40.41 12.1 14.2 -3.344  0.0047 
#  Fencing Dry - Fencing Wet  -108.16 14.1 12.0 -7.694  <.0001 
#  Fencing Dry - Grazing Wet   -92.69 12.1 14.2 -7.670  <.0001 
#  Fencing Dry - Mowing Wet    -73.98 12.1 14.2 -6.121  <.0001 
#  Grazing Dry - Mowing Dry      8.69 12.1 14.2  0.719  0.4837 
#  Grazing Dry - Fencing Amb   -69.88 12.1 14.2 -5.783  <.0001 
#  Grazing Dry - Grazing Amb   -40.63 14.1 12.0 -2.890  0.0136 
#  Grazing Dry - Mowing Amb    -39.32 12.1 14.2 -3.254  0.0057 
#  Grazing Dry - Fencing Wet  -107.08 12.1 14.2 -8.861  <.0001 
#  Grazing Dry - Grazing Wet   -91.60 14.1 12.0 -6.516  <.0001 
#  Grazing Dry - Mowing Wet    -72.89 12.1 14.2 -6.032  <.0001 
#  Mowing Dry - Fencing Amb    -78.57 12.1 14.2 -6.502  <.0001 
#  Mowing Dry - Grazing Amb    -49.32 12.1 14.2 -4.081  0.0011 
#  Mowing Dry - Mowing Amb     -48.01 14.1 12.0 -3.416  0.0051 
#  Mowing Dry - Fencing Wet   -115.77 12.1 14.2 -9.580  <.0001 
#  Mowing Dry - Grazing Wet   -100.29 12.1 14.2 -8.299  <.0001 
#  Mowing Dry - Mowing Wet     -81.58 14.1 12.0 -5.804  0.0001 
#  Fencing Amb - Grazing Amb    29.25 12.1 14.2  2.421  0.0294 
#  Fencing Amb - Mowing Amb     30.56 12.1 14.2  2.529  0.0238 
#  Fencing Amb - Fencing Wet   -37.20 14.1 12.0 -2.646  0.0213 
#  Fencing Amb - Grazing Wet   -21.72 12.1 14.2 -1.797  0.0935 
#  Fencing Amb - Mowing Wet     -3.01 12.1 14.2 -0.249  0.8069 
#  Grazing Amb - Mowing Amb      1.31 12.1 14.2  0.108  0.9154 
#  Grazing Amb - Fencing Wet   -66.45 12.1 14.2 -5.499  0.0001 
#  Grazing Amb - Grazing Wet   -50.97 14.1 12.0 -3.626  0.0035 
#  Grazing Amb - Mowing Wet    -32.26 12.1 14.2 -2.670  0.0181 
#  Mowing Amb - Fencing Wet    -67.76 12.1 14.2 -5.607  0.0001 
#  Mowing Amb - Grazing Wet    -52.28 12.1 14.2 -4.326  0.0007 
#  Mowing Amb - Mowing Wet     -33.57 14.1 12.0 -2.388  0.0343 
#  Fencing Wet - Grazing Wet    15.48 12.1 14.2  1.281  0.2208 
#  Fencing Wet - Mowing Wet     34.19 12.1 14.2  2.829  0.0132 
#  Grazing Wet - Mowing Wet     18.71 12.1 14.2  1.548  0.1435 

tapply(srda_ann$ANPP[srda_ann$Year==2019], list(srda_ann$Man[srda_ann$Year==2019]), mean)

#  Fencing  Grazing   Mowing 
# 80.20667 65.65778 56.08889 

summary(emmeans(aov_anpp_19, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate   SE df t.ratio p.value
#  Fencing - Grazing    14.55 3.78  4 3.847   0.0184 
#  Fencing - Mowing     24.12 3.78  4 6.377   0.0031 
#  Grazing - Mowing      9.57 3.78  4 2.530   0.0647 
# 
# Results are averaged over the levels of: Precip 

tapply(srda_ann$ANPP[srda_ann$Year==2019], list(srda_ann$Precip[srda_ann$Year==2019]), mean)

#       Dry       Amb       Wet 
#  18.32222  71.52556 112.10556 

summary(emmeans(aov_anpp_19, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate   SE df t.ratio p.value
#  Dry - Amb    -53.2 8.12 12  -6.555 <.0001 
#  Dry - Wet    -93.8 8.12 12 -11.555 <.0001 
#  Amb - Wet    -40.6 8.12 12  -5.000 0.0003 
# 
# Results are averaged over the levels of: Man 

# R codes for analyzing the effects of land-use regimes and altered
# precipitation amount on aboveground net primary productivity during the overall 3
# years.
aov_anpp_oa = aov(ANPP~Year*Man*Precip+Error(Block/Man/Precip), data=subset(srda_ann))
summary(aov_anpp_oa)

# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  676.2   338.1               
# 
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)
# Man        2   2252  1125.8   3.933  0.114
# Residuals  4   1145   286.3               
# 
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2 117047   58524 379.714 1.42e-11 ***
# Man:Precip  4   1291     323   2.094    0.145    
# Residuals  12   1850     154                     
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Error: Within
#                 Df Sum Sq Mean Sq F value  Pr(>F)   
# Year             2    471   235.3   0.937 0.40102   
# Year:Man         4   4023  1005.8   4.006 0.00866 **
# Year:Precip      4   3237   809.2   3.223 0.02325 * 
# Year:Man:Precip  8   2705   338.1   1.347 0.25280   
# Residuals       36   9038   251.1                   
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

tapply(srda_ann$ANPP, list(srda_ann$Precip, srda_ann$Man), mean)

#       Fencing   Grazing    Mowing
# Dry  23.53333  22.59556  17.70111
# Amb  78.17889  80.07333  73.26444
# Wet 114.52333 126.51222 100.11778

summary(emmeans(aov_anpp_oa, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate   SE   df t.ratio p.value
#  Fencing Dry - Grazing Dry    0.938 6.64 12.4   0.141 0.8899 
#  Fencing Dry - Mowing Dry     5.832 6.64 12.4   0.879 0.3961 
#  Fencing Dry - Fencing Amb  -54.646 5.85 12.0  -9.337 <.0001 
#  Fencing Dry - Grazing Amb  -56.540 6.64 12.4  -8.520 <.0001 
#  Fencing Dry - Mowing Amb   -49.731 6.64 12.4  -7.494 <.0001 
#  Fencing Dry - Fencing Wet  -90.990 5.85 12.0 -15.548 <.0001 
#  Fencing Dry - Grazing Wet -102.979 6.64 12.4 -15.518 <.0001 
#  Fencing Dry - Mowing Wet   -76.584 6.64 12.4 -11.540 <.0001 
#  Grazing Dry - Mowing Dry     4.894 6.64 12.4   0.738 0.4745 
#  Grazing Dry - Fencing Amb  -55.583 6.64 12.4  -8.376 <.0001 
#  Grazing Dry - Grazing Amb  -57.478 5.85 12.0  -9.821 <.0001 
#  Grazing Dry - Mowing Amb   -50.669 6.64 12.4  -7.635 <.0001 
#  Grazing Dry - Fencing Wet  -91.928 6.64 12.4 -13.852 <.0001 
#  Grazing Dry - Grazing Wet -103.917 5.85 12.0 -17.756 <.0001 
#  Grazing Dry - Mowing Wet   -77.522 6.64 12.4 -11.682 <.0001 
#  Mowing Dry - Fencing Amb   -60.478 6.64 12.4  -9.113 <.0001 
#  Mowing Dry - Grazing Amb   -62.372 6.64 12.4  -9.399 <.0001 
#  Mowing Dry - Mowing Amb    -55.563 5.85 12.0  -9.494 <.0001 
#  Mowing Dry - Fencing Wet   -96.822 6.64 12.4 -14.590 <.0001 
#  Mowing Dry - Grazing Wet  -108.811 6.64 12.4 -16.397 <.0001 
#  Mowing Dry - Mowing Wet    -82.417 5.85 12.0 -14.083 <.0001 
#  Fencing Amb - Grazing Amb   -1.894 6.64 12.4  -0.285 0.7800 
#  Fencing Amb - Mowing Amb     4.914 6.64 12.4   0.741 0.4727 
#  Fencing Amb - Fencing Wet  -36.344 5.85 12.0  -6.210 <.0001 
#  Fencing Amb - Grazing Wet  -48.333 6.64 12.4  -7.283 <.0001 
#  Fencing Amb - Mowing Wet   -21.939 6.64 12.4  -3.306 0.0060 
#  Grazing Amb - Mowing Amb     6.809 6.64 12.4   1.026 0.3244 
#  Grazing Amb - Fencing Wet  -34.450 6.64 12.4  -5.191 0.0002 
#  Grazing Amb - Grazing Wet  -46.439 5.85 12.0  -7.935 <.0001 
#  Grazing Amb - Mowing Wet   -20.044 6.64 12.4  -3.020 0.0103 
#  Mowing Amb - Fencing Wet   -41.259 6.64 12.4  -6.217 <.0001 
#  Mowing Amb - Grazing Wet   -53.248 6.64 12.4  -8.024 <.0001 
#  Mowing Amb - Mowing Wet    -26.853 5.85 12.0  -4.588 0.0006 
#  Fencing Wet - Grazing Wet  -11.989 6.64 12.4  -1.807 0.0951 
#  Fencing Wet - Mowing Wet    14.406 6.64 12.4   2.171 0.0500 
#  Grazing Wet - Mowing Wet    26.394 6.64 12.4   3.977 0.0017 
# 
# Results are averaged over the levels of: Year 

tapply(srda_ann$ANPP, list(srda_ann$Man), mean)

#  Fencing  Grazing   Mowing 
# 72.07852 76.39370 63.69444 

summary(emmeans(aov_anpp_oa, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate  SE df t.ratio p.value
#  Fencing - Grazing    -4.32 4.6  4 -0.937  0.4018 
#  Fencing - Mowing      8.38 4.6  4  1.821  0.1428 
#  Grazing - Mowing     12.70 4.6  4  2.758  0.0510 
# 
# Results are averaged over the levels of: Year, Precip

tapply(srda_ann$ANPP, list(srda_ann$Precip), mean)

#       Dry       Amb       Wet 
#  21.27667  77.17222 113.71778 

summary(emmeans(aov_anpp_oa, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate   SE df t.ratio p.value
#  Dry - Amb    -55.9 3.38 12 -16.543 <.0001 
#  Dry - Wet    -92.4 3.38 12 -27.359 <.0001 
#  Amb - Wet    -36.5 3.38 12 -10.816 <.0001 
# 
# Results are averaged over the levels of: Year, Man 

######################################################################################
# The following codes and results were used to analyze the effects of land-use regimes
# and altered precipitation amount on belowground net primary productivity in 2018, 
# 2019 and during the overall 2 years of our experiment.##############################

# R codes for analyzing the effects of land-use regimes and altered precipitation 
# amount on belowground net primary productivity in 2018.
aov_bnpp_18 = aov(BNPP~Man*Precip+Error(Block/Man/Precip), data=subset(srda_ann, Year=="2018"))
summary(aov_bnpp_18)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  185.4   92.69               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)  
# Man        2   2401  1200.5   14.87 0.0141 *
# Residuals  4    323    80.7                 
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2 2903.8  1451.9  65.105 3.61e-07 ***
# Man:Precip  4   50.5    12.6   0.566    0.692    
# Residuals  12  267.6    22.3                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$BNPP[srda_ann$Year==2018], list(srda_ann$Precip[srda_ann$Year==2018], srda_ann$Man[srda_ann$Year==2018]), mean)

#     Fencing  Grazing   Mowing
# Dry   65.12 50.46333 70.74000
# Amb   77.81 61.58667 85.35333
# Wet   94.17 73.30667 95.05333

summary(emmeans(aov_bnpp_18, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate   SE    df t.ratio p.value
#  Fencing Dry - Grazing Dry   14.657 5.28  8.75  2.777  0.0221 
#  Fencing Dry - Mowing Dry    -5.620 5.28  8.75 -1.065  0.3154 
#  Fencing Dry - Fencing Amb  -12.690 3.86 12.00 -3.291  0.0064 
#  Fencing Dry - Grazing Amb    3.533 5.28  8.75  0.669  0.5205 
#  Fencing Dry - Mowing Amb   -20.233 5.28  8.75 -3.834  0.0042 
#  Fencing Dry - Fencing Wet  -29.050 3.86 12.00 -7.534  <.0001 
#  Fencing Dry - Grazing Wet   -8.187 5.28  8.75 -1.551  0.1562 
#  Fencing Dry - Mowing Wet   -29.933 5.28  8.75 -5.672  0.0003 
#  Grazing Dry - Mowing Dry   -20.277 5.28  8.75 -3.842  0.0042 
#  Grazing Dry - Fencing Amb  -27.347 5.28  8.75 -5.182  0.0006 
#  Grazing Dry - Grazing Amb  -11.123 3.86 12.00 -2.885  0.0137 
#  Grazing Dry - Mowing Amb   -34.890 5.28  8.75 -6.611  0.0001 
#  Grazing Dry - Fencing Wet  -43.707 5.28  8.75 -8.282  <.0001 
#  Grazing Dry - Grazing Wet  -22.843 3.86 12.00 -5.924  0.0001 
#  Grazing Dry - Mowing Wet   -44.590 5.28  8.75 -8.449  <.0001 
#  Mowing Dry - Fencing Amb    -7.070 5.28  8.75 -1.340  0.2141 
#  Mowing Dry - Grazing Amb     9.153 5.28  8.75  1.734  0.1178 
#  Mowing Dry - Mowing Amb    -14.613 3.86 12.00 -3.790  0.0026 
#  Mowing Dry - Fencing Wet   -23.430 5.28  8.75 -4.440  0.0017 
#  Mowing Dry - Grazing Wet    -2.567 5.28  8.75 -0.486  0.6387 
#  Mowing Dry - Mowing Wet    -24.313 3.86 12.00 -6.306  <.0001 
#  Fencing Amb - Grazing Amb   16.223 5.28  8.75  3.074  0.0137 
#  Fencing Amb - Mowing Amb    -7.543 5.28  8.75 -1.429  0.1876 
#  Fencing Amb - Fencing Wet  -16.360 3.86 12.00 -4.243  0.0011 
#  Fencing Amb - Grazing Wet    4.503 5.28  8.75  0.853  0.4162 
#  Fencing Amb - Mowing Wet   -17.243 5.28  8.75 -3.267  0.0101 
#  Grazing Amb - Mowing Amb   -23.767 5.28  8.75 -4.503  0.0016 
#  Grazing Amb - Fencing Wet  -32.583 5.28  8.75 -6.174  0.0002 
#  Grazing Amb - Grazing Wet  -11.720 3.86 12.00 -3.040  0.0103 
#  Grazing Amb - Mowing Wet   -33.467 5.28  8.75 -6.341  0.0002 
#  Mowing Amb - Fencing Wet    -8.817 5.28  8.75 -1.671  0.1301 
#  Mowing Amb - Grazing Wet    12.047 5.28  8.75  2.283  0.0492 
#  Mowing Amb - Mowing Wet     -9.700 3.86 12.00 -2.516  0.0271 
#  Fencing Wet - Grazing Wet   20.863 5.28  8.75  3.953  0.0035 
#  Fencing Wet - Mowing Wet    -0.883 5.28  8.75 -0.167  0.8709 
#  Grazing Wet - Mowing Wet   -21.747 5.28  8.75 -4.121  0.0028 

tapply(srda_ann$BNPP[srda_ann$Year==2018], list(srda_ann$Man[srda_ann$Year==2018]), mean)

#  Fencing  Grazing   Mowing 
# 79.03333 61.78556 83.71556 

summary(emmeans(aov_bnpp_18, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate   SE df t.ratio p.value
#  Fencing - Grazing    17.25 4.24  4  4.072  0.0152 
#  Fencing - Mowing     -4.68 4.24  4 -1.105  0.3310 
#  Grazing - Mowing    -21.93 4.24  4 -5.177  0.0066 
# 
# Results are averaged over the levels of: Precip 

tapply(srda_ann$BNPP[srda_ann$Year==2018], list(srda_ann$Precip[srda_ann$Year==2018]), mean)

#      Dry      Amb      Wet 
# 62.10778 74.91667 87.51000 

summary(emmeans(aov_bnpp_18, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate   SE df t.ratio p.value
#  Dry - Amb    -12.8 2.23 12  -5.754 0.0001 
#  Dry - Wet    -25.4 2.23 12 -11.411 <.0001 
#  Amb - Wet    -12.6 2.23 12  -5.657 0.0001 
# 
# Results are averaged over the levels of: Man 

# R codes for analyzing the effects of land-use regimes and altered precipitation
# amount on belowground net primary productivity in 2019.
aov_bnpp_19 = aov(BNPP~Man*Precip+Error(Block/Man/Precip), data=subset(srda_ann, Year=="2019"))
summary(aov_bnpp_19)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  26.66   13.33               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)  
# Man        2 192.04   96.02   16.13 0.0122 *
# Residuals  4  23.81    5.95                 
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2 2414.6  1207.3 158.814 2.33e-09 ***
# Man:Precip  4   29.1     7.3   0.956    0.466    
# Residuals  12   91.2     7.6                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$BNPP[srda_ann$Year==2019], list(srda_ann$Precip[srda_ann$Year==2019], srda_ann$Man[srda_ann$Year==2019]), mean)

#      Fencing  Grazing Mowing
# Dry 75.57333 73.21000  65.99
# Amb 86.74000 85.10667  81.75
# Wet 97.06000 94.65000  92.39

summary(emmeans(aov_bnpp_19, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate   SE   df t.ratio p.value
#  Fencing Dry - Grazing Dry     2.36 2.17 15.9   1.090 0.2920 
#  Fencing Dry - Mowing Dry      9.58 2.17 15.9   4.420 0.0004 
#  Fencing Dry - Fencing Amb   -11.17 2.25 12.0  -4.960 0.0003 
#  Fencing Dry - Grazing Amb    -9.53 2.17 15.9  -4.397 0.0005 
#  Fencing Dry - Mowing Amb     -6.18 2.17 15.9  -2.849 0.0117 
#  Fencing Dry - Fencing Wet   -21.49 2.25 12.0  -9.544 <.0001 
#  Fencing Dry - Grazing Wet   -19.08 2.17 15.9  -8.798 <.0001 
#  Fencing Dry - Mowing Wet    -16.82 2.17 15.9  -7.756 <.0001 
#  Grazing Dry - Mowing Dry      7.22 2.17 15.9   3.330 0.0043 
#  Grazing Dry - Fencing Amb   -13.53 2.17 15.9  -6.240 <.0001 
#  Grazing Dry - Grazing Amb   -11.90 2.25 12.0  -5.285 0.0002 
#  Grazing Dry - Mowing Amb     -8.54 2.17 15.9  -3.939 0.0012 
#  Grazing Dry - Fencing Wet   -23.85 2.17 15.9 -11.000 <.0001 
#  Grazing Dry - Grazing Wet   -21.44 2.25 12.0  -9.524 <.0001 
#  Grazing Dry - Mowing Wet    -19.18 2.17 15.9  -8.846 <.0001 
#  Mowing Dry - Fencing Amb    -20.75 2.17 15.9  -9.570 <.0001 
#  Mowing Dry - Grazing Amb    -19.12 2.17 15.9  -8.817 <.0001 
#  Mowing Dry - Mowing Amb     -15.76 2.25 12.0  -7.001 <.0001 
#  Mowing Dry - Fencing Wet    -31.07 2.17 15.9 -14.329 <.0001 
#  Mowing Dry - Grazing Wet    -28.66 2.17 15.9 -13.218 <.0001 
#  Mowing Dry - Mowing Wet     -26.40 2.25 12.0 -11.727 <.0001 
#  Fencing Amb - Grazing Amb     1.63 2.17 15.9   0.753 0.4623 
#  Fencing Amb - Mowing Amb      4.99 2.17 15.9   2.301 0.0352 
#  Fencing Amb - Fencing Wet   -10.32 2.25 12.0  -4.584 0.0006 
#  Fencing Amb - Grazing Wet    -7.91 2.17 15.9  -3.648 0.0022 
#  Fencing Amb - Mowing Wet     -5.65 2.17 15.9  -2.606 0.0192 
#  Grazing Amb - Mowing Amb      3.36 2.17 15.9   1.548 0.1413 
#  Grazing Amb - Fencing Wet   -11.95 2.17 15.9  -5.513 <.0001 
#  Grazing Amb - Grazing Wet    -9.54 2.25 12.0  -4.239 0.0011 
#  Grazing Amb - Mowing Wet     -7.28 2.17 15.9  -3.359 0.0040 
#  Mowing Amb - Fencing Wet    -15.31 2.17 15.9  -7.061 <.0001 
#  Mowing Amb - Grazing Wet    -12.90 2.17 15.9  -5.949 <.0001 
#  Mowing Amb - Mowing Wet     -10.64 2.25 12.0  -4.726 0.0005 
#  Fencing Wet - Grazing Wet     2.41 2.17 15.9   1.111 0.2829 
#  Fencing Wet - Mowing Wet      4.67 2.17 15.9   2.154 0.0469 
#  Grazing Wet - Mowing Wet      2.26 2.17 15.9   1.042 0.3128 

tapply(srda_ann$BNPP[srda_ann$Year==2019], list(srda_ann$Man[srda_ann$Year==2019]), mean)

#  Fencing  Grazing   Mowing 
# 86.45778 84.32222 80.04333 

summary(emmeans(aov_bnpp_19, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate   SE df t.ratio p.value
#  Fencing - Grazing     2.14 1.15  4 1.857   0.1369 
#  Fencing - Mowing      6.41 1.15  4 5.577   0.0051 
#  Grazing - Mowing      4.28 1.15  4 3.721   0.0205 
# 
# Results are averaged over the levels of: Precip 

tapply(srda_ann$BNPP[srda_ann$Year==2019], list(srda_ann$Precip[srda_ann$Year==2019]), mean)

#      Dry      Amb      Wet 
# 71.59111 84.53222 94.70000 

summary(emmeans(aov_bnpp_19, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate  SE df t.ratio p.value
#  Dry - Amb    -12.9 1.3 12  -9.957 <.0001 
#  Dry - Wet    -23.1 1.3 12 -17.780 <.0001 
#  Amb - Wet    -10.2 1.3 12  -7.823 <.0001 
# 
# Results are averaged over the levels of: Man 

# R codes for analyzing the effects of land-use regimes and altered precipitation
# amount on belowground net primary productivity during the overall 2 years.
aov_bnpp_oa = aov(BNPP~Year*Man*Precip+Error(Block/Man/Precip), data=subset(srda_ann, Year!="2017"))
summary(aov_bnpp_oa)

# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  42.58   21.29               
# 
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)  
# Man        2 1035.4   517.7   17.71 0.0103 *
# Residuals  4  116.9    29.2                 
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2   5302  2650.8 119.937 1.17e-08 ***
# Man:Precip  4     41    10.3   0.468    0.759    
# Residuals  12    265    22.1                     
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Error: Within
#                 Df Sum Sq Mean Sq F value   Pr(>F)    
# Year             1 1036.7  1036.7  37.857 8.25e-06 ***
# Year:Man         2 1557.6   778.8  28.441 2.68e-06 ***
# Year:Precip      2   16.7     8.4   0.306    0.740    
# Year:Man:Precip  4   38.2     9.5   0.349    0.841    
# Residuals       18  492.9    27.4                     
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

tapply(srda_ann$BNPP, list(srda_ann$Precip, srda_ann$Man), mean, na.rm=T)

#      Fencing  Grazing   Mowing
# Dry 70.34667 61.83667 68.36500
# Amb 82.27500 73.34667 83.55167
# Wet 95.61500 83.97833 93.72167

summary(emmeans(aov_bnpp_oa, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate   SE   df t.ratio p.value
#  Fencing Dry - Grazing Dry    8.510 2.86 14.3   2.979 0.0098 
#  Fencing Dry - Mowing Dry     1.982 2.86 14.3   0.694 0.4989 
#  Fencing Dry - Fencing Amb  -11.928 2.71 12.0  -4.395 0.0009 
#  Fencing Dry - Grazing Amb   -3.000 2.86 14.3  -1.050 0.3110 
#  Fencing Dry - Mowing Amb   -13.205 2.86 14.3  -4.623 0.0004 
#  Fencing Dry - Fencing Wet  -25.268 2.71 12.0  -9.309 <.0001 
#  Fencing Dry - Grazing Wet  -13.632 2.86 14.3  -4.772 0.0003 
#  Fencing Dry - Mowing Wet   -23.375 2.86 14.3  -8.183 <.0001 
#  Grazing Dry - Mowing Dry    -6.528 2.86 14.3  -2.285 0.0380 
#  Grazing Dry - Fencing Amb  -20.438 2.86 14.3  -7.155 <.0001 
#  Grazing Dry - Grazing Amb  -11.510 2.71 12.0  -4.241 0.0011 
#  Grazing Dry - Mowing Amb   -21.715 2.86 14.3  -7.602 <.0001 
#  Grazing Dry - Fencing Wet  -33.778 2.86 14.3 -11.825 <.0001 
#  Grazing Dry - Grazing Wet  -22.142 2.71 12.0  -8.157 <.0001 
#  Grazing Dry - Mowing Wet   -31.885 2.86 14.3 -11.162 <.0001 
#  Mowing Dry - Fencing Amb   -13.910 2.86 14.3  -4.870 0.0002 
#  Mowing Dry - Grazing Amb    -4.982 2.86 14.3  -1.744 0.1026 
#  Mowing Dry - Mowing Amb    -15.187 2.71 12.0  -5.595 0.0001 
#  Mowing Dry - Fencing Wet   -27.250 2.86 14.3  -9.540 <.0001 
#  Mowing Dry - Grazing Wet   -15.613 2.86 14.3  -5.466 0.0001 
#  Mowing Dry - Mowing Wet    -25.357 2.71 12.0  -9.342 <.0001 
#  Fencing Amb - Grazing Amb    8.928 2.86 14.3   3.126 0.0073 
#  Fencing Amb - Mowing Amb    -1.277 2.86 14.3  -0.447 0.6616 
#  Fencing Amb - Fencing Wet  -13.340 2.71 12.0  -4.915 0.0004 
#  Fencing Amb - Grazing Wet   -1.703 2.86 14.3  -0.596 0.5603 
#  Fencing Amb - Mowing Wet   -11.447 2.86 14.3  -4.007 0.0012 
#  Grazing Amb - Mowing Amb   -10.205 2.86 14.3  -3.573 0.0030 
#  Grazing Amb - Fencing Wet  -22.268 2.86 14.3  -7.796 <.0001 
#  Grazing Amb - Grazing Wet  -10.632 2.71 12.0  -3.917 0.0020 
#  Grazing Amb - Mowing Wet   -20.375 2.86 14.3  -7.133 <.0001 
#  Mowing Amb - Fencing Wet   -12.063 2.86 14.3  -4.223 0.0008 
#  Mowing Amb - Grazing Wet    -0.427 2.86 14.3  -0.149 0.8833 
#  Mowing Amb - Mowing Wet    -10.170 2.71 12.0  -3.747 0.0028 
#  Fencing Wet - Grazing Wet   11.637 2.86 14.3   4.074 0.0011 
#  Fencing Wet - Mowing Wet     1.893 2.86 14.3   0.663 0.5180 
#  Grazing Wet - Mowing Wet    -9.743 2.86 14.3  -3.411 0.0041 
# 
# Results are averaged over the levels of: Year 

tapply(srda_ann$BNPP, list(srda_ann$Man), mean, na.rm=T)

#  Fencing  Grazing   Mowing 
# 82.74556 73.05389 81.87944 

summary(emmeans(aov_bnpp_oa, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate  SE df t.ratio p.value
#  Fencing - Grazing    9.692 1.8  4  5.377  0.0058 
#  Fencing - Mowing     0.866 1.8  4  0.481  0.6559 
#  Grazing - Mowing    -8.826 1.8  4 -4.897  0.0081 
# 
# Results are averaged over the levels of: Year, Precip 

tapply(srda_ann$BNPP, list(srda_ann$Precip), mean, na.rm=T)

#      Dry      Amb      Wet 
# 66.84944 79.72444 91.10500

summary(emmeans(aov_bnpp_oa, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate   SE df t.ratio p.value
#  Dry - Amb    -12.9 1.57 12  -8.216 <.0001 
#  Dry - Wet    -24.3 1.57 12 -15.478 <.0001 
#  Amb - Wet    -11.4 1.57 12  -7.262 <.0001 
# 
# Results are averaged over the levels of: Year, Man 

######################################################################################
# The following codes and results were used to analyze the effects of land-use regimes
# and altered precipitation amount on soil microbial biomass carbon and nitrogen in 
# 2019 of our experiment.#############################################################

# R codes for analyzing the effects of land-use regimes and altered precipitation
# amount on microbial biomass carbon in 2019.
aov_mbc_19 = aov(MBC~Man*Precip+Error(Block/Man/Precip), data=subset(srda_ann, Year=="2019"))
summary(aov_mbc_19)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  33965   16983               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)  
# Man        2   9516    4758   8.168 0.0387 *
# Residuals  4   2330     583                 
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2  27677   13839  17.767 0.000259 ***
# Man:Precip  4   7979    1995   2.561 0.092761 .  
# Residuals  12   9347     779                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$MBC[srda_ann$Year==2019], list(srda_ann$Precip[srda_ann$Year==2019], srda_ann$Man[srda_ann$Year==2019]), mean)

#      Fencing  Grazing   Mowing
# Dry 294.1185 222.4222 313.0815
# Amb 328.0519 331.8296 349.4889
# Wet 330.4222 346.0815 374.4593

summary(emmeans(aov_mbc_19, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate   SE df t.ratio p.value
#  Fencing Dry - Grazing Dry    71.70 21.8 16  3.287  0.0047 
#  Fencing Dry - Mowing Dry    -18.96 21.8 16 -0.870  0.3975 
#  Fencing Dry - Fencing Amb   -33.93 22.8 12 -1.489  0.1623 
#  Fencing Dry - Grazing Amb   -37.71 21.8 16 -1.729  0.1031 
#  Fencing Dry - Mowing Amb    -55.37 21.8 16 -2.539  0.0219 
#  Fencing Dry - Fencing Wet   -36.30 22.8 12 -1.593  0.1371 
#  Fencing Dry - Grazing Wet   -51.96 21.8 16 -2.383  0.0300 
#  Fencing Dry - Mowing Wet    -80.34 21.8 16 -3.684  0.0020 
#  Grazing Dry - Mowing Dry    -90.66 21.8 16 -4.157  0.0007 
#  Grazing Dry - Fencing Amb  -105.63 21.8 16 -4.843  0.0002 
#  Grazing Dry - Grazing Amb  -109.41 22.8 12 -4.801  0.0004 
#  Grazing Dry - Mowing Amb   -127.07 21.8 16 -5.826  <.0001 
#  Grazing Dry - Fencing Wet  -108.00 21.8 16 -4.952  0.0001 
#  Grazing Dry - Grazing Wet  -123.66 22.8 12 -5.427  0.0002 
#  Grazing Dry - Mowing Wet   -152.04 21.8 16 -6.971  <.0001 
#  Mowing Dry - Fencing Amb    -14.97 21.8 16 -0.686  0.5023 
#  Mowing Dry - Grazing Amb    -18.75 21.8 16 -0.860  0.4027 
#  Mowing Dry - Mowing Amb     -36.41 22.8 12 -1.598  0.1361 
#  Mowing Dry - Fencing Wet    -17.34 21.8 16 -0.795  0.4382 
#  Mowing Dry - Grazing Wet    -33.00 21.8 16 -1.513  0.1498 
#  Mowing Dry - Mowing Wet     -61.38 22.8 12 -2.694  0.0195 
#  Fencing Amb - Grazing Amb    -3.78 21.8 16 -0.173  0.8647 
#  Fencing Amb - Mowing Amb    -21.44 21.8 16 -0.983  0.3403 
#  Fencing Amb - Fencing Wet    -2.37 22.8 12 -0.104  0.9189 
#  Fencing Amb - Grazing Wet   -18.03 21.8 16 -0.827  0.4206 
#  Fencing Amb - Mowing Wet    -46.41 21.8 16 -2.128  0.0493 
#  Grazing Amb - Mowing Amb    -17.66 21.8 16 -0.810  0.4300 
#  Grazing Amb - Fencing Wet     1.41 21.8 16  0.065  0.9493 
#  Grazing Amb - Grazing Wet   -14.25 22.8 12 -0.625  0.5434 
#  Grazing Amb - Mowing Wet    -42.63 21.8 16 -1.955  0.0684 
#  Mowing Amb - Fencing Wet     19.07 21.8 16  0.874  0.3949 
#  Mowing Amb - Grazing Wet      3.41 21.8 16  0.156  0.8778 
#  Mowing Amb - Mowing Wet     -24.97 22.8 12 -1.096  0.2947 
#  Fencing Wet - Grazing Wet   -15.66 21.8 16 -0.718  0.4831 
#  Fencing Wet - Mowing Wet    -44.04 21.8 16 -2.019  0.0606 
#  Grazing Wet - Mowing Wet    -28.38 21.8 16 -1.301  0.2117 

tapply(srda_ann$MBC[srda_ann$Year==2019], list(srda_ann$Man[srda_ann$Year==2019]), mean)

#  Fencing  Grazing   Mowing 
# 317.5309 300.1111 345.6765 

summary(emmeans(aov_mbc_19, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate   SE df t.ratio p.value
#  Fencing - Grazing     17.4 11.4  4  1.531  0.2005 
#  Fencing - Mowing     -28.1 11.4  4 -2.474  0.0687 
#  Grazing - Mowing     -45.6 11.4  4 -4.005  0.0161 
# 
# Results are averaged over the levels of: Precip 

tapply(srda_ann$MBC[srda_ann$Year==2019], list(srda_ann$Precip[srda_ann$Year==2019]), mean)

#      Dry      Amb      Wet 
# 276.5407 336.4568 350.3210 

summary(emmeans(aov_mbc_19, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate   SE df t.ratio p.value
#  Dry - Amb    -59.9 13.2 12 -4.554  0.0007 
#  Dry - Wet    -73.8 13.2 12 -5.608  0.0001 
#  Amb - Wet    -13.9 13.2 12 -1.054  0.3127 
# 
# Results are averaged over the levels of: Man 

# R codes for analyzing the effects of land-use regimes and altered precipitation
# amount on microbial biomass nitrogen in 2019.
aov_mbn_19 = aov(MBN~Man*Precip+Error(Block/Man/Precip), data=subset(srda_ann, Year=="2019"))
summary(aov_mbn_19)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2   1468   733.8               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)
# Man        2  105.8   52.92   0.609  0.588
# Residuals  4  347.7   86.92               
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value  Pr(>F)   
# Precip      2   1892   946.1   11.09 0.00188 **
# Man:Precip  4   1263   315.8    3.70 0.03475 * 
# Residuals  12   1024    85.4                   
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$MBN[srda_ann$Year==2019], list(srda_ann$Precip[srda_ann$Year==2019], srda_ann$Man[srda_ann$Year==2019]), mean)

#      Fencing  Grazing   Mowing
# Dry 49.91111 31.11111 50.60741
# Amb 54.25185 60.74074 59.20000
# Wet 54.35556 73.76296 63.25926

summary(emmeans(aov_mbn_19, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate   SE   df t.ratio p.value
#  Fencing Dry - Grazing Dry   18.800 7.57 15.4  2.485  0.0249 
#  Fencing Dry - Mowing Dry    -0.696 7.57 15.4 -0.092  0.9279 
#  Fencing Dry - Fencing Amb   -4.341 7.54 12.0 -0.575  0.5756 
#  Fencing Dry - Grazing Amb  -10.830 7.57 15.4 -1.431  0.1724 
#  Fencing Dry - Mowing Amb    -9.289 7.57 15.4 -1.228  0.2380 
#  Fencing Dry - Fencing Wet   -4.444 7.54 12.0 -0.589  0.5667 
#  Fencing Dry - Grazing Wet  -23.852 7.57 15.4 -3.152  0.0064 
#  Fencing Dry - Mowing Wet   -13.348 7.57 15.4 -1.764  0.0976 
#  Grazing Dry - Mowing Dry   -19.496 7.57 15.4 -2.577  0.0207 
#  Grazing Dry - Fencing Amb  -23.141 7.57 15.4 -3.058  0.0078 
#  Grazing Dry - Grazing Amb  -29.630 7.54 12.0 -3.928  0.0020 
#  Grazing Dry - Mowing Amb   -28.089 7.57 15.4 -3.712  0.0020 
#  Grazing Dry - Fencing Wet  -23.244 7.57 15.4 -3.072  0.0076 
#  Grazing Dry - Grazing Wet  -42.652 7.54 12.0 -5.654  0.0001 
#  Grazing Dry - Mowing Wet   -32.148 7.57 15.4 -4.249  0.0007 
#  Mowing Dry - Fencing Amb    -3.644 7.57 15.4 -0.482  0.6368 
#  Mowing Dry - Grazing Amb   -10.133 7.57 15.4 -1.339  0.2000 
#  Mowing Dry - Mowing Amb     -8.593 7.54 12.0 -1.139  0.2769 
#  Mowing Dry - Fencing Wet    -3.748 7.57 15.4 -0.495  0.6273 
#  Mowing Dry - Grazing Wet   -23.156 7.57 15.4 -3.060  0.0078 
#  Mowing Dry - Mowing Wet    -12.652 7.54 12.0 -1.677  0.1193 
#  Fencing Amb - Grazing Amb   -6.489 7.57 15.4 -0.858  0.4043 
#  Fencing Amb - Mowing Amb    -4.948 7.57 15.4 -0.654  0.5228 
#  Fencing Amb - Fencing Wet   -0.104 7.54 12.0 -0.014  0.9893 
#  Fencing Amb - Grazing Wet  -19.511 7.57 15.4 -2.579  0.0207 
#  Fencing Amb - Mowing Wet    -9.007 7.57 15.4 -1.190  0.2519 
#  Grazing Amb - Mowing Amb     1.541 7.57 15.4  0.204  0.8413 
#  Grazing Amb - Fencing Wet    6.385 7.57 15.4  0.844  0.4117 
#  Grazing Amb - Grazing Wet  -13.022 7.54 12.0 -1.726  0.1099 
#  Grazing Amb - Mowing Wet    -2.519 7.57 15.4 -0.333  0.7437 
#  Mowing Amb - Fencing Wet     4.844 7.57 15.4  0.640  0.5314 
#  Mowing Amb - Grazing Wet   -14.563 7.57 15.4 -1.925  0.0730 
#  Mowing Amb - Mowing Wet     -4.059 7.54 12.0 -0.538  0.6003 
#  Fencing Wet - Grazing Wet  -19.407 7.57 15.4 -2.565  0.0212 
#  Fencing Wet - Mowing Wet    -8.904 7.57 15.4 -1.177  0.2572 
#  Grazing Wet - Mowing Wet    10.504 7.57 15.4  1.388  0.1849 

tapply(srda_ann$MBN[srda_ann$Year==2019], list(srda_ann$Man[srda_ann$Year==2019]), mean)

#  Fencing  Grazing   Mowing 
# 52.83951 55.20494 57.68889 

summary(emmeans(aov_mbn_19, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate   SE df t.ratio p.value
#  Fencing - Grazing    -2.37 4.39  4 -0.538  0.6190 
#  Fencing - Mowing     -4.85 4.39  4 -1.103  0.3318 
#  Grazing - Mowing     -2.48 4.39  4 -0.565  0.6021 
# 
# Results are averaged over the levels of: Precip 

tapply(srda_ann$MBN[srda_ann$Year==2019], list(srda_ann$Precip[srda_ann$Year==2019]), mean)

#      Dry      Amb      Wet 
# 43.87654 58.06420 63.79259 

summary(emmeans(aov_mbn_19, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate   SE df t.ratio p.value
#  Dry - Amb   -14.19 4.36 12 -3.258  0.0069 
#  Dry - Wet   -19.92 4.36 12 -4.573  0.0006 
#  Amb - Wet    -5.73 4.36 12 -1.315  0.2130 
# 
# Results are averaged over the levels of: Man 

######################################################################################
# The following codes and results were used to analyze the effects of land-use regimes
# and altered precipitation amount on soil respiration in 2017, 2018, 2019 and during 
# the overall 3 years of our experiment.##############################################

# R codes for analyzing the effects of land-use regimes  and altered precipitation
# amount on soil respiration in 2017.
aov_sr_17 = aov(log(SR)~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda, Year=="2017"))
summary(aov_sr_17)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  1.751  0.8757               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)  
# Man        2  1.568  0.7840    7.82 0.0415 *
# Residuals  4  0.401  0.1003                 
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2 25.188  12.594 334.932 2.97e-11 ***
# Man:Precip  4  0.691   0.173   4.593   0.0176 *  
# Residuals  12  0.451   0.038                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq F value   Pr(>F)    
# Date             10  59.88   5.988 139.142  < 2e-16 ***
# Man:Date         20   1.33   0.066   1.544 0.071751 .  
# Precip:Date      20   2.28   0.114   2.643 0.000351 ***
# Man:Precip:Date  40   0.94   0.024   0.549 0.986607    
# Residuals       180   7.75   0.043                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$SR[srda_ann$Year==2017], list(srda_ann$Precip[srda_ann$Year==2017], srda_ann$Man[srda_ann$Year==2017]), mean)

#      Fencing   Grazing    Mowing
# Dry 1.237879 0.9227273 0.9184848
# Amb 1.756212 1.7539394 1.6156061
# Wet 2.235758 2.1893939 2.0290909

summary(emmeans(aov_sr_17, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate     SE   df t.ratio p.value
#  Fencing Dry - Grazing Dry   0.3050 0.0595 10.3   5.122 0.0004 
#  Fencing Dry - Mowing Dry    0.2757 0.0595 10.3   4.630 0.0009 
#  Fencing Dry - Fencing Amb  -0.3390 0.0477 12.0  -7.101 <.0001 
#  Fencing Dry - Grazing Amb  -0.2825 0.0595 10.3  -4.745 0.0007 
#  Fencing Dry - Mowing Amb   -0.2307 0.0595 10.3  -3.875 0.0029 
#  Fencing Dry - Fencing Wet  -0.5614 0.0477 12.0 -11.761 <.0001 
#  Fencing Dry - Grazing Wet  -0.4983 0.0595 10.3  -8.369 <.0001 
#  Fencing Dry - Mowing Wet   -0.4527 0.0595 10.3  -7.603 <.0001 
#  Grazing Dry - Mowing Dry   -0.0293 0.0595 10.3  -0.492 0.6329 
#  Grazing Dry - Fencing Amb  -0.6439 0.0595 10.3 -10.816 <.0001 
#  Grazing Dry - Grazing Amb  -0.5875 0.0477 12.0 -12.307 <.0001 
#  Grazing Dry - Mowing Amb   -0.5356 0.0595 10.3  -8.997 <.0001 
#  Grazing Dry - Fencing Wet  -0.8664 0.0595 10.3 -14.552 <.0001 
#  Grazing Dry - Grazing Wet  -0.8032 0.0477 12.0 -16.826 <.0001 
#  Grazing Dry - Mowing Wet   -0.7576 0.0595 10.3 -12.725 <.0001 
#  Mowing Dry - Fencing Amb   -0.6146 0.0595 10.3 -10.323 <.0001 
#  Mowing Dry - Grazing Amb   -0.5582 0.0595 10.3  -9.375 <.0001 
#  Mowing Dry - Mowing Amb    -0.5063 0.0477 12.0 -10.607 <.0001 
#  Mowing Dry - Fencing Wet   -0.8371 0.0595 10.3 -14.060 <.0001 
#  Mowing Dry - Grazing Wet   -0.7739 0.0595 10.3 -12.999 <.0001 
#  Mowing Dry - Mowing Wet    -0.7283 0.0477 12.0 -15.257 <.0001 
#  Fencing Amb - Grazing Amb   0.0564 0.0595 10.3   0.948 0.3648 
#  Fencing Amb - Mowing Amb    0.1083 0.0595 10.3   1.819 0.0981 
#  Fencing Amb - Fencing Wet  -0.2225 0.0477 12.0  -4.660 0.0006 
#  Fencing Amb - Grazing Wet  -0.1593 0.0595 10.3  -2.676 0.0227 
#  Fencing Amb - Mowing Wet   -0.1137 0.0595 10.3  -1.910 0.0843 
#  Grazing Amb - Mowing Amb    0.0518 0.0595 10.3   0.871 0.4037 
#  Grazing Amb - Fencing Wet  -0.2789 0.0595 10.3  -4.684 0.0008 
#  Grazing Amb - Grazing Wet  -0.2158 0.0477 12.0  -4.520 0.0007 
#  Grazing Amb - Mowing Wet   -0.1701 0.0595 10.3  -2.858 0.0165 
#  Mowing Amb - Fencing Wet   -0.3307 0.0595 10.3  -5.555 0.0002 
#  Mowing Amb - Grazing Wet   -0.2676 0.0595 10.3  -4.495 0.0011 
#  Mowing Amb - Mowing Wet    -0.2220 0.0477 12.0  -4.650 0.0006 
#  Fencing Wet - Grazing Wet   0.0631 0.0595 10.3   1.061 0.3131 
#  Fencing Wet - Mowing Wet    0.1087 0.0595 10.3   1.827 0.0968 
#  Grazing Wet - Mowing Wet    0.0456 0.0595 10.3   0.766 0.4609 
# 
# Results are averaged over the levels of: Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$SR[srda_ann$Year==2017], list(srda_ann$Man[srda_ann$Year==2017]), mean)

#  Fencing  Grazing   Mowing 
# 1.743283 1.622020 1.521061 

summary(emmeans(aov_sr_17, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate    SE df t.ratio p.value
#  Fencing - Grazing   0.1415 0.045  4 3.144   0.0347 
#  Fencing - Mowing    0.1642 0.045  4 3.649   0.0218 
#  Grazing - Mowing    0.0227 0.045  4 0.505   0.6403 
# 
# Results are averaged over the levels of: Precip, Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$SR[srda_ann$Year==2017], list(srda_ann$Precip[srda_ann$Year==2017]), mean)

#      Dry      Amb      Wet 
# 1.026364 1.708586 2.151414 

summary(emmeans(aov_sr_17, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate     SE df t.ratio p.value
#  Dry - Amb   -0.478 0.0276 12 -17.329 <.0001 
#  Dry - Wet   -0.698 0.0276 12 -25.313 <.0001 
#  Amb - Wet   -0.220 0.0276 12  -7.985 <.0001 
# 
# Results are averaged over the levels of: Man, Date 
# Results are given on the log (not the response) scale. 

# R codes for analyzing the effects of land-use regimes  and altered precipitation
# amount on soil respiration in 2018.
aov_sr_18 = aov(log(SR)~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda, Year=="2018"))
summary(aov_sr_18)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2 0.1318 0.06592               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)
# Man        2 0.4195  0.2097   1.972  0.254
# Residuals  4 0.4255  0.1064               
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2 17.972   8.986 283.725 7.89e-11 ***
# Man:Precip  4  0.047   0.012   0.374    0.823    
# Residuals  12  0.380   0.032                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq F value   Pr(>F)    
# Date             10  91.39   9.139 359.692  < 2e-16 ***
# Man:Date         20   2.86   0.143   5.625 3.97e-11 ***
# Precip:Date      20   2.11   0.105   4.146 1.05e-07 ***
# Man:Precip:Date  40   1.99   0.050   1.958  0.00159 ** 
# Residuals       180   4.57   0.025                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$SR[srda_ann$Year==2018], list(srda_ann$Precip[srda_ann$Year==2018], srda_ann$Man[srda_ann$Year==2018]), mean)

#      Fencing  Grazing   Mowing
# Dry 1.208788 1.268939 1.189242
# Amb 1.669394 1.893182 1.695530
# Wet 2.222652 2.415606 2.118182

summary(emmeans(aov_sr_18, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate     SE    df t.ratio p.value
#  Fencing Dry - Grazing Dry  -0.0415 0.0586  9.11  -0.708 0.4965 
#  Fencing Dry - Mowing Dry    0.0137 0.0586  9.11   0.233 0.8206 
#  Fencing Dry - Fencing Amb  -0.3445 0.0438 12.00  -7.862 <.0001 
#  Fencing Dry - Grazing Amb  -0.4211 0.0586  9.11  -7.191 <.0001 
#  Fencing Dry - Mowing Amb   -0.3148 0.0586  9.11  -5.377 0.0004 
#  Fencing Dry - Fencing Wet  -0.6165 0.0438 12.00 -14.072 <.0001 
#  Fencing Dry - Grazing Wet  -0.6617 0.0586  9.11 -11.301 <.0001 
#  Fencing Dry - Mowing Wet   -0.5486 0.0586  9.11  -9.369 <.0001 
#  Grazing Dry - Mowing Dry    0.0551 0.0586  9.11   0.942 0.3707 
#  Grazing Dry - Fencing Amb  -0.3030 0.0586  9.11  -5.175 0.0006 
#  Grazing Dry - Grazing Amb  -0.3796 0.0438 12.00  -8.664 <.0001 
#  Grazing Dry - Mowing Amb   -0.2734 0.0586  9.11  -4.669 0.0011 
#  Grazing Dry - Fencing Wet  -0.5750 0.0586  9.11  -9.821 <.0001 
#  Grazing Dry - Grazing Wet  -0.6203 0.0438 12.00 -14.157 <.0001 
#  Grazing Dry - Mowing Wet   -0.5071 0.0586  9.11  -8.660 <.0001 
#  Mowing Dry - Fencing Amb   -0.3581 0.0586  9.11  -6.116 0.0002 
#  Mowing Dry - Grazing Amb   -0.4347 0.0586  9.11  -7.425 <.0001 
#  Mowing Dry - Mowing Amb    -0.3285 0.0438 12.00  -7.498 <.0001 
#  Mowing Dry - Fencing Wet   -0.6302 0.0586  9.11 -10.762 <.0001 
#  Mowing Dry - Grazing Wet   -0.6754 0.0586  9.11 -11.535 <.0001 
#  Mowing Dry - Mowing Wet    -0.5622 0.0438 12.00 -12.833 <.0001 
#  Fencing Amb - Grazing Amb  -0.0766 0.0586  9.11  -1.308 0.2229 
#  Fencing Amb - Mowing Amb    0.0296 0.0586  9.11   0.506 0.6249 
#  Fencing Amb - Fencing Wet  -0.2720 0.0438 12.00  -6.209 <.0001 
#  Fencing Amb - Grazing Wet  -0.3173 0.0586  9.11  -5.418 0.0004 
#  Fencing Amb - Mowing Wet   -0.2041 0.0586  9.11  -3.486 0.0068 
#  Grazing Amb - Mowing Amb    0.1062 0.0586  9.11   1.814 0.1027 
#  Grazing Amb - Fencing Wet  -0.1954 0.0586  9.11  -3.338 0.0086 
#  Grazing Amb - Grazing Wet  -0.2407 0.0438 12.00  -5.493 0.0001 
#  Grazing Amb - Mowing Wet   -0.1275 0.0586  9.11  -2.178 0.0571 
#  Mowing Amb - Fencing Wet   -0.3017 0.0586  9.11  -5.152 0.0006 
#  Mowing Amb - Grazing Wet   -0.3469 0.0586  9.11  -5.924 0.0002 
#  Mowing Amb - Mowing Wet    -0.2337 0.0438 12.00  -5.335 0.0002 
#  Fencing Wet - Grazing Wet  -0.0452 0.0586  9.11  -0.772 0.4594 
#  Fencing Wet - Mowing Wet    0.0679 0.0586  9.11   1.160 0.2755 
#  Grazing Wet - Mowing Wet    0.1132 0.0586  9.11   1.933 0.0849 
# 
# Results are averaged over the levels of: Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$SR[srda_ann$Year==2018], list(srda_ann$Man[srda_ann$Year==2018]), mean)

#  Fencing  Grazing   Mowing 
# 1.700278 1.859242 1.667652 

summary(emmeans(aov_sr_18, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate     SE df t.ratio p.value
#  Fencing - Grazing  -0.0544 0.0464  4 -1.174  0.3054 
#  Fencing - Mowing    0.0371 0.0464  4  0.800  0.4686 
#  Grazing - Mowing    0.0915 0.0464  4  1.974  0.1196 
# 
# Results are averaged over the levels of: Precip, Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$SR[srda_ann$Year==2018], list(srda_ann$Precip[srda_ann$Year==2018]), mean)

#      Dry      Amb      Wet 
# 1.222323 1.752702 2.252146 

summary(emmeans(aov_sr_18, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate     SE df t.ratio p.value
#  Dry - Amb   -0.351 0.0253 12 -13.871 <.0001 
#  Dry - Wet   -0.600 0.0253 12 -23.707 <.0001 
#  Amb - Wet   -0.249 0.0253 12  -9.836 <.0001 
# 
# Results are averaged over the levels of: Man, Date 
# Results are given on the log (not the response) scale. 

# R codes for analyzing the effects of land-use regimes  and altered precipitation
# amount on soil respiration in 2019.
aov_sr_19 = aov(log(SR)~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda, Year=="2019"))
summary(aov_sr_19)

# Results of analysis
#
# Error: Block
#           Df   Sum Sq  Mean Sq F value Pr(>F)
# Residuals  2 0.005066 0.002533               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)
# Man        2 0.3028 0.15141   3.664  0.125
# Residuals  4 0.1653 0.04133               
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2 26.809  13.404 496.858 2.89e-12 ***
# Man:Precip  4  0.164   0.041   1.516    0.259    
# Residuals  12  0.324   0.027                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq F value   Pr(>F)    
# Date             11  60.74   5.522 315.758  < 2e-16 ***
# Man:Date         22   1.07   0.049   2.794 8.16e-05 ***
# Precip:Date      22   2.06   0.094   5.353 2.28e-11 ***
# Man:Precip:Date  44   0.97   0.022   1.267    0.141    
# Residuals       198   3.46   0.017                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$SR[srda_ann$Year==2019], list(srda_ann$Precip[srda_ann$Year==2019], srda_ann$Man[srda_ann$Year==2019]), mean)

#      Fencing  Grazing   Mowing
# Dry 1.235833 1.145833 1.158056
# Amb 1.985139 1.773889 1.891250
# Wet 2.536597 2.549028 2.309306

summary(emmeans(aov_sr_19, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate     SE   df t.ratio p.value
#  Fencing Dry - Grazing Dry   0.0564 0.0420 13.6   1.342 0.2017 
#  Fencing Dry - Mowing Dry    0.0853 0.0420 13.6   2.031 0.0624 
#  Fencing Dry - Fencing Amb  -0.4229 0.0387 12.0 -10.923 <.0001 
#  Fencing Dry - Grazing Amb  -0.3534 0.0420 13.6  -8.413 <.0001 
#  Fencing Dry - Mowing Amb   -0.3758 0.0420 13.6  -8.945 <.0001 
#  Fencing Dry - Fencing Wet  -0.6770 0.0387 12.0 -17.487 <.0001 
#  Fencing Dry - Grazing Wet  -0.6911 0.0420 13.6 -16.453 <.0001 
#  Fencing Dry - Mowing Wet   -0.5847 0.0420 13.6 -13.920 <.0001 
#  Grazing Dry - Mowing Dry    0.0289 0.0420 13.6   0.689 0.5025 
#  Grazing Dry - Fencing Amb  -0.4792 0.0420 13.6 -11.408 <.0001 
#  Grazing Dry - Grazing Amb  -0.4098 0.0387 12.0 -10.584 <.0001 
#  Grazing Dry - Mowing Amb   -0.4321 0.0420 13.6 -10.287 <.0001 
#  Grazing Dry - Fencing Wet  -0.7334 0.0420 13.6 -17.458 <.0001 
#  Grazing Dry - Grazing Wet  -0.7475 0.0387 12.0 -19.308 <.0001 
#  Grazing Dry - Mowing Wet   -0.6411 0.0420 13.6 -15.262 <.0001 
#  Mowing Dry - Fencing Amb   -0.5082 0.0420 13.6 -12.097 <.0001 
#  Mowing Dry - Grazing Amb   -0.4387 0.0420 13.6 -10.444 <.0001 
#  Mowing Dry - Mowing Amb    -0.4611 0.0387 12.0 -11.910 <.0001 
#  Mowing Dry - Fencing Wet   -0.7623 0.0420 13.6 -18.147 <.0001 
#  Mowing Dry - Grazing Wet   -0.7764 0.0420 13.6 -18.484 <.0001 
#  Mowing Dry - Mowing Wet    -0.6700 0.0387 12.0 -17.308 <.0001 
#  Fencing Amb - Grazing Amb   0.0695 0.0420 13.6   1.654 0.1212 
#  Fencing Amb - Mowing Amb    0.0471 0.0420 13.6   1.121 0.2817 
#  Fencing Amb - Fencing Wet  -0.2541 0.0387 12.0  -6.564 <.0001 
#  Fencing Amb - Grazing Wet  -0.2683 0.0420 13.6  -6.387 <.0001 
#  Fencing Amb - Mowing Wet   -0.1619 0.0420 13.6  -3.854 0.0019 
#  Grazing Amb - Mowing Amb   -0.0224 0.0420 13.6  -0.532 0.6031 
#  Grazing Amb - Fencing Wet  -0.3236 0.0420 13.6  -7.704 <.0001 
#  Grazing Amb - Grazing Wet  -0.3377 0.0387 12.0  -8.724 <.0001 
#  Grazing Amb - Mowing Wet   -0.2313 0.0420 13.6  -5.507 0.0001 
#  Mowing Amb - Fencing Wet   -0.3012 0.0420 13.6  -7.171 <.0001 
#  Mowing Amb - Grazing Wet   -0.3154 0.0420 13.6  -7.508 <.0001 
#  Mowing Amb - Mowing Wet    -0.2090 0.0387 12.0  -5.398 0.0002 
#  Fencing Wet - Grazing Wet  -0.0141 0.0420 13.6  -0.337 0.7415 
#  Fencing Wet - Mowing Wet    0.0923 0.0420 13.6   2.196 0.0460 
#  Grazing Wet - Mowing Wet    0.1064 0.0420 13.6   2.533 0.0244 
# 
# Results are averaged over the levels of: Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$SR[srda_ann$Year==2019], list(srda_ann$Man[srda_ann$Year==2019]), mean)

#  Fencing  Grazing   Mowing 
# 1.919190 1.822917 1.786204 

summary(emmeans(aov_sr_19, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate     SE df t.ratio p.value
#  Fencing - Grazing   0.0372 0.0277  4 1.346   0.2496 
#  Fencing - Mowing    0.0749 0.0277  4 2.707   0.0537 
#  Grazing - Mowing    0.0377 0.0277  4 1.361   0.2451 
# 
# Results are averaged over the levels of: Precip, Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$SR[srda_ann$Year==2019], list(srda_ann$Precip[srda_ann$Year==2019]), mean)

#      Dry      Amb      Wet 
# 1.179907 1.883426 2.464977 

summary(emmeans(aov_sr_19, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate     SE df t.ratio p.value
#  Dry - Amb   -0.431 0.0224 12 -19.293 <.0001 
#  Dry - Wet   -0.698 0.0224 12 -31.236 <.0001 
#  Amb - Wet   -0.267 0.0224 12 -11.943 <.0001 
# 
# Results are averaged over the levels of: Man, Date 
# Results are given on the log (not the response) scale. 

# R codes for analyzing the effects of land-use regimes  and altered precipitation
# amount on soil respiration during the overall 3 years.
aov_sr_oa = aov(log(SR)~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda))
summary(aov_sr_oa)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2 0.3599  0.1799               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)  
# Man        2 1.2867  0.6433   14.06 0.0155 *
# Residuals  4 0.1831  0.0458                 
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2  69.44   34.72 893.079 8.83e-14 ***
# Man:Precip  4   0.37    0.09   2.353    0.113    
# Residuals  12   0.47    0.04                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq F value   Pr(>F)    
# Date             33 215.14   6.520 205.899  < 2e-16 ***
# Man:Date         66   6.27   0.095   2.998 1.82e-12 ***
# Precip:Date      66   6.97   0.106   3.334 5.93e-15 ***
# Man:Precip:Date 132   4.45   0.034   1.064    0.314    
# Residuals       594  18.81   0.032                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$SR, list(srda_ann$Precip, srda_ann$Man), mean)

#      Fencing  Grazing   Mowing
# Dry 1.227500 1.112500 1.088594
# Amb 1.803582 1.807003 1.734129
# Wet 2.331669 2.384676 2.152193

summary(emmeans(aov_sr_oa, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                          estimate     SE   df t.ratio p.value
#  Fencing Dry - Grazing Dry  0.105140 0.0284 14.8   3.700 0.0022 
#  Fencing Dry - Mowing Dry   0.123714 0.0284 14.8   4.354 0.0006 
#  Fencing Dry - Fencing Amb -0.370358 0.0276 12.0 -13.414 <.0001 
#  Fencing Dry - Grazing Amb -0.352364 0.0284 14.8 -12.401 <.0001 
#  Fencing Dry - Mowing Amb  -0.309118 0.0284 14.8 -10.879 <.0001 
#  Fencing Dry - Fencing Wet -0.620036 0.0276 12.0 -22.457 <.0001 
#  Fencing Dry - Grazing Wet -0.619232 0.0284 14.8 -21.793 <.0001 
#  Fencing Dry - Mowing Wet  -0.530312 0.0284 14.8 -18.664 <.0001 
#  Grazing Dry - Mowing Dry   0.018574 0.0284 14.8   0.654 0.5233 
#  Grazing Dry - Fencing Amb -0.475497 0.0284 14.8 -16.734 <.0001 
#  Grazing Dry - Grazing Amb -0.457504 0.0276 12.0 -16.570 <.0001 
#  Grazing Dry - Mowing Amb  -0.414258 0.0284 14.8 -14.579 <.0001 
#  Grazing Dry - Fencing Wet -0.725175 0.0284 14.8 -25.522 <.0001 
#  Grazing Dry - Grazing Wet -0.724371 0.0276 12.0 -26.236 <.0001 
#  Grazing Dry - Mowing Wet  -0.635452 0.0284 14.8 -22.364 <.0001 
#  Mowing Dry - Fencing Amb  -0.494071 0.0284 14.8 -17.388 <.0001 
#  Mowing Dry - Grazing Amb  -0.476078 0.0284 14.8 -16.755 <.0001 
#  Mowing Dry - Mowing Amb   -0.432832 0.0276 12.0 -15.677 <.0001 
#  Mowing Dry - Fencing Wet  -0.743750 0.0284 14.8 -26.175 <.0001 
#  Mowing Dry - Grazing Wet  -0.742946 0.0284 14.8 -26.147 <.0001 
#  Mowing Dry - Mowing Wet   -0.654026 0.0276 12.0 -23.688 <.0001 
#  Fencing Amb - Grazing Amb  0.017993 0.0284 14.8   0.633 0.5362 
#  Fencing Amb - Mowing Amb   0.061240 0.0284 14.8   2.155 0.0480 
#  Fencing Amb - Fencing Wet -0.249678 0.0276 12.0  -9.043 <.0001 
#  Fencing Amb - Grazing Wet -0.248874 0.0284 14.8  -8.759 <.0001 
#  Fencing Amb - Mowing Wet  -0.159954 0.0284 14.8  -5.629 <.0001 
#  Grazing Amb - Mowing Amb   0.043246 0.0284 14.8   1.522 0.1490 
#  Grazing Amb - Fencing Wet -0.267672 0.0284 14.8  -9.420 <.0001 
#  Grazing Amb - Grazing Wet -0.266867 0.0276 12.0  -9.666 <.0001 
#  Grazing Amb - Mowing Wet  -0.177948 0.0284 14.8  -6.263 <.0001 
#  Mowing Amb - Fencing Wet  -0.310918 0.0284 14.8 -10.942 <.0001 
#  Mowing Amb - Grazing Wet  -0.310114 0.0284 14.8 -10.914 <.0001 
#  Mowing Amb - Mowing Wet   -0.221194 0.0276 12.0  -8.011 <.0001 
#  Fencing Wet - Grazing Wet  0.000804 0.0284 14.8   0.028 0.9778 
#  Fencing Wet - Mowing Wet   0.089724 0.0284 14.8   3.158 0.0066 
#  Grazing Wet - Mowing Wet   0.088920 0.0284 14.8   3.129 0.0070 
# 
# Results are averaged over the levels of: Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$SR, list(srda_ann$Man), mean)

#  Fencing  Grazing   Mowing 
# 1.787583 1.768060 1.658305 

summary(emmeans(aov_sr_oa, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate     SE df t.ratio p.value
#  Fencing - Grazing   0.0413 0.0173  4 2.389   0.0753 
#  Fencing - Mowing    0.0916 0.0173  4 5.294   0.0061 
#  Grazing - Mowing    0.0502 0.0173  4 2.905   0.0439 
# 
# Results are averaged over the levels of: Precip, Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$SR, list(srda_ann$Precip), mean)

#      Dry      Amb      Wet 
# 1.142865 1.781571 2.289512 

summary(emmeans(aov_sr_oa, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate     SE df t.ratio p.value
#  Dry - Amb   -0.420 0.0159 12 -26.362 <.0001 
#  Dry - Wet   -0.666 0.0159 12 -41.789 <.0001 
#  Amb - Wet   -0.246 0.0159 12 -15.427 <.0001 
# 
# Results are averaged over the levels of: Man, Date 
# Results are given on the log (not the response) scale. 

#####################################################################################
# The following codes and results were used to analyze the effects of land-use regimes
# and altered precipitation amount on autotrophic component of soil respiration in 
# 2017, 2018, 2019 and during the overall 3 years of our experiment.#################

# R codes for analyzing the effects of land-use regimes  and altered precipitation 
# amount on autotrophic component of soil respiration in 2017.
aov_ar_17 = aov(log(RA)~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda, Year=="2017"))
summary(aov_ar_17)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  1.903  0.9515               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)
# Man        2  1.763  0.8814   3.364  0.139
# Residuals  4  1.048  0.2620               
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2 29.237  14.619  41.760 3.93e-06 ***
# Man:Precip  4  1.993   0.498   1.424    0.285    
# Residuals  12  4.201   0.350                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq F value Pr(>F)    
# Date             10  80.74   8.074  38.162 <2e-16 ***
# Man:Date         20   6.83   0.341   1.613 0.0535 .  
# Precip:Date      20   8.01   0.400   1.892 0.0153 *  
# Man:Precip:Date  40   5.89   0.147   0.696 0.9117    
# Residuals       180  38.08   0.212                   
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$RA[srda_ann$Year==2017], list(srda_ann$Precip[srda_ann$Year==2017], srda_ann$Man[srda_ann$Year==2017]), mean)

#       Fencing   Grazing    Mowing
# Dry 0.4352678 0.2788850 0.2781169
# Amb 0.5659776 0.6931410 0.5568250
# Wet 0.8252649 0.8196418 0.7125415

summary(emmeans(aov_ar_17, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate    SE df t.ratio p.value
#  Fencing Dry - Grazing Dry  0.44112 0.139 16  3.164  0.0060 
#  Fencing Dry - Mowing Dry   0.32504 0.139 16  2.331  0.0332 
#  Fencing Dry - Fencing Amb -0.27642 0.146 12 -1.898  0.0820 
#  Fencing Dry - Grazing Amb -0.26673 0.139 16 -1.913  0.0738 
#  Fencing Dry - Mowing Amb  -0.21304 0.139 16 -1.528  0.1461 
#  Fencing Dry - Fencing Wet -0.54505 0.146 12 -3.742  0.0028 
#  Fencing Dry - Grazing Wet -0.51737 0.139 16 -3.711  0.0019 
#  Fencing Dry - Mowing Wet  -0.43217 0.139 16 -3.100  0.0069 
#  Grazing Dry - Mowing Dry  -0.11608 0.139 16 -0.833  0.4174 
#  Grazing Dry - Fencing Amb -0.71754 0.139 16 -5.147  0.0001 
#  Grazing Dry - Grazing Amb -0.70786 0.146 12 -4.860  0.0004 
#  Grazing Dry - Mowing Amb  -0.65416 0.139 16 -4.692  0.0002 
#  Grazing Dry - Fencing Wet -0.98617 0.139 16 -7.074  <.0001 
#  Grazing Dry - Grazing Wet -0.95849 0.146 12 -6.580  <.0001 
#  Grazing Dry - Mowing Wet  -0.87329 0.139 16 -6.264  <.0001 
#  Mowing Dry - Fencing Amb  -0.60146 0.139 16 -4.314  0.0005 
#  Mowing Dry - Grazing Amb  -0.59178 0.139 16 -4.245  0.0006 
#  Mowing Dry - Mowing Amb   -0.53808 0.146 12 -3.694  0.0031 
#  Mowing Dry - Fencing Wet  -0.87009 0.139 16 -6.241  <.0001 
#  Mowing Dry - Grazing Wet  -0.84241 0.139 16 -6.042  <.0001 
#  Mowing Dry - Mowing Wet   -0.75721 0.146 12 -5.199  0.0002 
#  Fencing Amb - Grazing Amb  0.00968 0.139 16  0.069  0.9455 
#  Fencing Amb - Mowing Amb   0.06338 0.139 16  0.455  0.6555 
#  Fencing Amb - Fencing Wet -0.26863 0.146 12 -1.844  0.0900 
#  Fencing Amb - Grazing Wet -0.24095 0.139 16 -1.728  0.1032 
#  Fencing Amb - Mowing Wet  -0.15575 0.139 16 -1.117  0.2805 
#  Grazing Amb - Mowing Amb   0.05370 0.139 16  0.385  0.7052 
#  Grazing Amb - Fencing Wet -0.27831 0.139 16 -1.996  0.0633 
#  Grazing Amb - Grazing Wet -0.25064 0.146 12 -1.721  0.1110 
#  Grazing Amb - Mowing Wet  -0.16543 0.139 16 -1.187  0.2527 
#  Mowing Amb - Fencing Wet  -0.33201 0.139 16 -2.381  0.0300 
#  Mowing Amb - Grazing Wet  -0.30433 0.139 16 -2.183  0.0443 
#  Mowing Amb - Mowing Wet   -0.21913 0.146 12 -1.504  0.1583 
#  Fencing Wet - Grazing Wet  0.02768 0.139 16  0.199  0.8451 
#  Fencing Wet - Mowing Wet   0.11288 0.139 16  0.810  0.4300 
#  Grazing Wet - Mowing Wet   0.08520 0.139 16  0.611  0.5497 
# 
# Results are averaged over the levels of: Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$RA[srda_ann$Year==2017], list(srda_ann$Man[srda_ann$Year==2017]), mean)

#   Fencing   Grazing    Mowing 
# 0.6088368 0.5972226 0.5158278 

summary(emmeans(aov_ar_17, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate     SE df t.ratio p.value
#  Fencing - Grazing  0.15949 0.0728  4 2.192   0.0935 
#  Fencing - Mowing   0.16710 0.0728  4 2.297   0.0832 
#  Grazing - Mowing   0.00761 0.0728  4 0.105   0.9218 
# 
# Results are averaged over the levels of: Precip, Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$RA[srda_ann$Year==2017], list(srda_ann$Precip[srda_ann$Year==2017]), mean)

#       Dry       Amb       Wet 
# 0.3307566 0.6053145 0.7858161 

summary(emmeans(aov_ar_17, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate     SE df t.ratio p.value
#  Dry - Amb   -0.507 0.0841 12 -6.034  0.0001 
#  Dry - Wet   -0.754 0.0841 12 -8.961  <.0001 
#  Amb - Wet   -0.246 0.0841 12 -2.927  0.0127 
# 
# Results are averaged over the levels of: Man, Date 
# Results are given on the log (not the response) scale. 

# R codes for analyzing the effects of land-use regimes  and altered precipitation
# amount on autotrophic component of soil respiration in 2018.
aov_ar_18 = aov(log(RA)~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda, Year=="2018"))
summary(aov_ar_18)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  2.019    1.01               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)
# Man        2  0.267  0.1336   0.148  0.867
# Residuals  4  3.612  0.9031               
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value  Pr(>F)   
# Precip      2  9.147   4.573  10.687 0.00216 **
# Man:Precip  4  5.147   1.287   3.007 0.06213 . 
# Residuals  12  5.135   0.428                   
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq F value Pr(>F)    
# Date             10 115.02  11.502  19.106 <2e-16 ***
# Man:Date         20  14.63   0.731   1.215  0.246    
# Precip:Date      20  15.54   0.777   1.290  0.190    
# Man:Precip:Date  40  25.87   0.647   1.074  0.366    
# Residuals       180 108.36   0.602                   
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$RA[srda_ann$Year==2018], list(srda_ann$Precip[srda_ann$Year==2018], srda_ann$Man[srda_ann$Year==2018]), mean)

#       Fencing   Grazing    Mowing
# Dry 0.3929127 0.3478549 0.3283761
# Amb 0.3630399 0.4790931 0.3854413
# Wet 0.6447988 0.5584980 0.5638877

summary(emmeans(aov_ar_18, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate    SE   df t.ratio p.value
#  Fencing Dry - Grazing Dry  -0.0689 0.189 11.7 -0.365  0.7214 
#  Fencing Dry - Mowing Dry    0.1575 0.189 11.7  0.836  0.4202 
#  Fencing Dry - Fencing Amb   0.1339 0.161 12.0  0.831  0.4220 
#  Fencing Dry - Grazing Amb  -0.2362 0.189 11.7 -1.253  0.2346 
#  Fencing Dry - Mowing Amb    0.0417 0.189 11.7  0.221  0.8287 
#  Fencing Dry - Fencing Wet  -0.4878 0.161 12.0 -3.029  0.0105 
#  Fencing Dry - Grazing Wet  -0.1618 0.189 11.7 -0.858  0.4080 
#  Fencing Dry - Mowing Wet   -0.4457 0.189 11.7 -2.364  0.0363 
#  Grazing Dry - Mowing Dry    0.2264 0.189 11.7  1.201  0.2536 
#  Grazing Dry - Fencing Amb   0.2028 0.189 11.7  1.076  0.3038 
#  Grazing Dry - Grazing Amb  -0.1674 0.161 12.0 -1.039  0.3192 
#  Grazing Dry - Mowing Amb    0.1106 0.189 11.7  0.587  0.5686 
#  Grazing Dry - Fencing Wet  -0.4189 0.189 11.7 -2.222  0.0468 
#  Grazing Dry - Grazing Wet  -0.0929 0.161 12.0 -0.577  0.5746 
#  Grazing Dry - Mowing Wet   -0.3768 0.189 11.7 -1.999  0.0694 
#  Mowing Dry - Fencing Amb   -0.0236 0.189 11.7 -0.125  0.9024 
#  Mowing Dry - Grazing Amb   -0.3937 0.189 11.7 -2.089  0.0593 
#  Mowing Dry - Mowing Amb    -0.1158 0.161 12.0 -0.719  0.4859 
#  Mowing Dry - Fencing Wet   -0.6453 0.189 11.7 -3.423  0.0052 
#  Mowing Dry - Grazing Wet   -0.3193 0.189 11.7 -1.694  0.1168 
#  Mowing Dry - Mowing Wet    -0.6032 0.161 12.0 -3.746  0.0028 
#  Fencing Amb - Grazing Amb  -0.3701 0.189 11.7 -1.964  0.0738 
#  Fencing Amb - Mowing Amb   -0.0922 0.189 11.7 -0.489  0.6339 
#  Fencing Amb - Fencing Wet  -0.6217 0.161 12.0 -3.860  0.0023 
#  Fencing Amb - Grazing Wet  -0.2957 0.189 11.7 -1.569  0.1434 
#  Fencing Amb - Mowing Wet   -0.5796 0.189 11.7 -3.075  0.0099 
#  Grazing Amb - Mowing Amb    0.2780 0.189 11.7  1.475  0.1668 
#  Grazing Amb - Fencing Wet  -0.2515 0.189 11.7 -1.334  0.2075 
#  Grazing Amb - Grazing Wet   0.0744 0.161 12.0  0.462  0.6522 
#  Grazing Amb - Mowing Wet   -0.2095 0.189 11.7 -1.111  0.2888 
#  Mowing Amb - Fencing Wet   -0.5295 0.189 11.7 -2.809  0.0161 
#  Mowing Amb - Grazing Wet   -0.2035 0.189 11.7 -1.080  0.3021 
#  Mowing Amb - Mowing Wet    -0.4874 0.161 12.0 -3.027  0.0105 
#  Fencing Wet - Grazing Wet   0.3260 0.189 11.7  1.729  0.1101 
#  Fencing Wet - Mowing Wet    0.0421 0.189 11.7  0.223  0.8272 
#  Grazing Wet - Mowing Wet   -0.2839 0.189 11.7 -1.506  0.1586 
# 
# Results are averaged over the levels of: Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$RA[srda_ann$Year==2018], list(srda_ann$Man[srda_ann$Year==2018]), mean)

#   Fencing   Grazing    Mowing 
# 0.4669171 0.4618154 0.4259017 

summary(emmeans(aov_ar_18, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate    SE df t.ratio p.value
#  Fencing - Grazing  -0.0377 0.135  4 -0.279  0.7942 
#  Fencing - Mowing    0.0358 0.135  4  0.265  0.8041 
#  Grazing - Mowing    0.0735 0.135  4  0.544  0.6154 
# 
# Results are averaged over the levels of: Precip, Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$RA[srda_ann$Year==2018], list(srda_ann$Precip[srda_ann$Year==2018]), mean)

#       Dry       Amb       Wet 
# 0.3563812 0.4091914 0.5890615 

summary(emmeans(aov_ar_18, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate    SE df t.ratio p.value
#  Dry - Amb  -0.0498 0.093 12 -0.535  0.6023 
#  Dry - Wet  -0.3946 0.093 12 -4.244  0.0011 
#  Amb - Wet  -0.3449 0.093 12 -3.709  0.0030 
# 
# Results are averaged over the levels of: Man, Date 
# Results are given on the log (not the response) scale. 

# R codes for analyzing the effects of land-use regimes  and altered precipitation
# amount on autotrophic component of soil respiration in 2019.
aov_ar_19 = aov(log(RA)~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda, Year=="2019"))
summary(aov_ar_19)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  1.567  0.7835               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)
# Man        2  2.558  1.2790   1.754  0.284
# Residuals  4  2.916  0.7291               
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2  78.38   39.19 152.359 2.96e-09 ***
# Man:Precip  4   0.42    0.10   0.408      0.8    
# Residuals  12   3.09    0.26                     
# ---
# Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq F value   Pr(>F)    
# Date             11 135.68  12.335  44.885  < 2e-16 ***
# Man:Date         22  38.16   1.734   6.311 1.00e-13 ***
# Precip:Date      22  18.06   0.821   2.987 2.63e-05 ***
# Man:Precip:Date  44  29.93   0.680   2.475 1.13e-05 ***
# Residuals       198  54.41   0.275                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$RA[srda_ann$Year==2019], list(srda_ann$Precip[srda_ann$Year==2019], srda_ann$Man[srda_ann$Year==2019]), mean)

#       Fencing   Grazing    Mowing
# Dry 0.3277429 0.2683290 0.3129952
# Amb 0.7717150 0.5760139 0.7048652
# Wet 0.9529204 0.9796451 0.8716664

summary(emmeans(aov_ar_19, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate    SE    df t.ratio p.value
#  Fencing Dry - Grazing Dry   0.1317 0.152  9.98   0.868 0.4058 
#  Fencing Dry - Mowing Dry    0.2601 0.152  9.98   1.714 0.1174 
#  Fencing Dry - Fencing Amb  -0.8566 0.120 12.00  -7.166 <.0001 
#  Fencing Dry - Grazing Amb  -0.6108 0.152  9.98  -4.025 0.0024 
#  Fencing Dry - Mowing Amb   -0.6351 0.152  9.98  -4.185 0.0019 
#  Fencing Dry - Fencing Wet  -1.1137 0.120 12.00  -9.316 <.0001 
#  Fencing Dry - Grazing Wet  -1.0486 0.152  9.98  -6.910 <.0001 
#  Fencing Dry - Mowing Wet   -0.9583 0.152  9.98  -6.315 0.0001 
#  Grazing Dry - Mowing Dry    0.1284 0.152  9.98   0.846 0.4174 
#  Grazing Dry - Fencing Amb  -0.9884 0.152  9.98  -6.513 0.0001 
#  Grazing Dry - Grazing Amb  -0.7425 0.120 12.00  -6.212 <.0001 
#  Grazing Dry - Mowing Amb   -0.7668 0.152  9.98  -5.053 0.0005 
#  Grazing Dry - Fencing Wet  -1.2454 0.152  9.98  -8.207 <.0001 
#  Grazing Dry - Grazing Wet  -1.1803 0.120 12.00  -9.874 <.0001 
#  Grazing Dry - Mowing Wet   -1.0900 0.152  9.98  -7.183 <.0001 
#  Mowing Dry - Fencing Amb   -1.1167 0.152  9.98  -7.359 <.0001 
#  Mowing Dry - Grazing Amb   -0.8709 0.152  9.98  -5.739 0.0002 
#  Mowing Dry - Mowing Amb    -0.8952 0.120 12.00  -7.489 <.0001 
#  Mowing Dry - Fencing Wet   -1.3738 0.152  9.98  -9.053 <.0001 
#  Mowing Dry - Grazing Wet   -1.3087 0.152  9.98  -8.624 <.0001 
#  Mowing Dry - Mowing Wet    -1.2183 0.120 12.00 -10.192 <.0001 
#  Fencing Amb - Grazing Amb   0.2458 0.152  9.98   1.620 0.1364 
#  Fencing Amb - Mowing Amb    0.2215 0.152  9.98   1.460 0.1751 
#  Fencing Amb - Fencing Wet  -0.2570 0.120 12.00  -2.150 0.0526 
#  Fencing Amb - Grazing Wet  -0.1920 0.152  9.98  -1.265 0.2346 
#  Fencing Amb - Mowing Wet   -0.1016 0.152  9.98  -0.670 0.5183 
#  Grazing Amb - Mowing Amb   -0.0243 0.152  9.98  -0.160 0.8761 
#  Grazing Amb - Fencing Wet  -0.5028 0.152  9.98  -3.314 0.0079 
#  Grazing Amb - Grazing Wet  -0.4378 0.120 12.00  -3.662 0.0033 
#  Grazing Amb - Mowing Wet   -0.3474 0.152  9.98  -2.289 0.0451 
#  Mowing Amb - Fencing Wet   -0.4786 0.152  9.98  -3.154 0.0103 
#  Mowing Amb - Grazing Wet   -0.4135 0.152  9.98  -2.725 0.0214 
#  Mowing Amb - Mowing Wet    -0.3232 0.120 12.00  -2.703 0.0192 
#  Fencing Wet - Grazing Wet   0.0651 0.152  9.98   0.429 0.6773 
#  Fencing Wet - Mowing Wet    0.1554 0.152  9.98   1.024 0.3300 
#  Grazing Wet - Mowing Wet    0.0904 0.152  9.98   0.595 0.5648 
# 
# Results are averaged over the levels of: Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$RA[srda_ann$Year==2019], list(srda_ann$Man[srda_ann$Year==2019]), mean)

#   Fencing   Grazing    Mowing 
# 0.6841261 0.6079960 0.6298422 

summary(emmeans(aov_ar_19, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate    SE df t.ratio p.value
#  Fencing - Grazing   0.1475 0.116  4 1.270   0.2731 
#  Fencing - Mowing    0.2123 0.116  4 1.827   0.1416 
#  Grazing - Mowing    0.0648 0.116  4 0.558   0.6067 
# 
# Results are averaged over the levels of: Precip, Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$RA[srda_ann$Year==2019], list(srda_ann$Precip[srda_ann$Year==2019]), mean)

#       Dry       Amb       Wet 
# 0.3030224 0.6841980 0.9347440 

summary(emmeans(aov_ar_19, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate    SE df t.ratio p.value
#  Dry - Amb   -0.831 0.069 12 -12.047 <.0001 
#  Dry - Wet   -1.171 0.069 12 -16.964 <.0001 
#  Amb - Wet   -0.339 0.069 12  -4.917 0.0004 
# 
# Results are averaged over the levels of: Man, Date 
# Results are given on the log (not the response) scale. 

# R codes for analyzing the effects of land-use regimes  and altered precipitation
# amount on autotrophic component of soil respiration during the overall 3 years.
aov_ar_oa = aov(log(RA)~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda))
summary(aov_ar_oa)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2 0.3452  0.1726               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)  
# Man        2 3.1157  1.5578   13.08 0.0176 *
# Residuals  4 0.4763  0.1191                 
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
# 
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2  95.56   47.78 153.275 2.86e-09 ***
# Man:Precip  4   1.72    0.43   1.379    0.299    
# Residuals  12   3.74    0.31                     
# ---
# Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

# Error: Within
#                  Df Sum Sq Mean Sq F value   Pr(>F)    
# Date             33  352.7  10.688  28.627  < 2e-16 ***
# Man:Date         66   61.1   0.926   2.479 9.59e-09 ***
# Precip:Date      66   62.8   0.952   2.549 3.13e-09 ***
# Man:Precip:Date 132   67.5   0.512   1.370  0.00781 ** 
# Residuals       594  221.8   0.373                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$RA, list(srda_ann$Precip, srda_ann$Man), mean)

#       Fencing   Grazing    Mowing
# Dry 0.3853078 0.2983563 0.3064960
# Amb 0.5669108 0.5827494 0.5490439
# Wet 0.8076614 0.7859283 0.7160319

summary(emmeans(aov_ar_oa, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate     SE   df t.ratio p.value
#  Fencing Dry - Grazing Dry   0.1669 0.0697 15.3   2.396 0.0297 
#  Fencing Dry - Mowing Dry    0.2479 0.0697 15.3   3.559 0.0028 
#  Fencing Dry - Fencing Amb  -0.3485 0.0782 12.0  -4.457 0.0008 
#  Fencing Dry - Grazing Amb  -0.3783 0.0697 15.3  -5.431 0.0001 
#  Fencing Dry - Mowing Amb   -0.2796 0.0697 15.3  -4.013 0.0011 
#  Fencing Dry - Fencing Wet  -0.7272 0.0782 12.0  -9.302 <.0001 
#  Fencing Dry - Grazing Wet  -0.5898 0.0697 15.3  -8.467 <.0001 
#  Fencing Dry - Mowing Wet   -0.6222 0.0697 15.3  -8.932 <.0001 
#  Grazing Dry - Mowing Dry    0.0810 0.0697 15.3   1.163 0.2628 
#  Grazing Dry - Fencing Amb  -0.5154 0.0697 15.3  -7.398 <.0001 
#  Grazing Dry - Grazing Amb  -0.5452 0.0782 12.0  -6.974 <.0001 
#  Grazing Dry - Mowing Amb   -0.4465 0.0697 15.3  -6.409 <.0001 
#  Grazing Dry - Fencing Wet  -0.8941 0.0697 15.3 -12.835 <.0001 
#  Grazing Dry - Grazing Wet  -0.7568 0.0782 12.0  -9.679 <.0001 
#  Grazing Dry - Mowing Wet   -0.7892 0.0697 15.3 -11.328 <.0001 
#  Mowing Dry - Fencing Amb   -0.5964 0.0697 15.3  -8.561 <.0001 
#  Mowing Dry - Grazing Amb   -0.6262 0.0697 15.3  -8.989 <.0001 
#  Mowing Dry - Mowing Amb    -0.5275 0.0782 12.0  -6.747 <.0001 
#  Mowing Dry - Fencing Wet   -0.9751 0.0697 15.3 -13.997 <.0001 
#  Mowing Dry - Grazing Wet   -0.8377 0.0697 15.3 -12.025 <.0001 
#  Mowing Dry - Mowing Wet    -0.8701 0.0782 12.0 -11.130 <.0001 
#  Fencing Amb - Grazing Amb  -0.0299 0.0697 15.3  -0.429 0.6742 
#  Fencing Amb - Mowing Amb    0.0689 0.0697 15.3   0.989 0.3382 
#  Fencing Amb - Fencing Wet  -0.3788 0.0782 12.0  -4.845 0.0004 
#  Fencing Amb - Grazing Wet  -0.2414 0.0697 15.3  -3.465 0.0034 
#  Fencing Amb - Mowing Wet   -0.2738 0.0697 15.3  -3.930 0.0013 
#  Grazing Amb - Mowing Amb    0.0987 0.0697 15.3   1.417 0.1764 
#  Grazing Amb - Fencing Wet  -0.3489 0.0697 15.3  -5.008 0.0001 
#  Grazing Amb - Grazing Wet  -0.2115 0.0782 12.0  -2.705 0.0191 
#  Grazing Amb - Mowing Wet   -0.2439 0.0697 15.3  -3.501 0.0031 
#  Mowing Amb - Fencing Wet   -0.4476 0.0697 15.3  -6.425 <.0001 
#  Mowing Amb - Grazing Wet   -0.3102 0.0697 15.3  -4.453 0.0004 
#  Mowing Amb - Mowing Wet    -0.3426 0.0782 12.0  -4.383 0.0009 
#  Fencing Wet - Grazing Wet   0.1374 0.0697 15.3   1.972 0.0669 
#  Fencing Wet - Mowing Wet    0.1050 0.0697 15.3   1.507 0.1521 
#  Grazing Wet - Mowing Wet   -0.0324 0.0697 15.3  -0.465 0.6484 
# 
# Results are averaged over the levels of: Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$RA, list(srda_ann$Man), mean)

#   Fencing   Grazing    Mowing 
# 0.5866267 0.5556780 0.5238573 

summary(emmeans(aov_ar_oa, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate     SE df t.ratio p.value
#  Fencing - Grazing   0.0915 0.0279  4 3.279   0.0305 
#  Fencing - Mowing    0.1406 0.0279  4 5.040   0.0073 
#  Grazing - Mowing    0.0491 0.0279  4 1.760   0.1532 
# 
# Results are averaged over the levels of: Precip, Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$RA, list(srda_ann$Precip), mean)

#       Dry       Amb       Wet 
# 0.3300534 0.5662347 0.7698738 

summary(emmeans(aov_ar_oa, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate     SE df t.ratio p.value
#  Dry - Amb   -0.474 0.0451 12 -10.495 <.0001 
#  Dry - Wet   -0.785 0.0451 12 -17.384 <.0001 
#  Amb - Wet   -0.311 0.0451 12  -6.889 <.0001 
# 
# Results are averaged over the levels of: Man, Date 
# Results are given on the log (not the response) scale. 

######################################################################################
# The following codes and results were used to analyze the effects of land-use regimes
# and altered precipitation amount on heterotrophic component of soil respiration in 
# 2017, 2018, 2019 and during the overall 3 years of our experiment.##################

# R codes for analyzing the effects of land-use regimes  and altered precipitation
# amount on heterotrophic component of soil respiration in 2017.
aov_hr_17 = aov(log(RH)~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda, Year=="2017"))
summary(aov_hr_17)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2  1.204   0.602               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)
# Man        2  1.302  0.6508   3.823  0.118
# Residuals  4  0.681  0.1703               
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2 21.716  10.858 509.903 2.47e-12 ***
# Man:Precip  4  0.286   0.071   3.357   0.0461 *  
# Residuals  12  0.256   0.021                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq F value Pr(>F)    
# Date             10  54.89   5.489  67.150 <2e-16 ***
# Man:Date         20   1.70   0.085   1.039  0.419    
# Precip:Date      20   1.61   0.080   0.983  0.485    
# Man:Precip:Date  40   1.36   0.034   0.417  0.999    
# Residuals       180  14.71   0.082                   
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$RH[srda_ann$Year==2017], list(srda_ann$Precip[srda_ann$Year==2017], srda_ann$Man[srda_ann$Year==2017]), mean)

#      Fencing   Grazing    Mowing
# Dry 0.802611 0.6438423 0.6403679
# Amb 1.190235 1.0607984 1.0587810
# Wet 1.410493 1.3697521 1.3165494

summary(emmeans(aov_hr_17, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate     SE    df t.ratio p.value
#  Fencing Dry - Grazing Dry  0.22837 0.0656  6.12   3.483 0.0127 
#  Fencing Dry - Mowing Dry   0.21993 0.0656  6.12   3.354 0.0149 
#  Fencing Dry - Fencing Amb -0.38112 0.0359 12.00 -10.609 <.0001 
#  Fencing Dry - Grazing Amb -0.25619 0.0656  6.12  -3.907 0.0076 
#  Fencing Dry - Mowing Amb  -0.24220 0.0656  6.12  -3.694 0.0098 
#  Fencing Dry - Fencing Wet -0.54193 0.0359 12.00 -15.085 <.0001 
#  Fencing Dry - Grazing Wet -0.48247 0.0656  6.12  -7.358 0.0003 
#  Fencing Dry - Mowing Wet  -0.47141 0.0656  6.12  -7.189 0.0003 
#  Grazing Dry - Mowing Dry  -0.00845 0.0656  6.12  -0.129 0.9016 
#  Grazing Dry - Fencing Amb -0.60949 0.0656  6.12  -9.295 0.0001 
#  Grazing Dry - Grazing Amb -0.48456 0.0359 12.00 -13.488 <.0001 
#  Grazing Dry - Mowing Amb  -0.47057 0.0656  6.12  -7.176 0.0003 
#  Grazing Dry - Fencing Wet -0.77030 0.0656  6.12 -11.747 <.0001 
#  Grazing Dry - Grazing Wet -0.71084 0.0359 12.00 -19.787 <.0001 
#  Grazing Dry - Mowing Wet  -0.69978 0.0656  6.12 -10.672 <.0001 
#  Mowing Dry - Fencing Amb  -0.60104 0.0656  6.12  -9.166 0.0001 
#  Mowing Dry - Grazing Amb  -0.47611 0.0656  6.12  -7.261 0.0003 
#  Mowing Dry - Mowing Amb   -0.46212 0.0359 12.00 -12.864 <.0001 
#  Mowing Dry - Fencing Wet  -0.76185 0.0656  6.12 -11.618 <.0001 
#  Mowing Dry - Grazing Wet  -0.70239 0.0656  6.12 -10.711 <.0001 
#  Mowing Dry - Mowing Wet   -0.69133 0.0359 12.00 -19.244 <.0001 
#  Fencing Amb - Grazing Amb  0.12493 0.0656  6.12   1.905 0.1044 
#  Fencing Amb - Mowing Amb   0.13892 0.0656  6.12   2.119 0.0775 
#  Fencing Amb - Fencing Wet -0.16081 0.0359 12.00  -4.476 0.0008 
#  Fencing Amb - Grazing Wet -0.10135 0.0656  6.12  -1.546 0.1722 
#  Fencing Amb - Mowing Wet  -0.09029 0.0656  6.12  -1.377 0.2167 
#  Grazing Amb - Mowing Amb   0.01399 0.0656  6.12   0.213 0.8380 
#  Grazing Amb - Fencing Wet -0.28574 0.0656  6.12  -4.358 0.0046 
#  Grazing Amb - Grazing Wet -0.22628 0.0359 12.00  -6.299 <.0001 
#  Grazing Amb - Mowing Wet  -0.21522 0.0656  6.12  -3.282 0.0163 
#  Mowing Amb - Fencing Wet  -0.29973 0.0656  6.12  -4.571 0.0036 
#  Mowing Amb - Grazing Wet  -0.24027 0.0656  6.12  -3.664 0.0102 
#  Mowing Amb - Mowing Wet   -0.22921 0.0359 12.00  -6.380 <.0001 
#  Fencing Wet - Grazing Wet  0.05946 0.0656  6.12   0.907 0.3988 
#  Fencing Wet - Mowing Wet   0.07052 0.0656  6.12   1.075 0.3227 
#  Grazing Wet - Mowing Wet   0.01106 0.0656  6.12   0.169 0.8715 
# 
# Results are averaged over the levels of: Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$RH[srda_ann$Year==2017], list(srda_ann$Man[srda_ann$Year==2017]), mean)

#  Fencing  Grazing   Mowing 
# 1.134446 1.024798 1.005233 

summary(emmeans(aov_hr_17, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate     SE df t.ratio p.value
#  Fencing - Grazing  0.13759 0.0586  4 2.346   0.0789 
#  Fencing - Mowing   0.14312 0.0586  4 2.440   0.0712 
#  Grazing - Mowing   0.00553 0.0586  4 0.094   0.9294 
# 
# Results are averaged over the levels of: Precip, Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$RH[srda_ann$Year==2017], list(srda_ann$Precip[srda_ann$Year==2017]), mean)

#       Dry       Amb       Wet 
# 0.6956071 1.1032713 1.3655981 

summary(emmeans(aov_hr_17, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate     SE df t.ratio p.value
#  Dry - Amb   -0.443 0.0207 12 -21.340 <.0001 
#  Dry - Wet   -0.648 0.0207 12 -31.245 <.0001 
#  Amb - Wet   -0.205 0.0207 12  -9.905 <.0001 
# 
# Results are averaged over the levels of: Man, Date 
# Results are given on the log (not the response) scale. 

# R codes for analyzing the effects of land-use regimes  and altered precipitation
# amount on heterotrophic component of soil respiration in 2018.
aov_hr_18 = aov(log(RH)~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda, Year=="2018"))
summary(aov_hr_18)

# Results of analysis
#
# Error: Block
#           Df  Sum Sq Mean Sq F value Pr(>F)
# Residuals  2 0.03896 0.01948               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)  
# Man        2 0.4797 0.23984   10.07 0.0274 *
# Residuals  4 0.0952 0.02381                 
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2 22.927  11.464 532.203 1.92e-12 ***
# Man:Precip  4  0.150   0.038   1.742    0.205    
# Residuals  12  0.258   0.022                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq F value   Pr(>F)    
# Date             10  95.07   9.507 283.533  < 2e-16 ***
# Man:Date         20   5.74   0.287   8.558  < 2e-16 ***
# Precip:Date      20   2.75   0.138   4.108 1.29e-07 ***
# Man:Precip:Date  40   2.34   0.059   1.746  0.00753 ** 
# Residuals       180   6.04   0.034                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$RH[srda_ann$Year==2018], list(srda_ann$Precip[srda_ann$Year==2018], srda_ann$Man[srda_ann$Year==2018]), mean)

#       Fencing   Grazing    Mowing
# Dry 0.8158751 0.9210845 0.8608663
# Amb 1.3063541 1.4140887 1.3100890
# Wet 1.5778528 1.8571080 1.5542941

summary(emmeans(aov_hr_18, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate     SE   df t.ratio p.value
#  Fencing Dry - Grazing Dry  -0.0326 0.0368 15.1  -0.886 0.3895 
#  Fencing Dry - Mowing Dry    0.0286 0.0368 15.1   0.779 0.4480 
#  Fencing Dry - Fencing Amb  -0.4573 0.0361 12.0 -12.656 <.0001 
#  Fencing Dry - Grazing Amb  -0.4739 0.0368 15.1 -12.893 <.0001 
#  Fencing Dry - Mowing Amb   -0.4113 0.0368 15.1 -11.188 <.0001 
#  Fencing Dry - Fencing Wet  -0.6515 0.0361 12.0 -18.032 <.0001 
#  Fencing Dry - Grazing Wet  -0.7639 0.0368 15.1 -20.781 <.0001 
#  Fencing Dry - Mowing Wet   -0.5929 0.0368 15.1 -16.129 <.0001 
#  Grazing Dry - Mowing Dry    0.0612 0.0368 15.1   1.665 0.1165 
#  Grazing Dry - Fencing Amb  -0.4247 0.0368 15.1 -11.553 <.0001 
#  Grazing Dry - Grazing Amb  -0.4414 0.0361 12.0 -12.216 <.0001 
#  Grazing Dry - Mowing Amb   -0.3787 0.0368 15.1 -10.302 <.0001 
#  Grazing Dry - Fencing Wet  -0.6190 0.0368 15.1 -16.838 <.0001 
#  Grazing Dry - Grazing Wet  -0.7314 0.0361 12.0 -20.242 <.0001 
#  Grazing Dry - Mowing Wet   -0.5603 0.0368 15.1 -15.243 <.0001 
#  Mowing Dry - Fencing Amb   -0.4859 0.0368 15.1 -13.218 <.0001 
#  Mowing Dry - Grazing Amb   -0.5026 0.0368 15.1 -13.672 <.0001 
#  Mowing Dry - Mowing Amb    -0.4399 0.0361 12.0 -12.176 <.0001 
#  Mowing Dry - Fencing Wet   -0.6802 0.0368 15.1 -18.502 <.0001 
#  Mowing Dry - Grazing Wet   -0.7926 0.0368 15.1 -21.560 <.0001 
#  Mowing Dry - Mowing Wet    -0.6216 0.0361 12.0 -17.203 <.0001 
#  Fencing Amb - Grazing Amb  -0.0167 0.0368 15.1  -0.453 0.6567 
#  Fencing Amb - Mowing Amb    0.0460 0.0368 15.1   1.251 0.2300 
#  Fencing Amb - Fencing Wet  -0.1943 0.0361 12.0  -5.377 0.0002 
#  Fencing Amb - Grazing Wet  -0.3067 0.0368 15.1  -8.342 <.0001 
#  Fencing Amb - Mowing Wet   -0.1356 0.0368 15.1  -3.690 0.0022 
#  Grazing Amb - Mowing Amb    0.0627 0.0368 15.1   1.704 0.1088 
#  Grazing Amb - Fencing Wet  -0.1776 0.0368 15.1  -4.831 0.0002 
#  Grazing Amb - Grazing Wet  -0.2900 0.0361 12.0  -8.026 <.0001 
#  Grazing Amb - Mowing Wet   -0.1190 0.0368 15.1  -3.236 0.0055 
#  Mowing Amb - Fencing Wet   -0.2402 0.0368 15.1  -6.535 <.0001 
#  Mowing Amb - Grazing Wet   -0.3526 0.0368 15.1  -9.593 <.0001 
#  Mowing Amb - Mowing Wet    -0.1816 0.0361 12.0  -5.027 0.0003 
#  Fencing Wet - Grazing Wet  -0.1124 0.0368 15.1  -3.057 0.0079 
#  Fencing Wet - Mowing Wet    0.0586 0.0368 15.1   1.594 0.1315 
#  Grazing Wet - Mowing Wet    0.1710 0.0368 15.1   4.652 0.0003 
# 
# Results are averaged over the levels of: Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$RH[srda_ann$Year==2018], list(srda_ann$Man[srda_ann$Year==2018]), mean)

#  Fencing  Grazing   Mowing 
# 1.233361 1.397427 1.241750 

summary(emmeans(aov_hr_18, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate     SE df t.ratio p.value
#  Fencing - Grazing  -0.0539 0.0219  4 -2.456  0.0700 
#  Fencing - Mowing    0.0444 0.0219  4  2.025  0.1129 
#  Grazing - Mowing    0.0983 0.0219  4  4.481  0.0110 
# 
# Results are averaged over the levels of: Precip, Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$RH[srda_ann$Year==2018], list(srda_ann$Precip[srda_ann$Year==2018]), mean)

#      Dry      Amb      Wet 
# 0.865942 1.343511 1.663085 

summary(emmeans(aov_hr_18, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate     SE df t.ratio p.value
#  Dry - Amb   -0.446 0.0209 12 -21.389 <.0001 
#  Dry - Wet   -0.668 0.0209 12 -32.030 <.0001 
#  Amb - Wet   -0.222 0.0209 12 -10.640 <.0001 
# 
# Results are averaged over the levels of: Man, Date 
# Results are given on the log (not the response) scale. 

# R codes for analyzing the effects of land-use regimes  and altered precipitation
# amount on heterotrophic component of soil respiration in 2019.
aov_hr_19 = aov(log(RH)~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda, Year=="2019"))
summary(aov_hr_19)

# Results of analysis
#
# Error: Block
#           Df  Sum Sq Mean Sq F value Pr(>F)
# Residuals  2 0.06634 0.03317               
#
# Error: Block:Man
#           Df  Sum Sq Mean Sq F value Pr(>F)  
# Man        2 0.27532 0.13766   8.337 0.0374 *
# Residuals  4 0.06605 0.01651                 
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq F value   Pr(>F)    
# Precip      2 16.628   8.314 505.493 2.61e-12 ***
# Man:Precip  4  0.063   0.016   0.953    0.467    
# Residuals  12  0.197   0.016                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq F value   Pr(>F)    
# Date             11  49.01   4.456 239.796  < 2e-16 ***
# Man:Date         22   1.64   0.075   4.024 5.57e-08 ***
# Precip:Date      22   1.13   0.051   2.755 0.000102 ***
# Man:Precip:Date  44   1.87   0.043   2.293 5.69e-05 ***
# Residuals       198   3.68   0.019                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$RH[srda_ann$Year==2019], list(srda_ann$Precip[srda_ann$Year==2019], srda_ann$Man[srda_ann$Year==2019]), mean)

#       Fencing   Grazing    Mowing
# Dry 0.9080904 0.8775043 0.8450604
# Amb 1.2134239 1.1978750 1.1863848
# Wet 1.5836768 1.5693827 1.4376391

summary(emmeans(aov_hr_19, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate     SE   df t.ratio p.value
#  Fencing Dry - Grazing Dry  0.04860 0.0302 15.4   1.607 0.1284 
#  Fencing Dry - Mowing Dry   0.08178 0.0302 15.4   2.704 0.0160 
#  Fencing Dry - Fencing Amb -0.27888 0.0302 12.0  -9.226 <.0001 
#  Fencing Dry - Grazing Amb -0.26790 0.0302 15.4  -8.857 <.0001 
#  Fencing Dry - Mowing Amb  -0.23828 0.0302 15.4  -7.878 <.0001 
#  Fencing Dry - Fencing Wet -0.53576 0.0302 12.0 -17.724 <.0001 
#  Fencing Dry - Grazing Wet -0.54350 0.0302 15.4 -17.968 <.0001 
#  Fencing Dry - Mowing Wet  -0.45223 0.0302 15.4 -14.951 <.0001 
#  Grazing Dry - Mowing Dry   0.03318 0.0302 15.4   1.097 0.2895 
#  Grazing Dry - Fencing Amb -0.32749 0.0302 15.4 -10.827 <.0001 
#  Grazing Dry - Grazing Amb -0.31650 0.0302 12.0 -10.470 <.0001 
#  Grazing Dry - Mowing Amb  -0.28689 0.0302 15.4  -9.484 <.0001 
#  Grazing Dry - Fencing Wet -0.58437 0.0302 15.4 -19.319 <.0001 
#  Grazing Dry - Grazing Wet -0.59210 0.0302 12.0 -19.588 <.0001 
#  Grazing Dry - Mowing Wet  -0.50083 0.0302 15.4 -16.557 <.0001 
#  Mowing Dry - Fencing Amb  -0.36067 0.0302 15.4 -11.924 <.0001 
#  Mowing Dry - Grazing Amb  -0.34968 0.0302 15.4 -11.560 <.0001 
#  Mowing Dry - Mowing Amb   -0.32007 0.0302 12.0 -10.588 <.0001 
#  Mowing Dry - Fencing Wet  -0.61755 0.0302 15.4 -20.416 <.0001 
#  Mowing Dry - Grazing Wet  -0.62528 0.0302 15.4 -20.672 <.0001 
#  Mowing Dry - Mowing Wet   -0.53401 0.0302 12.0 -17.666 <.0001 
#  Fencing Amb - Grazing Amb  0.01099 0.0302 15.4   0.363 0.7214 
#  Fencing Amb - Mowing Amb   0.04060 0.0302 15.4   1.342 0.1989 
#  Fencing Amb - Fencing Wet -0.25688 0.0302 12.0  -8.498 <.0001 
#  Fencing Amb - Grazing Wet -0.26462 0.0302 15.4  -8.748 <.0001 
#  Fencing Amb - Mowing Wet  -0.17334 0.0302 15.4  -5.731 <.0001 
#  Grazing Amb - Mowing Amb   0.02961 0.0302 15.4   0.979 0.3427 
#  Grazing Amb - Fencing Wet -0.26787 0.0302 15.4  -8.856 <.0001 
#  Grazing Amb - Grazing Wet -0.27560 0.0302 12.0  -9.117 <.0001 
#  Grazing Amb - Mowing Wet  -0.18433 0.0302 15.4  -6.094 <.0001 
#  Mowing Amb - Fencing Wet  -0.29748 0.0302 15.4  -9.835 <.0001 
#  Mowing Amb - Grazing Wet  -0.30522 0.0302 15.4 -10.091 <.0001 
#  Mowing Amb - Mowing Wet   -0.21394 0.0302 12.0  -7.078 <.0001 
#  Fencing Wet - Grazing Wet -0.00774 0.0302 15.4  -0.256 0.8015 
#  Fencing Wet - Mowing Wet   0.08354 0.0302 15.4   2.762 0.0143 
#  Grazing Wet - Mowing Wet   0.09127 0.0302 15.4   3.018 0.0084 
# 
# Results are averaged over the levels of: Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$RH[srda_ann$Year==2019], list(srda_ann$Man[srda_ann$Year==2019]), mean)

#  Fencing  Grazing   Mowing 
# 1.235064 1.214921 1.156361 

summary(emmeans(aov_hr_19, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate     SE df t.ratio p.value
#  Fencing - Grazing   0.0173 0.0175  4 0.988   0.3789 
#  Fencing - Mowing    0.0686 0.0175  4 3.925   0.0172 
#  Grazing - Mowing    0.0514 0.0175  4 2.937   0.0425 
# 
# Results are averaged over the levels of: Precip, Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$RH[srda_ann$Year==2019], list(srda_ann$Precip[srda_ann$Year==2019]), mean)

#      Dry      Amb      Wet 
# 0.876885 1.199228 1.530233 

summary(emmeans(aov_hr_19, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate     SE df t.ratio p.value
#  Dry - Amb   -0.305 0.0175 12 -17.485 <.0001 
#  Dry - Wet   -0.554 0.0175 12 -31.741 <.0001 
#  Amb - Wet   -0.249 0.0175 12 -14.257 <.0001 
# 
# Results are averaged over the levels of: Man, Date 
# Results are given on the log (not the response) scale. 

# R codes for analyzing the effects of land-use regimes  and altered precipitation
# amount on heterotrophic component of soil respiration during the overall 3 years.
aov_hr_oa = aov(log(RH)~Man*Precip*Date+Error(Block/Man/Precip), data=subset(srda))
summary(aov_hr_oa)

# Results of analysis
#
# Error: Block
#           Df Sum Sq Mean Sq F value Pr(>F)
# Residuals  2 0.1887 0.09434               
#
# Error: Block:Man
#           Df Sum Sq Mean Sq F value Pr(>F)  
# Man        2 1.1203  0.5602   6.665 0.0533 .
# Residuals  4 0.3362  0.0840                 
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Block:Man:Precip
#            Df Sum Sq Mean Sq  F value   Pr(>F)    
# Precip      2  60.53  30.263 1310.285 8.97e-15 ***
# Man:Precip  4   0.28   0.071    3.066    0.059 .  
# Residuals  12   0.28   0.023                      
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Error: Within
#                  Df Sum Sq Mean Sq F value   Pr(>F)    
# Date             33 204.90   6.209 139.230  < 2e-16 ***
# Man:Date         66  10.02   0.152   3.404 1.77e-15 ***
# Precip:Date      66   6.23   0.094   2.117 2.57e-06 ***
# Man:Precip:Date 132   5.79   0.044   0.984    0.535    
# Residuals       594  26.49   0.045                     
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1

tapply(srda_ann$RH, list(srda_ann$Precip, srda_ann$Man), mean)

#       Fencing   Grazing    Mowing
# Dry 0.8421922 0.8141437 0.7820982
# Amb 1.2366708 1.2242540 1.1850849
# Wet 1.5240074 1.5987476 1.4361609

summary(emmeans(aov_hr_oa, list(pairwise~Man+Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man, Precip`
#  1                         estimate     SE    df t.ratio p.value
#  Fencing Dry - Grazing Dry   0.0805 0.0292  8.73   2.759 0.0228 
#  Fencing Dry - Mowing Dry    0.1093 0.0292  8.73   3.746 0.0048 
#  Fencing Dry - Fencing Amb  -0.3697 0.0213 12.00 -17.371 <.0001 
#  Fencing Dry - Grazing Amb  -0.3308 0.0292  8.73 -11.337 <.0001 
#  Fencing Dry - Mowing Amb   -0.2955 0.0292  8.73 -10.129 <.0001 
#  Fencing Dry - Fencing Wet  -0.5752 0.0213 12.00 -27.029 <.0001 
#  Fencing Dry - Grazing Wet  -0.5951 0.0292  8.73 -20.396 <.0001 
#  Fencing Dry - Mowing Wet   -0.5040 0.0292  8.73 -17.273 <.0001 
#  Grazing Dry - Mowing Dry    0.0288 0.0292  8.73   0.986 0.3505 
#  Grazing Dry - Fencing Amb  -0.4502 0.0292  8.73 -15.430 <.0001 
#  Grazing Dry - Grazing Amb  -0.4113 0.0213 12.00 -19.326 <.0001 
#  Grazing Dry - Mowing Amb   -0.3760 0.0292  8.73 -12.888 <.0001 
#  Grazing Dry - Fencing Wet  -0.6557 0.0292  8.73 -22.475 <.0001 
#  Grazing Dry - Grazing Wet  -0.6756 0.0213 12.00 -31.745 <.0001 
#  Grazing Dry - Mowing Wet   -0.5845 0.0292  8.73 -20.032 <.0001 
#  Mowing Dry - Fencing Amb   -0.4790 0.0292  8.73 -16.416 <.0001 
#  Mowing Dry - Grazing Amb   -0.4401 0.0292  8.73 -15.083 <.0001 
#  Mowing Dry - Mowing Amb    -0.4048 0.0213 12.00 -19.022 <.0001 
#  Mowing Dry - Fencing Wet   -0.6845 0.0292  8.73 -23.461 <.0001 
#  Mowing Dry - Grazing Wet   -0.7043 0.0292  8.73 -24.142 <.0001 
#  Mowing Dry - Mowing Wet    -0.6132 0.0213 12.00 -28.816 <.0001 
#  Fencing Amb - Grazing Amb   0.0389 0.0292  8.73   1.333 0.2161 
#  Fencing Amb - Mowing Amb    0.0742 0.0292  8.73   2.542 0.0324 
#  Fencing Amb - Fencing Wet  -0.2055 0.0213 12.00  -9.658 <.0001 
#  Fencing Amb - Grazing Wet  -0.2254 0.0292  8.73  -7.725 <.0001 
#  Fencing Amb - Mowing Wet   -0.1343 0.0292  8.73  -4.602 0.0014 
#  Grazing Amb - Mowing Amb    0.0352 0.0292  8.73   1.208 0.2587 
#  Grazing Amb - Fencing Wet  -0.2444 0.0292  8.73  -8.378 <.0001 
#  Grazing Amb - Grazing Wet  -0.2643 0.0213 12.00 -12.419 <.0001 
#  Grazing Amb - Mowing Wet   -0.1732 0.0292  8.73  -5.936 0.0002 
#  Mowing Amb - Fencing Wet   -0.2797 0.0292  8.73  -9.587 <.0001 
#  Mowing Amb - Grazing Wet   -0.2995 0.0292  8.73 -10.267 <.0001 
#  Mowing Amb - Mowing Wet    -0.2084 0.0213 12.00  -9.794 <.0001 
#  Fencing Wet - Grazing Wet  -0.0199 0.0292  8.73  -0.681 0.5138 
#  Fencing Wet - Mowing Wet    0.0713 0.0292  8.73   2.443 0.0380 
#  Grazing Wet - Mowing Wet    0.0911 0.0292  8.73   3.123 0.0127 
# 
# Results are averaged over the levels of: Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$RH, list(srda_ann$Man), mean)

#  Fencing  Grazing   Mowing 
# 1.200957 1.212382 1.134448 

summary(emmeans(aov_hr_oa, list(pairwise~Man)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Man`
#  1                 estimate     SE df t.ratio p.value
#  Fencing - Grazing   0.0332 0.0234  4 1.416   0.2297 
#  Fencing - Mowing    0.0849 0.0234  4 3.622   0.0223 
#  Grazing - Mowing    0.0517 0.0234  4 2.207   0.0920 
# 
# Results are averaged over the levels of: Precip, Date 
# Results are given on the log (not the response) scale. 

tapply(srda_ann$RH, list(srda_ann$Precip), mean)

#       Dry       Amb       Wet 
# 0.8128114 1.2153366 1.5196386 

summary(emmeans(aov_hr_oa, list(pairwise~Precip)), alpha=0.10, level=0.10, adjust="none")

# $`pairwise differences of Precip`
#  1         estimate     SE df t.ratio p.value
#  Dry - Amb   -0.395 0.0123 12 -32.169 <.0001 
#  Dry - Wet   -0.621 0.0123 12 -50.571 <.0001 
#  Amb - Wet   -0.226 0.0123 12 -18.401 <.0001 
# 
# Results are averaged over the levels of: Man, Date 
# Results are given on the log (not the response) scale. 

#####################################################################################
#####################################################################################

#####################################################################################
# Codes of the following part is used to analyze the linear relationships between
# aboveground and belowground net primary productivity, as well as microbial biomass 
# carbon and nitrogen with soil temperature and moisture.
# Results of these analyses can also be found in Figure S6.
#####################################################################################

# R codes for analyzing the effect of ST on ANPP.
summary(lm(ANPP~ST, data=srda_ann))

# Results of analysis
#
# Call:
#   lm(formula = ANPP ~ ST, data = srda_ann)
#
# Residuals:
#     Min      1Q  Median      3Q     Max 
# -74.383 -36.449   1.625  26.649  99.746 
#
# Coefficients:
#              Estimate Std. Error t value Pr(>|t|)   
# (Intercept)  205.554     62.547   3.286  0.00152 **
# ST            -8.418      3.894  -2.162  0.03368 * 
#   ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Residual standard error: 41.45 on 79 degrees of freedom
# Multiple R-squared:  0.05584,	Adjusted R-squared:  0.04389 
# F-statistic: 4.672 on 1 and 79 DF,  p-value: 0.03368

# R codes for analyzing the effect of ST on ANPP in 2019.
summary(lm(ANPP~ST, data=subset(srda_ann, Year=="2019")))

# Results of analysis
#
# Call:
# lm(formula = ANPP ~ ST, data = subset(srda_ann, Year == "2019"))
# 
# Residuals:
#     Min      1Q  Median      3Q     Max 
# -69.283 -29.672   2.193  29.847  66.334 
# 
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)   
# (Intercept)  308.493    101.479   3.040  0.00548 **
# ST           -15.647      6.565  -2.383  0.02507 * 
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Residual standard error: 39.54 on 25 degrees of freedom
# Multiple R-squared:  0.1851,	Adjusted R-squared:  0.1525 
# F-statistic:  5.68 on 1 and 25 DF,  p-value: 0.02507

# R codes for analyzing the effect of ST on BNPP.
summary(lm(BNPP~ST, data=srda_ann))

# Results of analysis
# Call:
# lm(formula = BNPP ~ ST, data = srda_ann)
# 
# Residuals:
#     Min      1Q  Median      3Q     Max 
# -33.800  -6.819   1.263   9.872  23.966 
# 
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  165.079     22.491   7.340 1.42e-09 ***
# ST            -5.364      1.401  -3.828 0.000349 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Residual standard error: 12.22 on 52 degrees of freedom
#   (27 observations deleted due to missingness)
# Multiple R-squared:  0.2198,	Adjusted R-squared:  0.2048 
# F-statistic: 14.65 on 1 and 52 DF,  p-value: 0.000349

# R codes for analyzing the effect of ST on BNPP in 2019.
summary(lm(BNPP~ST, data=subset(srda_ann, Year=="2019")))

# Results of analysis
#
# Call:
# lm(formula = BNPP ~ ST, data = subset(srda_ann, Year == "2019"))
# 
# Residuals:
#      Min       1Q   Median       3Q      Max 
# -22.4670  -5.7005  -0.1657   6.9697  12.9817 
# 
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  150.113     23.533   6.379 1.12e-06 ***
# ST            -4.315      1.522  -2.834  0.00896 ** 
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Residual standard error: 9.17 on 25 degrees of freedom
# Multiple R-squared:  0.2432,	Adjusted R-squared:  0.2129 
# F-statistic: 8.032 on 1 and 25 DF,  p-value: 0.008962

# R codes for analyzing the effect of ST on MBC
summary(lm(MBC~ST, data=srda_ann))

# Results of analysis
#
# Call:
#   lm(formula = MBC ~ ST, data = srda_ann)
#
# Residuals:
#   Min      1Q  Median      3Q     Max 
# -57.551  -8.092  -1.223  16.671  37.779 
#
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  313.095     60.838   5.146 2.55e-05 ***
# ST           -10.938      3.936  -2.779   0.0102 *  
#   ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Residual standard error: 23.71 on 25 degrees of freedom
# (54 observations deleted due to missingness)
# Multiple R-squared:  0.236,	Adjusted R-squared:  0.2055 
# F-statistic: 7.723 on 1 and 25 DF,  p-value: 0.0102

# R codes for analyzing the effect of ST on MBN
summary(lm(MBN~ST, data=srda_ann))

# Results of analysis
#
# Call:
#   lm(formula = MBN ~ ST, data = srda_ann)
#
# Residuals:
#     Min      1Q  Median      3Q     Max 
# -15.607  -3.326   0.340   4.252  12.414 
#
# Coefficients:
#              Estimate Std. Error t value Pr(>|t|)   
# (Intercept)   51.461     17.234   2.986  0.00624 **
# ST            -1.726      1.115  -1.548  0.13422   
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Residual standard error: 6.715 on 25 degrees of freedom
# (54 observations deleted due to missingness)
# Multiple R-squared:  0.08746,	Adjusted R-squared:  0.05095 
# F-statistic: 2.396 on 1 and 25 DF,  p-value: 0.1342

# R codes for analyzing the effect of SM on ANPP
summary(lm(ANPP~SM, data=srda_ann))

# Results of analysis
#
# Call:
#   lm(formula = ANPP ~ SM, data = srda_ann)
#
# Residuals:
#     Min      1Q  Median      3Q     Max 
# -78.171 -22.014   1.924  23.828  65.637 
#
# Coefficients:
#               Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  -31.811     12.860  -2.474   0.0155 *  
# SM            11.112      1.342   8.280 2.48e-12 ***
#   ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Residual standard error: 31.21 on 79 degrees of freedom
# Multiple R-squared:  0.4646,	Adjusted R-squared:  0.4578 
# F-statistic: 68.55 on 1 and 79 DF,  p-value: 2.483e-12

# R codes for analyzing the effect of SM on ANPP in 2019.
summary(lm(ANPP~SM, data=subset(srda_ann, Year=="2019")))

# Results of analysis
#
# Call:
# lm(formula = ANPP ~ SM, data = subset(srda_ann, Year == "2019"))
# 
# Residuals:
#     Min      1Q  Median      3Q     Max 
# -64.111 -13.098  -3.378  16.525  65.141 
# 
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  -49.325     23.174  -2.128   0.0433 *  
# SM            11.455      2.202   5.201 2.22e-05 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Residual standard error: 30.36 on 25 degrees of freedom
# Multiple R-squared:  0.5197,	Adjusted R-squared:  0.5005 

# R codes for analyzing the effect of SM on BNPP
summary(lm(BNPP~SM, data=srda_ann))

# Results of analysis
#
# Call:
# lm(formula = BNPP ~ SM, data = srda_ann)
# 
# Residuals:
#     Min      1Q  Median      3Q     Max 
# -32.007  -3.898   2.735   9.290  16.374 
# 
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  52.8035     6.7976   7.768 2.97e-10 ***
# SM            2.6102     0.6515   4.006 0.000197 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Residual standard error: 12.09 on 52 degrees of freedom
#   (27 observations deleted due to missingness)
# Multiple R-squared:  0.2359,	Adjusted R-squared:  0.2212 
# F-statistic: 16.05 on 1 and 52 DF,  p-value: 0.0001973

# R codes for analyzing the effect of SM on BNPP in 2019.
summary(lm(BNPP~SM, data=subset(srda_ann, Year=="2019")))

# Results of analysis
#
# Call:
# lm(formula = BNPP ~ SM, data = subset(srda_ann, Year == "2019"))
# 
# Residuals:
#     Min      1Q  Median      3Q     Max 
# -22.298  -4.408   2.625   5.554   8.941 
# 
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  56.6203     5.7991   9.764 5.18e-10 ***
# SM            2.6504     0.5511   4.809 6.11e-05 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Residual standard error: 7.597 on 25 degrees of freedom
# Multiple R-squared:  0.4805,	Adjusted R-squared:  0.4598 
# F-statistic: 23.13 on 1 and 25 DF,  p-value: 6.111e-05

# R codes for analyzing the effect of SM on MBC
summary(lm(MBC~SM, data=srda_ann))

# Results of analysis
#
# Call:
#   lm(formula = MBC ~ SM, data = srda_ann)
#
# Residuals:
#   Min      1Q  Median      3Q     Max 
# -50.566 -16.913   1.026  17.074  36.063 
#
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)   88.530     17.171   5.156 2.49e-05 ***
# SM             5.496      1.632   3.368  0.00245 ** 
#   ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Residual standard error: 22.49 on 25 degrees of freedom
# (54 observations deleted due to missingness)
# Multiple R-squared:  0.3121,	Adjusted R-squared:  0.2846 
# F-statistic: 11.34 on 1 and 25 DF,  p-value: 0.002454

# R codes for analyzing the effect of SM on MBN
summary(lm(MBN~SM, data=srda_ann))

# Results of analysis
#
# Call:
#   lm(formula = MBN ~ SM, data = srda_ann)
#
# Residuals:
#      Min       1Q   Median       3Q      Max 
# -13.4546  -2.8397   0.0395   3.4097   9.6772 
#
# Coefficients:
#              Estimate Std. Error t value Pr(>|t|)   
# (Intercept)   11.058      4.545   2.433  0.02248 * 
# SM             1.355      0.432   3.138  0.00432 **
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Residual standard error: 5.954 on 25 degrees of freedom
# (54 observations deleted due to missingness)
# Multiple R-squared:  0.2826,	Adjusted R-squared:  0.2539 
# F-statistic: 9.847 on 1 and 25 DF,  p-value: 0.00432

#####################################################################################
#####################################################################################

#####################################################################################
# Codes of the following part is used to analyze the linear relationships between
# soil respiration and its components with soil temperature and moisture.
# Results of these analyses can also be found in Figure S7.
#####################################################################################

# R codes for analyzing the effect of ST on SR.
summary(lm(log(SR)~ST, data=srda_ann))

# Results of analysis
#
# Call:
#   lm(formula = log(SR) ~ ST, data = srda_ann)
#
# Residuals:
#      Min       1Q   Median       3Q      Max 
# -0.70608 -0.22722  0.04306  0.24774  0.51909 
#
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  1.74272    0.45010   3.872 0.000221 ***
# ST          -0.07712    0.02802  -2.752 0.007347 ** 
#   ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Residual standard error: 0.2983 on 79 degrees of freedom
# Multiple R-squared:  0.08747,	Adjusted R-squared:  0.07592 
# F-statistic: 7.573 on 1 and 79 DF,  p-value: 0.007347

# R codes for analyzing the effect of ST on SR in 2019.
summary(lm(log(SR)~ST, data=subset(srda_ann, Year=="2019")))

# Results of analysis
#
# Call:
# lm(formula = log(SR) ~ ST, data = subset(srda_ann, Year == "2019"))
# 
# Residuals:
#      Min       1Q   Median       3Q      Max 
# -0.46691 -0.24604  0.06627  0.23599  0.41474 
# 
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)   
# (Intercept)  2.42794    0.73899   3.285  0.00301 **
# ST          -0.12085    0.04781  -2.528  0.01817 * 
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Residual standard error: 0.288 on 25 degrees of freedom
# Multiple R-squared:  0.2036,	Adjusted R-squared:  0.1717 
# F-statistic:  6.39 on 1 and 25 DF,  p-value: 0.01817

# R codes for analyzing the effect of SM on SR.
summary(lm(log(SR)~SM, data=srda_ann))

# Results of analysis
#
# Call:
#   lm(formula = log(SR) ~ SM, data = srda_ann)
#
# Residuals:
#      Min       1Q   Median       3Q      Max 
# -0.47464 -0.14623  0.00776  0.13158  0.39170 
#
# Coefficients:
#              Estimate Std. Error t value Pr(>|t|)    
# (Intercept) -0.345311   0.081379  -4.243 5.95e-05 ***
# SM           0.092422   0.008493  10.882  < 2e-16 ***
#   ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Residual standard error: 0.1975 on 79 degrees of freedom
# Multiple R-squared:  0.5998,	Adjusted R-squared:  0.5948 
# F-statistic: 118.4 on 1 and 79 DF,  p-value: < 2.2e-16

# R codes for analyzing the effect of SM on SR in 2019.
summary(lm(log(SR)~SM, data=subset(srda_ann, Year=="2019")))

# Results of analysis
#
# Call:
# lm(formula = log(SR) ~ SM, data = subset(srda_ann, Year == "2019"))
# 
# Residuals:
#      Min       1Q   Median       3Q      Max 
# -0.44424 -0.14370  0.03529  0.12557  0.41541 
# 
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept) -0.35340    0.15695  -2.252   0.0334 *  
# SM           0.09021    0.01492   6.048 2.56e-06 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Residual standard error: 0.2056 on 25 degrees of freedom
# Multiple R-squared:  0.594,	Adjusted R-squared:  0.5778 
# F-statistic: 36.58 on 1 and 25 DF,  p-value: 2.559e-06

# R codes for analyzing the effect of ST on RA.
summary(lm(log(RA)~ST, data=srda_ann))

# Results of analysis
#
# Call:
#   lm(formula = log(RA) ~ ST, data = srda_ann)
# 
# Residuals:
#      Min       1Q   Median       3Q      Max 
# -0.92208 -0.33856  0.01024  0.33861  0.80125 
#
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  1.46578    0.60928   2.406 0.018476 *  
# ST          -0.13376    0.03793  -3.526 0.000705 ***
#   ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Residual standard error: 0.4037 on 79 degrees of freedom
# Multiple R-squared:  0.136,	Adjusted R-squared:  0.125 
# F-statistic: 12.43 on 1 and 79 DF,  p-value: 0.0007054

# R codes for analyzing the effect of ST on RA in 2019.
summary(lm(log(RA)~ST, data=subset(srda_ann, Year=="2019")))

# Results of analysis
#
# Call:
# lm(formula = log(RA) ~ ST, data = subset(srda_ann, Year == "2019"))
# 
# Residuals:
#     Min      1Q  Median      3Q     Max 
# -0.8880 -0.4183  0.1766  0.4163  0.6846 
# 
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)  
# (Intercept)  2.29267    1.22469   1.872   0.0729 .
# ST          -0.18499    0.07923  -2.335   0.0279 *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Residual standard error: 0.4772 on 25 degrees of freedom
# Multiple R-squared:  0.179,	Adjusted R-squared:  0.1462 
# F-statistic: 5.451 on 1 and 25 DF,  p-value: 0.02788

# R codes for analyzing the effect of SM on RA.
summary(lm(log(RA)~SM, data=srda_ann))

# Results of analysis
#
# Call:
#   lm(formula = log(RA) ~ SM, data = srda_ann)
# 
# Residuals:
#      Min       1Q   Median       3Q      Max 
# -0.84568 -0.26330  0.03976  0.27799  0.64926 
#
# Coefficients:
#              Estimate Std. Error t value Pr(>|t|)    
# (Intercept) -1.56254    0.14601   -10.7  < 2e-16 ***
# SM           0.09600    0.01524     6.3 1.57e-08 ***
#   ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Residual standard error: 0.3544 on 79 degrees of freedom
# Multiple R-squared:  0.3344,	Adjusted R-squared:  0.326 
# F-statistic: 39.69 on 1 and 79 DF,  p-value: 1.574e-08

# R codes for analyzing the effect of SM on RA in 2019.
summary(lm(log(RA)~SM, data=subset(srda_ann, Year=="2019")))

# Results of analysis
#
# Call:
# lm(formula = log(RA) ~ SM, data = subset(srda_ann, Year == "2019"))
# 
# Residuals:
#     Min      1Q  Median      3Q     Max 
# -0.7659 -0.1749  0.0372  0.1961  0.7605 
# 
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept) -1.98287    0.27388  -7.240 1.38e-07 ***
# SM           0.13986    0.02603   5.373 1.42e-05 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Residual standard error: 0.3588 on 25 degrees of freedom
# Multiple R-squared:  0.536,	Adjusted R-squared:  0.5174 
# F-statistic: 28.87 on 1 and 25 DF,  p-value: 1.422e-05

# R codes for analyzing the effect of ST on RH.
summary(lm(log(RH)~ST, data=srda_ann))

# Results of analysis
#
# Call:
#   lm(formula = log(RH) ~ ST, data = srda_ann)
# 
# Residuals:
#      Min       1Q   Median       3Q      Max 
# -0.64757 -0.22960  0.02601  0.21302  0.59027 
#
# Coefficients:
#               Estimate Std. Error t value Pr(>|t|)  
# (Intercept)  0.97466    0.42703   2.282   0.0252 *
# ST          -0.05283    0.02659  -1.987   0.0504 .
# ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Residual standard error: 0.283 on 79 degrees of freedom
# Multiple R-squared:  0.0476,	Adjusted R-squared:  0.03554 
# F-statistic: 3.948 on 1 and 79 DF,  p-value: 0.05039

# R codes for analyzing the effect of ST on RH in 2019.
summary(lm(log(RH)~ST, data=subset(srda_ann, Year=="2019")))

# Results of analysis
#
# Call:
# lm(formula = log(RH) ~ ST, data = subset(srda_ann, Year == "2019"))
# 
# Residuals:
#      Min       1Q   Median       3Q      Max 
# -0.37562 -0.14283 -0.00345  0.18477  0.33618 
# 
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)   
# (Intercept)  1.61413    0.54548   2.959  0.00666 **
# ST          -0.09450    0.03529  -2.678  0.01291 * 
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Residual standard error: 0.2126 on 25 degrees of freedom
# Multiple R-squared:  0.2229,	Adjusted R-squared:  0.1918 
# F-statistic:  7.17 on 1 and 25 DF,  p-value: 0.01291

# R codes for analyzing the effect of SM on RH.
summary(lm(log(RH)~SM, data=srda_ann))

# Results of analysis
#
# Call:
#   lm(formula = log(RH) ~ SM, data = srda_ann)
#
# Residuals:
#      Min       1Q   Median       3Q      Max 
# -0.36027 -0.12690  0.00474  0.12026  0.32962 
#
# Coefficients:
#              Estimate Std. Error t value Pr(>|t|)    
# (Intercept) -0.699517   0.070114  -9.977 1.22e-15 ***
# SM           0.089730   0.007317  12.263  < 2e-16 ***
#   ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Residual standard error: 0.1702 on 79 degrees of freedom
# Multiple R-squared:  0.6556,	Adjusted R-squared:  0.6512 
# F-statistic: 150.4 on 1 and 79 DF,  p-value: < 2.2e-16

# R codes for analyzing the effect of SM on RH in 2019.
summary(lm(log(RH)~SM, data=subset(srda_ann, Year=="2019")))

# Results of analysis
#
# Call:
# lm(formula = log(RH) ~ SM, data = subset(srda_ann, Year == "2019"))
# 
# Residuals:
#      Min       1Q   Median       3Q      Max 
# -0.30623 -0.10146  0.01340  0.08601  0.25435 
# 
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept) -0.53464    0.11580  -4.617 0.000101 ***
# SM           0.06798    0.01101   6.177 1.85e-06 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Residual standard error: 0.1517 on 25 degrees of freedom
# Multiple R-squared:  0.6042,	Adjusted R-squared:  0.5883 
# F-statistic: 38.16 on 1 and 25 DF,  p-value: 1.849e-06

#####################################################################################
#####################################################################################

#####################################################################################
# Codes of the following part is used to analyze the linear relationships between
# autotrophic respiration with aboveground and belowground net primary productivity, 
# and heterotrophic respirations with microbial biomass carbon and nitrogen.
# Results of these analyses can also be found in Figure S8.
#####################################################################################

# R codes for analyzing the effect of ANPP on RA.
summary(lm(log(RA)~ANPP, data=srda_ann))

# Results of analysis
#
# Call:
#   lm(formula = log(RA) ~ ANPP, data = srda_ann)
#
# Residuals:
#      Min       1Q   Median       3Q      Max 
# -0.94643 -0.19744  0.00736  0.23987  0.58956 
#
# Coefficients:
#               Estimate Std. Error t value Pr(>|t|)    
# (Intercept) -1.1751248  0.0680826  -17.26  < 2e-16 ***
# ANPP         0.0070464  0.0008271    8.52 8.44e-13 ***
#   ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Residual standard error: 0.3136 on 79 degrees of freedom
# Multiple R-squared:  0.4788,	Adjusted R-squared:  0.4722 
# F-statistic: 72.59 on 1 and 79 DF,  p-value: 8.44e-13

# R codes for analyzing the effect of ANPP on RA in 2019.
summary(lm(log(RA)~ANPP, data=subset(srda_ann, Year=="2019")))

# Results of analysis
#
# Call:
# lm(formula = log(RA) ~ ANPP, data = subset(srda_ann, Year == 
#     "2019"))
# 
# Residuals:
#      Min       1Q   Median       3Q      Max 
# -0.79863 -0.10921 -0.01292  0.15873  0.40330 
# 
# Coefficients:
#              Estimate Std. Error t value Pr(>|t|)    
# (Intercept) -1.250635   0.099095 -12.621 2.42e-12 ***
# ANPP         0.010278   0.001248   8.238 1.37e-08 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Residual standard error: 0.2733 on 25 degrees of freedom
# Multiple R-squared:  0.7308,	Adjusted R-squared:   0.72 
# F-statistic: 67.87 on 1 and 25 DF,  p-value: 1.371e-08

# R codes for analyzing the effect of BNPP on RA.
summary(lm(log(RA)~BNPP, data=srda_ann))

# Results of analysis
#
# Call:
# lm(formula = log(RA) ~ BNPP, data = srda_ann)
# 
# Residuals:
#      Min       1Q   Median       3Q      Max 
# -0.84063 -0.24137  0.05818  0.29458  0.46191 
# 
# Coefficients:
#              Estimate Std. Error t value Pr(>|t|)    
# (Intercept) -2.447835   0.256084  -9.559 4.82e-13 ***
# BNPP         0.022100   0.003186   6.937 6.24e-09 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Residual standard error: 0.3177 on 52 degrees of freedom
#   (27 observations deleted due to missingness)
# Multiple R-squared:  0.4806,	Adjusted R-squared:  0.4706 
# F-statistic: 48.12 on 1 and 52 DF,  p-value: 6.239e-09

# R codes for analyzing the effect of BNPP on RA in 2019.
summary(lm(log(RA)~BNPP, data=subset(srda_ann, Year=="2019")))

# Results of analysis
#
# Call:
# lm(formula = log(RA) ~ BNPP, data = subset(srda_ann, Year == 
#     "2019"))
# 
# Residuals:
#      Min       1Q   Median       3Q      Max 
# -0.61001 -0.09475  0.01247  0.13526  0.37186 
# 
# Coefficients:
#              Estimate Std. Error t value Pr(>|t|)    
# (Intercept) -4.311263   0.369950  -11.65 1.34e-11 ***
# BNPP         0.044883   0.004393   10.22 2.07e-10 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Residual standard error: 0.2315 on 25 degrees of freedom
# Multiple R-squared:  0.8068,	Adjusted R-squared:  0.7991 
# F-statistic: 104.4 on 1 and 25 DF,  p-value: 2.072e-10

# R codes for analyzing the effect of MBC on RH.
summary(lm(log(RH)~MBC, data=srda_ann))

# Results of analysis
#
# Call:
#   lm(formula = log(RH) ~ MBC, data = srda_ann)
#
# Residuals:
#   Min       1Q   Median       3Q      Max 
# -0.41237 -0.12950  0.00805  0.15132  0.37318 
#
# Coefficients:
#              Estimate Std. Error t value Pr(>|t|)   
# (Intercept) -0.476670   0.227037  -2.100  0.04603 * 
# MBC          0.004389   0.001546   2.839  0.00886 **
#   ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Residual standard error: 0.2097 on 25 degrees of freedom
# (54 observations deleted due to missingness)
# Multiple R-squared:  0.2438,	Adjusted R-squared:  0.2135 
# F-statistic: 8.059 on 1 and 25 DF,  p-value: 0.008863

# R codes for analyzing the effect of MBN on RH.
summary(lm(log(RH)~MBN, data=srda_ann))

# Results of analysis
#
# Call:
#   lm(formula = log(RH) ~ MBN, data = srda_ann)
#
# Residuals:
#      Min       1Q   Median       3Q      Max 
# -0.43570 -0.13542  0.01706  0.10795  0.41093 
#
# Coefficients:
#                Estimate Std. Error t value Pr(>|t|)   
# (Intercept) -0.310827   0.147678  -2.105   0.0455 * 
# MBN          0.018842   0.005732   3.287   0.0030 **
#   ---
#   Signif. codes:  0 ??***?? 0.001 ??**?? 0.01 ??*?? 0.05 ??.?? 0.1 ?? ?? 1
#
# Residual standard error: 0.2015 on 25 degrees of freedom
# (54 observations deleted due to missingness)
# Multiple R-squared:  0.3018,	Adjusted R-squared:  0.2739 
# F-statistic: 10.81 on 1 and 25 DF,  p-value: 0.002999

#####################################################################################
# Codes of the following part is used to investigating effects of soil temperature
# and moisture, net primary productities on autotrophic respiration and effects of 
# soil temperature and moisture, microbial biomass on heterotrophic respirations with
# general linear models and structural equation models.
# Results of these analyses can also be found in Figure 4.
#####################################################################################

# standardized data

srda_ann_sem_1 = subset(srda_ann, Year=="2019"); 
srda_ann_sem = srda_ann_sem_1
names(srda_ann_sem)
length(names(srda_ann_sem))

for (i in 5:15) {
  if (i <= 13) {
    srda_ann_sem[,i] = (srda_ann_sem[,i]-mean(srda_ann_sem[,i], na.rm=T))/sd(srda_ann_sem[,i], na.rm=T)
  } else {
    srda_ann_sem[,i] = (log(srda_ann_sem[,i])-mean(log(srda_ann_sem[,i]), na.rm=T))/sd(log(srda_ann_sem[,i]), na.rm=T)
  }
}

# pdry = ifelse(srda_ann_sem$Precip == "Dry", 1, 0)
# pamb = ifelse(srda_ann_sem$Precip == "Amb", 1, 0)
# pwet = ifelse(srda_ann_sem$Precip == "Wet", 1, 0)
# 
# srda_ann_sem$DryTreat = (pdry - mean(pdry, na.rm=T))/sd(pdry, na.rm=T)
# srda_ann_sem$CKTreat  = (pamb - mean(pamb, na.rm=T))/sd(pamb, na.rm=T)
# srda_ann_sem$WetTreat = (pwet - mean(pwet, na.rm=T))/sd(pwet, na.rm=T)

fen = ifelse(srda_ann_sem$Man == "Fencing", 1, 0)
gra = ifelse(srda_ann_sem$Man == "Grazing", 1, 0)
mow = ifelse(srda_ann_sem$Man == "Mowing", 1, 0)

srda_ann_sem$FenTreat = (fen - mean(fen, na.rm=T))/sd(fen, na.rm=T)
srda_ann_sem$GraTreat = (gra - mean(gra, na.rm=T))/sd(gra, na.rm=T)
srda_ann_sem$MowTreat = (mow - mean(mow, na.rm=T))/sd(mow, na.rm=T)
names(srda_ann_sem)

################################################################################
################################################################################

# initial SEM for RA
rasem_i = "
RA ~ ANPP + BNPP + ST + SM
BNPP ~ SM + ST + MowTreat + GraTreat
ANPP ~ SM + ST + MowTreat + GraTreat
SM ~ GS_Pre + MowTreat + GraTreat
ST ~ GS_Pre
SM ~~ ST
BNPP ~~ ANPP
"
fit_rasem_i = sem(rasem_i, fixed.x = F, data = srda_ann_sem)
summary(fit_rasem_i,standardized=TRUE, rsquare=T)
fitMeasures(fit_rasem_i, c("chisq", "pvalue", "gfi", "rmsea", "aic"))

#   Estimator                                         ML
#   Optimization method                           NLMINB
#   Number of free parameters                         29
#
#   Number of observations                            27
#
# Model Test User Model:
#                                                       
#   Test statistic                                51.065
#   Degrees of freedom                                 7
#   P-value (Chi-square)                           0.000
#
# Parameter Estimates:
#
#   Standard errors                             Standard
#   Information                                 Expected
#   Information saturated (h1) model          Structured
#
# Regressions:
#                    Estimate  Std.Err  z-value  P(>|z|)   Std.lv  Std.all
#   RA ~                                                                  
#     ANPP              0.060    0.208    0.290    0.772    0.060    0.060
#     BNPP              0.724    0.205    3.531    0.000    0.724    0.723
#     ST                0.077    0.097    0.797    0.425    0.077    0.077
#     SM                0.227    0.121    1.875    0.061    0.227    0.228
#   BNPP ~                                                                
#     SM                0.868    0.124    7.003    0.000    0.868    0.873
#     ST               -0.014    0.117   -0.123    0.902   -0.014   -0.014
#     MowTreat         -0.630    0.121   -5.213    0.000   -0.630   -0.631
#     GraTreat         -0.249    0.113   -2.195    0.028   -0.249   -0.249
#   ANPP ~                                                                
#     SM                0.968    0.117    8.270    0.000    0.968    0.973
#     ST                0.115    0.110    1.046    0.296    0.115    0.116
#     MowTreat         -0.651    0.114   -5.704    0.000   -0.651   -0.651
#     GraTreat         -0.354    0.107   -3.314    0.001   -0.354   -0.355
#   SM ~                                                                  
#     GS_Pre            0.839    0.083   10.096    0.000    0.839    0.835
#     MowTreat          0.398    0.090    4.411    0.000    0.398    0.396
#     GraTreat          0.208    0.090    2.302    0.021    0.208    0.207
#   ST ~                                                                  
#     GS_Pre           -0.496    0.167   -2.970    0.003   -0.496   -0.496
# 
# Covariances:
#                    Estimate  Std.Err  z-value  P(>|z|)   Std.lv  Std.all
#  .SM ~~                                                                 
#    .ST               -0.123    0.073   -1.673    0.094   -0.123   -0.340
#  .BNPP ~~                                                               
#    .ANPP              0.154    0.052    2.943    0.003    0.154    0.687
#   MowTreat ~~                                                           
#     GraTreat         -0.481    0.207   -2.324    0.020   -0.481   -0.500
#     GS_Pre            0.000    0.185    0.000    1.000    0.000    0.000
#   GraTreat ~~                                                           
#     GS_Pre            0.000    0.185    0.000    1.000    0.000    0.000
# 
# Variances: 
#                    Estimate  Std.Err  z-value  P(>|z|)   Std.lv  Std.all 
#    .RA                0.159    0.043    3.674    0.000    0.159    0.165
#    .BNPP              0.238    0.065    3.674    0.000    0.238    0.247
#    .ANPP              0.212    0.058    3.674    0.000    0.212    0.220
#    .SM                0.179    0.049    3.674    0.000    0.179    0.185
#    .ST                0.726    0.198    3.674    0.000    0.726    0.754
#     MowTreat          0.963    0.262    3.674    0.000    0.963    1.000
#     GraTreat          0.963    0.262    3.674    0.000    0.963    1.000
#     GS_Pre            0.963    0.262    3.674    0.000    0.963    1.000
# 
# R-Square:
#                    Estimate
#     RA                0.835
#     BNPP              0.753
#     ANPP              0.780
#     SM                0.815
#     ST                0.246
# 
#   chisq  pvalue     gfi   rmsea     aic 
#  51.065   0.000   0.779   0.483 454.133 

######################################################################################

# inital SEM for RH
rhsem_i = "
RH ~ MBC + MBN + ST + SM
MBC ~ SM + ST + MowTreat + GraTreat
MBN ~ SM 
SM ~ GS_Pre + MowTreat + GraTreat
ST ~ GS_Pre
SM ~~ ST
MBC ~~ MBN
"
fit_rhsem_i = sem(rhsem_i, fixed.x=F, data = srda_ann_sem)
summary(fit_rhsem_i, standardized=TRUE, rsquare=T)
fitMeasures(fit_rhsem_i, c("chisq", "pvalue", "gfi", "rmsea", "aic"))

#   Estimator                                         ML
#   Optimization method                           NLMINB
#   Number of free parameters                         26
#                                                       
#   Number of observations                            27
# 
# Model Test User Model:
#                                                       
#   Test statistic                                72.122
#   Degrees of freedom                                10
#   P-value (Chi-square)                           0.000
#
# Parameter Estimates:
#
#   Standard errors                             Standard
#   Information                                 Expected
#   Information saturated (h1) model          Structured
# 
# Regressions:
#                    Estimate  Std.Err  z-value  P(>|z|)   Std.lv  Std.all
#   RH ~                                                                  
#     MBC              -0.330    0.255   -1.292    0.196   -0.330   -0.327
#     MBN               0.446    0.242    1.839    0.066    0.446    0.444
#     ST               -0.171    0.145   -1.184    0.237   -0.171   -0.170
#     SM                0.636    0.151    4.208    0.000    0.636    0.636
#   MBC ~                                                                 
#     SM                0.387    0.158    2.453    0.014    0.387    0.390
#     ST               -0.245    0.086   -2.836    0.005   -0.245   -0.246
#     MowTreat          0.142    0.089    1.586    0.113    0.142    0.142
#     GraTreat         -0.148    0.084   -1.763    0.078   -0.148   -0.148
#   MBN ~                                                                 
#     SM                0.532    0.162    3.275    0.001    0.532    0.533
#   SM ~                                                                  
#     GS_Pre            0.839    0.083   10.096    0.000    0.839    0.835
#     MowTreat          0.398    0.090    4.411    0.000    0.398    0.396
#     GraTreat          0.208    0.090    2.302    0.021    0.208    0.207
#   ST ~                                                                  
#     GS_Pre           -0.496    0.167   -2.970    0.003   -0.496   -0.496
# 
# Covariances:
#                    Estimate  Std.Err  z-value  P(>|z|)   Std.lv  Std.all
#  .SM ~~                                                                 
#    .ST               -0.123    0.073   -1.673    0.094   -0.123   -0.340
#  .MBC ~~                                                                
#    .MBN               0.548    0.160    3.428    0.001    0.548    0.878
#   MowTreat ~~                                                           
#     GraTreat         -0.481    0.207   -2.324    0.020   -0.481   -0.500
#     GS_Pre            0.000    0.185    0.000    1.000    0.000    0.000
#   GraTreat ~~                                                           
#     GS_Pre           -0.000    0.185   -0.000    1.000   -0.000   -0.000
# 
# Variances:
#                    Estimate  Std.Err  z-value  P(>|z|)   Std.lv  Std.all
#    .RH                0.330    0.090    3.674    0.000    0.330    0.339
#    .MBC               0.564    0.154    3.674    0.000    0.564    0.589
#    .MBN               0.691    0.188    3.674    0.000    0.691    0.716
#    .SM                0.179    0.049    3.674    0.000    0.179    0.185
#    .ST                0.726    0.198    3.674    0.000    0.726    0.754
#     MowTreat          0.963    0.262    3.674    0.000    0.963    1.000
#     GraTreat          0.963    0.262    3.674    0.000    0.963    1.000
#     GS_Pre            0.963    0.262    3.674    0.000    0.963    1.000
# 
# R-Square:
#                    Estimate
#     RH                0.661
#     MBC               0.411
#     MBN               0.284
#     SM                0.815
#     ST                0.246
# 
#   chisq  pvalue     gfi   rmsea     aic 
#  72.122   0.000   0.810   0.480 500.726 

################################################################################
################################################################################

# final SEM for RA
rasem_f = "
RA ~ ANPP + BNPP + ST + SM
BNPP ~ SM + ST
ANPP ~ SM
SM ~~ ST
BNPP ~~ ANPP
"
fit_rasem_f = sem(rasem_f, fixed.x = F, data = srda_ann_sem)
summary(fit_rasem_f,standardized=TRUE, rsquare=T)
fitMeasures(fit_rasem_f, c("chisq", "pvalue", "gfi", "rmsea", "aic"))

#   Estimator                                         ML
#   Optimization method                           NLMINB
#   Number of free parameters                         14
#                                                       
#   Number of observations                            27
# 
# Model Test User Model:
#                                                       
#   Test statistic                                 0.251
#   Degrees of freedom                                 1
#   P-value (Chi-square)                           0.616
# 
# Parameter Estimates:
# 
#   Standard errors                             Standard
#   Information                                 Expected
#   Information saturated (h1) model          Structured
# 
# Regressions:
#                    Estimate  Std.Err  z-value  P(>|z|)   Std.lv  Std.all
#   RA ~                                                                  
#     ANPP              0.060    0.209    0.289    0.773    0.060    0.060
#     BNPP              0.724    0.205    3.532    0.000    0.724    0.720
#     ST                0.077    0.094    0.817    0.414    0.077    0.077
#     SM                0.227    0.122    1.855    0.064    0.227    0.227
#   BNPP ~                                                                
#     SM                0.633    0.143    4.428    0.000    0.633    0.636
#     ST               -0.117    0.086   -1.359    0.174   -0.117   -0.117
#   ANPP ~                                                                
#     SM                0.721    0.133    5.405    0.000    0.721    0.721
# 
# Covariances:
#                    Estimate  Std.Err  z-value  P(>|z|)   Std.lv  Std.all
#   ST ~~                                                                 
#     SM               -0.499    0.209   -2.389    0.017   -0.499   -0.518
#  .BNPP ~~                                                               
#    .ANPP              0.396    0.118    3.345    0.001    0.396    0.841
# 
# Variances:
#                    Estimate  Std.Err  z-value  P(>|z|)   Std.lv  Std.all
#    .RA                0.159    0.043    3.674    0.000    0.159    0.165
#    .BNPP              0.480    0.131    3.674    0.000    0.480    0.504
#    .ANPP              0.462    0.126    3.674    0.000    0.462    0.480
#     ST                0.963    0.262    3.674    0.000    0.963    1.000
#     SM                0.963    0.262    3.674    0.000    0.963    1.000
# 
# R-Square:
#                    Estimate
#     RA                0.835
#     BNPP              0.496
#     ANPP              0.520
# 
#   chisq  pvalue     gfi   rmsea     aic 
#   0.251   0.616   0.996   0.000 277.119 

######################################################################################

# final SEM for RH
rhsem_f = "
RH ~ MBC + MBN + SM + ST
MBC ~ SM + ST
MBN ~ SM
SM ~~ ST
MBC ~~ MBN
"
fit_rhsem_f = sem(rhsem_f, fixed.x=F, data = srda_ann_sem)
summary(fit_rhsem_f, standardized=TRUE, rsquare=T)
fitMeasures(fit_rhsem_f, c("chisq", "pvalue", "gfi", "rmsea", "aic"))

#   Estimator                                         ML
#   Optimization method                           NLMINB
#   Number of free parameters                         14
#                                                       
#   Number of observations                            27
#                                                       
# Model Test User Model:
#                                                       
#   Test statistic                                 0.022
#   Degrees of freedom                                 1
#   P-value (Chi-square)                           0.883
# 
# Parameter Estimates:
# 
#   Standard errors                             Standard
#   Information                                 Expected
#   Information saturated (h1) model          Structured
# 
# Regressions:
#                    Estimate  Std.Err  z-value  P(>|z|)   Std.lv  Std.all
#   RH ~                                                                  
#     MBC              -0.330    0.255   -1.293    0.196   -0.330   -0.329
#     MBN               0.446    0.240    1.856    0.063    0.446    0.446
#     SM                0.636    0.150    4.253    0.000    0.636    0.636
#     ST               -0.171    0.146   -1.174    0.241   -0.171   -0.171
#   MBC ~                                                                 
#     SM                0.431    0.162    2.664    0.008    0.431    0.433
#     ST               -0.247    0.099   -2.481    0.013   -0.247   -0.248
#   MBN ~                                                                 
#     SM                0.532    0.163    3.261    0.001    0.532    0.532
# 
# Covariances:
#                    Estimate  Std.Err  z-value  P(>|z|)   Std.lv  Std.all
#   SM ~~                                                                 
#     ST               -0.499    0.209   -2.389    0.017   -0.499   -0.518
#  .MBC ~~                                                                
#    .MBN               0.541    0.163    3.324    0.001    0.541    0.832
# 
# Variances:
#                    Estimate  Std.Err  z-value  P(>|z|)   Std.lv  Std.all
#    .RH                0.330    0.090    3.674    0.000    0.330    0.343
#    .MBC               0.612    0.167    3.674    0.000    0.612    0.641
#    .MBN               0.691    0.188    3.674    0.000    0.691    0.717
#     SM                0.963    0.262    3.674    0.000    0.963    1.000
#     ST                0.963    0.262    3.674    0.000    0.963    1.000
# 
# R-Square:
#                    Estimate
#     RH                0.657
#     MBC               0.359
#     MBN               0.283
# 
#   chisq  pvalue     gfi   rmsea     aic 
#   0.022   0.883   1.000   0.000 315.616 

#######################################################################################################
#######################################################################################################



